/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison implementation for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* C LALR(1) parser skeleton written by Richard Stallman, by
   simplifying the original so-called "semantic" parser.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

/* All symbols defined below should begin with yy or YY, to avoid
   infringing on user name space.  This should be done even for local
   variables, as they might otherwise be expanded by user macros.
   There are some unavoidable exceptions within include files to
   define necessary library symbols; they are noted "INFRINGES ON
   USER NAME SPACE" below.  */

/* Identify Bison output, and Bison version.  */
#define YYBISON 30802

/* Bison version string.  */
#define YYBISON_VERSION "3.8.2"

/* Skeleton name.  */
#define YYSKELETON_NAME "yacc.c"

/* Pure parsers.  */
#define YYPURE 0

/* Push parsers.  */
#define YYPUSH 0

/* Pull parsers.  */
#define YYPULL 1


/* Substitute the variable and function names.  */
#define yyparse         ir3_yyparse
#define yylex           ir3_yylex
#define yyerror         ir3_yyerror
#define yydebug         ir3_yydebug
#define yynerrs         ir3_yynerrs
#define yylval          ir3_yylval
#define yychar          ir3_yychar

/* First part of user prologue.  */
#line 32 "../src/freedreno/ir3/ir3_parser.y"

#define YYDEBUG 0

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <math.h>

#include "util/half_float.h"
#include "util/u_math.h"

#include "ir3/ir3.h"
#include "ir3/ir3_shader.h"
#include "ir3/instr-a3xx.h"

#include "ir3_parser.h"

#define swap(a, b) \
	do { __typeof(a) __tmp = (a); (a) = (b); (b) = __tmp; } while (0)

/* ir3 treats the abs/neg flags as separate flags for float vs integer,
 * but in the instruction encoding they are the same thing.  Tracking
 * them separately is only for the benefit of ir3 opt passes, and not
 * required here, so just use the float versions:
 */
#define IR3_REG_ABS     IR3_REG_FABS
#define IR3_REG_NEGATE  IR3_REG_FNEG

static pthread_mutex_t ir3_parse_mtx = PTHREAD_MUTEX_INITIALIZER;

static struct ir3_kernel_info    *info;
static struct ir3_shader_variant *variant;
/* NOTE the assembler doesn't really use the ir3_block construction
 * like the compiler does.  Everything is treated as one large block.
 * Which might happen to contain flow control.  But since we don't
 * use any of the ir3 backend passes (sched, RA, etc) this doesn't
 * really matter.
 */
static struct ir3_block          *block;   /* current shader block */
static struct ir3_instruction    *instr;   /* current instruction */
static unsigned ip; /* current instruction pointer */
static struct hash_table *labels;

static bool is_in_fullnop_section;
static bool is_in_fullsync_section;

void *ir3_parser_dead_ctx;

char* current_line;

static struct {
	unsigned flags;
	unsigned repeat;
	unsigned nop;
} iflags;

static struct {
	unsigned flags;
	unsigned wrmask;
} rflags;

static struct {
        uint32_t reg_address_hi;
        uint32_t reg_address_lo;
        uint32_t reg_tmp;

        uint32_t regs_to_dump[128];
        uint32_t regs_count;
} meta_print_data;

int ir3_yyget_lineno(void);

static void new_label(const char *name)
{
	ralloc_steal(labels, (void *) name);
	_mesa_hash_table_insert(labels, name, (void *)(uintptr_t)ip);
}

static struct ir3_instruction * new_instr(opc_t opc)
{
	instr = ir3_instr_create_at_end(block, opc, 4, 6);
	instr->flags = iflags.flags;
	instr->repeat = iflags.repeat;
	instr->nop = iflags.nop;
	instr->line = ir3_yyget_lineno();
	iflags.flags = iflags.repeat = iflags.nop = 0;

	if (is_in_fullnop_section) {
		struct ir3_instruction *nop =
			ir3_instr_create_at(ir3_before_instr(instr), OPC_NOP, 0, 0);
		nop->repeat = 5;
		ip++;
	}

	if (is_in_fullsync_section) {
		struct ir3_instruction *nop =
			ir3_instr_create_at(ir3_before_instr(instr), OPC_NOP, 0, 0);
		nop->flags = IR3_INSTR_SS | IR3_INSTR_SY;
		ip++;
	}

	ip++;
	return instr;
}

static void new_shader(void)
{
	variant->ir = ir3_create(variant->compiler, variant);
	block = ir3_block_create(variant->ir);
	list_addtail(&block->node, &variant->ir->block_list);
	ip = 0;
	labels = _mesa_hash_table_create(variant, _mesa_hash_string, _mesa_key_string_equal);
	ir3_parser_dead_ctx = ralloc_context(NULL);
}

static type_t parse_type(const char **type)
{
	if (!strncmp("f16", *type, 3)) {
		*type += 3;
		return TYPE_F16;
	} else if (!strncmp("f32", *type, 3)) {
		*type += 3;
		return TYPE_F32;
	} else if (!strncmp("u16", *type, 3)) {
		*type += 3;
		return TYPE_U16;
	} else if (!strncmp("u32", *type, 3)) {
		*type += 3;
		return TYPE_U32;
	} else if (!strncmp("s16", *type, 3)) {
		*type += 3;
		return TYPE_S16;
	} else if (!strncmp("s32", *type, 3)) {
		*type += 3;
		return TYPE_S32;
	} else if (!strncmp("u8", *type, 2)) {
		*type += 2;
		return TYPE_U8;
	} else if (!strncmp("u8_32", *type, 5)) {
		*type += 5;
		return TYPE_U8_32;
	} else if (!strncmp("u64", *type, 3)) {
		*type += 3;
		return TYPE_ATOMIC_U64;
	} else {
		assert(0);  /* shouldn't get here */
		return ~0;
	}
}

static struct ir3_instruction * parse_type_type(struct ir3_instruction *instr,
		const char *type_type)
{
	instr->cat1.src_type = parse_type(&type_type);
	instr->cat1.dst_type = parse_type(&type_type);
	return instr;
}

static struct ir3_register * new_src(int num, unsigned flags)
{
	struct ir3_register *reg;
	flags |= rflags.flags;
	if (num & 0x1)
		flags |= IR3_REG_HALF;
	reg = ir3_src_create(instr, num>>1, flags);
	reg->wrmask = MAX2(1, rflags.wrmask);
	rflags.flags = rflags.wrmask = 0;
	return reg;
}

static struct ir3_register * new_dst(int num, unsigned flags)
{
	struct ir3_register *reg;
	flags |= rflags.flags;
	if (num & 0x1)
		flags |= IR3_REG_HALF;
	reg = ir3_dst_create(instr, num>>1, flags);
	reg->wrmask = MAX2(1, rflags.wrmask);
	rflags.flags = rflags.wrmask = 0;
	return reg;
}

static struct ir3_register * dummy_dst(void)
{
	return new_dst(0, 0);
}

static void fixup_cat5_s2en(void)
{
	assert(opc_cat(instr->opc) == 5);
	if (!(instr->flags & IR3_INSTR_S2EN))
		return;
	/* For various reasons (ie. mainly to make the .s2en src easier to
	 * find, given that various different cat5 tex instructions can have
	 * different # of src registers), in ir3 the samp/tex src register
	 * is first, rather than last.  So we have to detect this case and
	 * fix things up.
	 */

	uint32_t s2en_off = instr->srcs_count - 1;
	if (instr->flags & IR3_INSTR_A1EN)
		s2en_off = instr->srcs_count - 2;

	struct ir3_register *s2en_src = instr->srcs[s2en_off];

	if (instr->flags & IR3_INSTR_B)
		assert(!(s2en_src->flags & IR3_REG_HALF));
	else
		assert(s2en_src->flags & IR3_REG_HALF);

	memmove(instr->srcs + 1, instr->srcs, s2en_off * sizeof(instr->srcs[0]));
	instr->srcs[0] = s2en_src;
}

static void add_const(unsigned reg, unsigned c0, unsigned c1, unsigned c2, unsigned c3)
{
	struct ir3_imm_const_state *imm_state = &variant->imm_state;
	assert((reg & 0x7) == 0);
	int idx = reg >> (1 + 2); /* low bit is half vs full, next two bits are swiz */
	if (idx * 4 + 4 > imm_state->size) {
		imm_state->values = rerzalloc(variant,
				imm_state->values,
				__typeof__(imm_state->values[0]),
				imm_state->size,
				idx * 4 + 4);
		for (unsigned i = imm_state->size; i < idx * 4; i++)
			imm_state->values[i] = 0xd0d0d0d0;
		imm_state->size = imm_state->count = idx * 4 + 4;
	}
	imm_state->values[idx * 4 + 0] = c0;
	imm_state->values[idx * 4 + 1] = c1;
	imm_state->values[idx * 4 + 2] = c2;
	imm_state->values[idx * 4 + 3] = c3;
}

static void add_buf_init_val(uint32_t val)
{
	assert(info->num_bufs > 0);
	unsigned idx = info->num_bufs - 1;

	if (!info->buf_init_data[idx]) {
		unsigned sz = info->buf_sizes[idx] * 4;
		info->buf_init_data[idx] = malloc(sz);
		memset(info->buf_init_data[idx], 0, sz);
	}

	assert(info->buf_init_data_sizes[idx] < info->buf_sizes[idx]);
	info->buf_init_data[idx][info->buf_init_data_sizes[idx]++] = val;
}

static void add_sysval(unsigned reg, unsigned compmask, gl_system_value sysval)
{
	unsigned n = variant->inputs_count++;
	variant->inputs[n].regid = reg;
	variant->inputs[n].sysval = true;
	variant->inputs[n].slot = sysval;
	variant->inputs[n].compmask = compmask;
	variant->total_in++;
}

static bool resolve_labels(void)
{
	int instr_ip = 0;
	foreach_instr (instr, &block->instr_list) {
		if (opc_cat(instr->opc) == 0 && instr->cat0.target_label) {
			struct hash_entry *entry = _mesa_hash_table_search(labels, instr->cat0.target_label);
			if (!entry) {
				fprintf(stderr, "unknown label %s\n", instr->cat0.target_label);
				return false;
			}
			int target_ip = (uintptr_t)entry->data;
			instr->cat0.immed = target_ip - instr_ip;
		}
		instr_ip++;
	}
	return true;
}

static unsigned cat6_type_shift()
{
	return util_logbase2(type_size(instr->cat6.type) / 8);
}

#ifdef YYDEBUG
int yydebug;
#endif

extern int yylex(void);
void ir3_yyset_lineno(int _line_number);
void ir3_yyset_input(FILE *f);

int yyparse(void);

static void yyerror(const char *error)
{
	fprintf(stderr, "error at line %d: %s\n%s\n", ir3_yyget_lineno(), error, current_line);
}

/* Needs to be a macro to use YYERROR */
#define illegal_syntax_from(gen_from, error)              \
	do {                                              \
		if (variant->compiler->gen >= gen_from) { \
			yyerror(error);                   \
			YYERROR;                          \
		}                                         \
	} while (0)

struct ir3 * ir3_parse(struct ir3_shader_variant *v,
		struct ir3_kernel_info *k, FILE *f)
{
	pthread_mutex_lock(&ir3_parse_mtx);

	ir3_yyset_lineno(1);
	ir3_yyset_input(f);
#ifdef YYDEBUG
	yydebug = 1;
#endif
	info = k;
	variant = v;

	is_in_fullnop_section = false;
	is_in_fullsync_section = false;

	if (yyparse() || !resolve_labels()) {
		ir3_destroy(variant->ir);
		variant->ir = NULL;
	}
	ralloc_free(labels);
	ralloc_free(ir3_parser_dead_ctx);

	struct ir3 *ir = variant->ir;
	pthread_mutex_unlock(&ir3_parse_mtx);
	return ir;
}

#line 414 "src/freedreno/ir3/ir3_parser.c"

# ifndef YY_CAST
#  ifdef __cplusplus
#   define YY_CAST(Type, Val) static_cast<Type> (Val)
#   define YY_REINTERPRET_CAST(Type, Val) reinterpret_cast<Type> (Val)
#  else
#   define YY_CAST(Type, Val) ((Type) (Val))
#   define YY_REINTERPRET_CAST(Type, Val) ((Type) (Val))
#  endif
# endif
# ifndef YY_NULLPTR
#  if defined __cplusplus
#   if 201103L <= __cplusplus
#    define YY_NULLPTR nullptr
#   else
#    define YY_NULLPTR 0
#   endif
#  else
#   define YY_NULLPTR ((void*)0)
#  endif
# endif

#include "ir3_parser.h"
/* Symbol kind.  */
enum yysymbol_kind_t
{
  YYSYMBOL_YYEMPTY = -2,
  YYSYMBOL_YYEOF = 0,                      /* "end of file"  */
  YYSYMBOL_YYerror = 1,                    /* error  */
  YYSYMBOL_YYUNDEF = 2,                    /* "invalid token"  */
  YYSYMBOL_T_INT = 3,                      /* T_INT  */
  YYSYMBOL_T_HEX = 4,                      /* T_HEX  */
  YYSYMBOL_T_FLOAT = 5,                    /* T_FLOAT  */
  YYSYMBOL_T_IDENTIFIER = 6,               /* T_IDENTIFIER  */
  YYSYMBOL_T_REGISTER = 7,                 /* T_REGISTER  */
  YYSYMBOL_T_CONSTANT = 8,                 /* T_CONSTANT  */
  YYSYMBOL_T_RT = 9,                       /* T_RT  */
  YYSYMBOL_T_A_LOCALSIZE = 10,             /* T_A_LOCALSIZE  */
  YYSYMBOL_T_A_CONST = 11,                 /* T_A_CONST  */
  YYSYMBOL_T_A_BUF = 12,                   /* T_A_BUF  */
  YYSYMBOL_T_A_INVOCATIONID = 13,          /* T_A_INVOCATIONID  */
  YYSYMBOL_T_A_WGID = 14,                  /* T_A_WGID  */
  YYSYMBOL_T_A_NUMWG = 15,                 /* T_A_NUMWG  */
  YYSYMBOL_T_A_BRANCHSTACK = 16,           /* T_A_BRANCHSTACK  */
  YYSYMBOL_T_A_IN = 17,                    /* T_A_IN  */
  YYSYMBOL_T_A_OUT = 18,                   /* T_A_OUT  */
  YYSYMBOL_T_A_TEX = 19,                   /* T_A_TEX  */
  YYSYMBOL_T_A_PVTMEM = 20,                /* T_A_PVTMEM  */
  YYSYMBOL_T_A_LOCALMEM = 21,              /* T_A_LOCALMEM  */
  YYSYMBOL_T_A_EARLYPREAMBLE = 22,         /* T_A_EARLYPREAMBLE  */
  YYSYMBOL_T_A_FULLNOPSTART = 23,          /* T_A_FULLNOPSTART  */
  YYSYMBOL_T_A_FULLNOPEND = 24,            /* T_A_FULLNOPEND  */
  YYSYMBOL_T_A_FULLSYNCSTART = 25,         /* T_A_FULLSYNCSTART  */
  YYSYMBOL_T_A_FULLSYNCEND = 26,           /* T_A_FULLSYNCEND  */
  YYSYMBOL_T_ABSNEG = 27,                  /* T_ABSNEG  */
  YYSYMBOL_T_NEG = 28,                     /* T_NEG  */
  YYSYMBOL_T_ABS = 29,                     /* T_ABS  */
  YYSYMBOL_T_R = 30,                       /* T_R  */
  YYSYMBOL_T_LAST = 31,                    /* T_LAST  */
  YYSYMBOL_T_HR = 32,                      /* T_HR  */
  YYSYMBOL_T_HC = 33,                      /* T_HC  */
  YYSYMBOL_T_EVEN = 34,                    /* T_EVEN  */
  YYSYMBOL_T_POS_INFINITY = 35,            /* T_POS_INFINITY  */
  YYSYMBOL_T_NEG_INFINITY = 36,            /* T_NEG_INFINITY  */
  YYSYMBOL_T_EI = 37,                      /* T_EI  */
  YYSYMBOL_T_WRMASK = 38,                  /* T_WRMASK  */
  YYSYMBOL_T_FLUT_0_0 = 39,                /* T_FLUT_0_0  */
  YYSYMBOL_T_FLUT_0_5 = 40,                /* T_FLUT_0_5  */
  YYSYMBOL_T_FLUT_1_0 = 41,                /* T_FLUT_1_0  */
  YYSYMBOL_T_FLUT_2_0 = 42,                /* T_FLUT_2_0  */
  YYSYMBOL_T_FLUT_E = 43,                  /* T_FLUT_E  */
  YYSYMBOL_T_FLUT_PI = 44,                 /* T_FLUT_PI  */
  YYSYMBOL_T_FLUT_INV_PI = 45,             /* T_FLUT_INV_PI  */
  YYSYMBOL_T_FLUT_INV_LOG2_E = 46,         /* T_FLUT_INV_LOG2_E  */
  YYSYMBOL_T_FLUT_LOG2_E = 47,             /* T_FLUT_LOG2_E  */
  YYSYMBOL_T_FLUT_INV_LOG2_10 = 48,        /* T_FLUT_INV_LOG2_10  */
  YYSYMBOL_T_FLUT_LOG2_10 = 49,            /* T_FLUT_LOG2_10  */
  YYSYMBOL_T_FLUT_4_0 = 50,                /* T_FLUT_4_0  */
  YYSYMBOL_T_SY = 51,                      /* T_SY  */
  YYSYMBOL_T_SS = 52,                      /* T_SS  */
  YYSYMBOL_T_JP = 53,                      /* T_JP  */
  YYSYMBOL_T_EQ_FLAG = 54,                 /* T_EQ_FLAG  */
  YYSYMBOL_T_SAT = 55,                     /* T_SAT  */
  YYSYMBOL_T_RPT = 56,                     /* T_RPT  */
  YYSYMBOL_T_UL = 57,                      /* T_UL  */
  YYSYMBOL_T_NOP = 58,                     /* T_NOP  */
  YYSYMBOL_T_OP_NOP = 59,                  /* T_OP_NOP  */
  YYSYMBOL_T_OP_BR = 60,                   /* T_OP_BR  */
  YYSYMBOL_T_OP_BRAO = 61,                 /* T_OP_BRAO  */
  YYSYMBOL_T_OP_BRAA = 62,                 /* T_OP_BRAA  */
  YYSYMBOL_T_OP_BRAC = 63,                 /* T_OP_BRAC  */
  YYSYMBOL_T_OP_BANY = 64,                 /* T_OP_BANY  */
  YYSYMBOL_T_OP_BALL = 65,                 /* T_OP_BALL  */
  YYSYMBOL_T_OP_BRAX = 66,                 /* T_OP_BRAX  */
  YYSYMBOL_T_OP_JUMP = 67,                 /* T_OP_JUMP  */
  YYSYMBOL_T_OP_CALL = 68,                 /* T_OP_CALL  */
  YYSYMBOL_T_OP_RET = 69,                  /* T_OP_RET  */
  YYSYMBOL_T_OP_KILL = 70,                 /* T_OP_KILL  */
  YYSYMBOL_T_OP_END = 71,                  /* T_OP_END  */
  YYSYMBOL_T_OP_EMIT = 72,                 /* T_OP_EMIT  */
  YYSYMBOL_T_OP_CUT = 73,                  /* T_OP_CUT  */
  YYSYMBOL_T_OP_CHMASK = 74,               /* T_OP_CHMASK  */
  YYSYMBOL_T_OP_CHSH = 75,                 /* T_OP_CHSH  */
  YYSYMBOL_T_OP_FLOW_REV = 76,             /* T_OP_FLOW_REV  */
  YYSYMBOL_T_OP_BKT = 77,                  /* T_OP_BKT  */
  YYSYMBOL_T_OP_STKS = 78,                 /* T_OP_STKS  */
  YYSYMBOL_T_OP_STKR = 79,                 /* T_OP_STKR  */
  YYSYMBOL_T_OP_XSET = 80,                 /* T_OP_XSET  */
  YYSYMBOL_T_OP_XCLR = 81,                 /* T_OP_XCLR  */
  YYSYMBOL_T_OP_GETLAST = 82,              /* T_OP_GETLAST  */
  YYSYMBOL_T_OP_GETONE = 83,               /* T_OP_GETONE  */
  YYSYMBOL_T_OP_DBG = 84,                  /* T_OP_DBG  */
  YYSYMBOL_T_OP_SHPS = 85,                 /* T_OP_SHPS  */
  YYSYMBOL_T_OP_SHPE = 86,                 /* T_OP_SHPE  */
  YYSYMBOL_T_OP_PREDT = 87,                /* T_OP_PREDT  */
  YYSYMBOL_T_OP_PREDF = 88,                /* T_OP_PREDF  */
  YYSYMBOL_T_OP_PREDE = 89,                /* T_OP_PREDE  */
  YYSYMBOL_T_OP_MOVMSK = 90,               /* T_OP_MOVMSK  */
  YYSYMBOL_T_OP_MOVA1 = 91,                /* T_OP_MOVA1  */
  YYSYMBOL_T_OP_MOVA = 92,                 /* T_OP_MOVA  */
  YYSYMBOL_T_OP_MOV = 93,                  /* T_OP_MOV  */
  YYSYMBOL_T_OP_COV = 94,                  /* T_OP_COV  */
  YYSYMBOL_T_OP_SWZ = 95,                  /* T_OP_SWZ  */
  YYSYMBOL_T_OP_GAT = 96,                  /* T_OP_GAT  */
  YYSYMBOL_T_OP_SCT = 97,                  /* T_OP_SCT  */
  YYSYMBOL_T_OP_MOVS = 98,                 /* T_OP_MOVS  */
  YYSYMBOL_T_OP_ADD_F = 99,                /* T_OP_ADD_F  */
  YYSYMBOL_T_OP_MIN_F = 100,               /* T_OP_MIN_F  */
  YYSYMBOL_T_OP_MAX_F = 101,               /* T_OP_MAX_F  */
  YYSYMBOL_T_OP_MUL_F = 102,               /* T_OP_MUL_F  */
  YYSYMBOL_T_OP_SIGN_F = 103,              /* T_OP_SIGN_F  */
  YYSYMBOL_T_OP_CMPS_F = 104,              /* T_OP_CMPS_F  */
  YYSYMBOL_T_OP_ABSNEG_F = 105,            /* T_OP_ABSNEG_F  */
  YYSYMBOL_T_OP_CMPV_F = 106,              /* T_OP_CMPV_F  */
  YYSYMBOL_T_OP_FLOOR_F = 107,             /* T_OP_FLOOR_F  */
  YYSYMBOL_T_OP_CEIL_F = 108,              /* T_OP_CEIL_F  */
  YYSYMBOL_T_OP_RNDNE_F = 109,             /* T_OP_RNDNE_F  */
  YYSYMBOL_T_OP_RNDAZ_F = 110,             /* T_OP_RNDAZ_F  */
  YYSYMBOL_T_OP_TRUNC_F = 111,             /* T_OP_TRUNC_F  */
  YYSYMBOL_T_OP_ADD_U = 112,               /* T_OP_ADD_U  */
  YYSYMBOL_T_OP_ADD_S = 113,               /* T_OP_ADD_S  */
  YYSYMBOL_T_OP_SUB_U = 114,               /* T_OP_SUB_U  */
  YYSYMBOL_T_OP_SUB_S = 115,               /* T_OP_SUB_S  */
  YYSYMBOL_T_OP_CMPS_U = 116,              /* T_OP_CMPS_U  */
  YYSYMBOL_T_OP_CMPS_S = 117,              /* T_OP_CMPS_S  */
  YYSYMBOL_T_OP_MIN_U = 118,               /* T_OP_MIN_U  */
  YYSYMBOL_T_OP_MIN_S = 119,               /* T_OP_MIN_S  */
  YYSYMBOL_T_OP_MAX_U = 120,               /* T_OP_MAX_U  */
  YYSYMBOL_T_OP_MAX_S = 121,               /* T_OP_MAX_S  */
  YYSYMBOL_T_OP_ABSNEG_S = 122,            /* T_OP_ABSNEG_S  */
  YYSYMBOL_T_OP_AND_B = 123,               /* T_OP_AND_B  */
  YYSYMBOL_T_OP_OR_B = 124,                /* T_OP_OR_B  */
  YYSYMBOL_T_OP_NOT_B = 125,               /* T_OP_NOT_B  */
  YYSYMBOL_T_OP_XOR_B = 126,               /* T_OP_XOR_B  */
  YYSYMBOL_T_OP_CMPV_U = 127,              /* T_OP_CMPV_U  */
  YYSYMBOL_T_OP_CMPV_S = 128,              /* T_OP_CMPV_S  */
  YYSYMBOL_T_OP_MUL_U24 = 129,             /* T_OP_MUL_U24  */
  YYSYMBOL_T_OP_MUL_S24 = 130,             /* T_OP_MUL_S24  */
  YYSYMBOL_T_OP_MULL_U = 131,              /* T_OP_MULL_U  */
  YYSYMBOL_T_OP_BFREV_B = 132,             /* T_OP_BFREV_B  */
  YYSYMBOL_T_OP_CLZ_S = 133,               /* T_OP_CLZ_S  */
  YYSYMBOL_T_OP_CLZ_B = 134,               /* T_OP_CLZ_B  */
  YYSYMBOL_T_OP_SHL_B = 135,               /* T_OP_SHL_B  */
  YYSYMBOL_T_OP_SHR_B = 136,               /* T_OP_SHR_B  */
  YYSYMBOL_T_OP_ASHR_B = 137,              /* T_OP_ASHR_B  */
  YYSYMBOL_T_OP_BARY_F = 138,              /* T_OP_BARY_F  */
  YYSYMBOL_T_OP_FLAT_B = 139,              /* T_OP_FLAT_B  */
  YYSYMBOL_T_OP_MGEN_B = 140,              /* T_OP_MGEN_B  */
  YYSYMBOL_T_OP_GETBIT_B = 141,            /* T_OP_GETBIT_B  */
  YYSYMBOL_T_OP_SETRM = 142,               /* T_OP_SETRM  */
  YYSYMBOL_T_OP_CBITS_B = 143,             /* T_OP_CBITS_B  */
  YYSYMBOL_T_OP_SHB = 144,                 /* T_OP_SHB  */
  YYSYMBOL_T_OP_MSAD = 145,                /* T_OP_MSAD  */
  YYSYMBOL_T_OP_MAD_U16 = 146,             /* T_OP_MAD_U16  */
  YYSYMBOL_T_OP_MADSH_U16 = 147,           /* T_OP_MADSH_U16  */
  YYSYMBOL_T_OP_MAD_S16 = 148,             /* T_OP_MAD_S16  */
  YYSYMBOL_T_OP_MADSH_M16 = 149,           /* T_OP_MADSH_M16  */
  YYSYMBOL_T_OP_MAD_U24 = 150,             /* T_OP_MAD_U24  */
  YYSYMBOL_T_OP_MAD_S24 = 151,             /* T_OP_MAD_S24  */
  YYSYMBOL_T_OP_MAD_F16 = 152,             /* T_OP_MAD_F16  */
  YYSYMBOL_T_OP_MAD_F32 = 153,             /* T_OP_MAD_F32  */
  YYSYMBOL_T_OP_SEL_B16 = 154,             /* T_OP_SEL_B16  */
  YYSYMBOL_T_OP_SEL_B32 = 155,             /* T_OP_SEL_B32  */
  YYSYMBOL_T_OP_SEL_S16 = 156,             /* T_OP_SEL_S16  */
  YYSYMBOL_T_OP_SEL_S32 = 157,             /* T_OP_SEL_S32  */
  YYSYMBOL_T_OP_SEL_F16 = 158,             /* T_OP_SEL_F16  */
  YYSYMBOL_T_OP_SEL_F32 = 159,             /* T_OP_SEL_F32  */
  YYSYMBOL_T_OP_SAD_S16 = 160,             /* T_OP_SAD_S16  */
  YYSYMBOL_T_OP_SAD_S32 = 161,             /* T_OP_SAD_S32  */
  YYSYMBOL_T_OP_SHRM = 162,                /* T_OP_SHRM  */
  YYSYMBOL_T_OP_SHLM = 163,                /* T_OP_SHLM  */
  YYSYMBOL_T_OP_SHRG = 164,                /* T_OP_SHRG  */
  YYSYMBOL_T_OP_SHLG = 165,                /* T_OP_SHLG  */
  YYSYMBOL_T_OP_ANDG = 166,                /* T_OP_ANDG  */
  YYSYMBOL_T_OP_DP2ACC = 167,              /* T_OP_DP2ACC  */
  YYSYMBOL_T_OP_DP4ACC = 168,              /* T_OP_DP4ACC  */
  YYSYMBOL_T_OP_WMM = 169,                 /* T_OP_WMM  */
  YYSYMBOL_T_OP_WMM_ACCU = 170,            /* T_OP_WMM_ACCU  */
  YYSYMBOL_T_OP_RCP = 171,                 /* T_OP_RCP  */
  YYSYMBOL_T_OP_RSQ = 172,                 /* T_OP_RSQ  */
  YYSYMBOL_T_OP_LOG2 = 173,                /* T_OP_LOG2  */
  YYSYMBOL_T_OP_EXP2 = 174,                /* T_OP_EXP2  */
  YYSYMBOL_T_OP_SIN = 175,                 /* T_OP_SIN  */
  YYSYMBOL_T_OP_COS = 176,                 /* T_OP_COS  */
  YYSYMBOL_T_OP_SQRT = 177,                /* T_OP_SQRT  */
  YYSYMBOL_T_OP_HRSQ = 178,                /* T_OP_HRSQ  */
  YYSYMBOL_T_OP_HLOG2 = 179,               /* T_OP_HLOG2  */
  YYSYMBOL_T_OP_HEXP2 = 180,               /* T_OP_HEXP2  */
  YYSYMBOL_T_OP_ISAM = 181,                /* T_OP_ISAM  */
  YYSYMBOL_T_OP_ISAML = 182,               /* T_OP_ISAML  */
  YYSYMBOL_T_OP_ISAMM = 183,               /* T_OP_ISAMM  */
  YYSYMBOL_T_OP_SAM = 184,                 /* T_OP_SAM  */
  YYSYMBOL_T_OP_SAMB = 185,                /* T_OP_SAMB  */
  YYSYMBOL_T_OP_SAML = 186,                /* T_OP_SAML  */
  YYSYMBOL_T_OP_SAMGQ = 187,               /* T_OP_SAMGQ  */
  YYSYMBOL_T_OP_GETLOD = 188,              /* T_OP_GETLOD  */
  YYSYMBOL_T_OP_CONV = 189,                /* T_OP_CONV  */
  YYSYMBOL_T_OP_CONVM = 190,               /* T_OP_CONVM  */
  YYSYMBOL_T_OP_GETSIZE = 191,             /* T_OP_GETSIZE  */
  YYSYMBOL_T_OP_GETBUF = 192,              /* T_OP_GETBUF  */
  YYSYMBOL_T_OP_GETPOS = 193,              /* T_OP_GETPOS  */
  YYSYMBOL_T_OP_GETINFO = 194,             /* T_OP_GETINFO  */
  YYSYMBOL_T_OP_DSX = 195,                 /* T_OP_DSX  */
  YYSYMBOL_T_OP_DSY = 196,                 /* T_OP_DSY  */
  YYSYMBOL_T_OP_GATHER4R = 197,            /* T_OP_GATHER4R  */
  YYSYMBOL_T_OP_GATHER4G = 198,            /* T_OP_GATHER4G  */
  YYSYMBOL_T_OP_GATHER4B = 199,            /* T_OP_GATHER4B  */
  YYSYMBOL_T_OP_GATHER4A = 200,            /* T_OP_GATHER4A  */
  YYSYMBOL_T_OP_SAMGP0 = 201,              /* T_OP_SAMGP0  */
  YYSYMBOL_T_OP_SAMGP1 = 202,              /* T_OP_SAMGP1  */
  YYSYMBOL_T_OP_SAMGP2 = 203,              /* T_OP_SAMGP2  */
  YYSYMBOL_T_OP_SAMGP3 = 204,              /* T_OP_SAMGP3  */
  YYSYMBOL_T_OP_DSXPP_1 = 205,             /* T_OP_DSXPP_1  */
  YYSYMBOL_T_OP_DSYPP_1 = 206,             /* T_OP_DSYPP_1  */
  YYSYMBOL_T_OP_RGETPOS = 207,             /* T_OP_RGETPOS  */
  YYSYMBOL_T_OP_RGETINFO = 208,            /* T_OP_RGETINFO  */
  YYSYMBOL_T_OP_BRCST_A = 209,             /* T_OP_BRCST_A  */
  YYSYMBOL_T_OP_QSHUFFLE_BRCST = 210,      /* T_OP_QSHUFFLE_BRCST  */
  YYSYMBOL_T_OP_QSHUFFLE_H = 211,          /* T_OP_QSHUFFLE_H  */
  YYSYMBOL_T_OP_QSHUFFLE_V = 212,          /* T_OP_QSHUFFLE_V  */
  YYSYMBOL_T_OP_QSHUFFLE_DIAG = 213,       /* T_OP_QSHUFFLE_DIAG  */
  YYSYMBOL_T_OP_TCINV = 214,               /* T_OP_TCINV  */
  YYSYMBOL_T_OP_LDG = 215,                 /* T_OP_LDG  */
  YYSYMBOL_T_OP_LDG_A = 216,               /* T_OP_LDG_A  */
  YYSYMBOL_T_OP_LDG_K = 217,               /* T_OP_LDG_K  */
  YYSYMBOL_T_OP_LDL = 218,                 /* T_OP_LDL  */
  YYSYMBOL_T_OP_LDP = 219,                 /* T_OP_LDP  */
  YYSYMBOL_T_OP_STG = 220,                 /* T_OP_STG  */
  YYSYMBOL_T_OP_STG_A = 221,               /* T_OP_STG_A  */
  YYSYMBOL_T_OP_STL = 222,                 /* T_OP_STL  */
  YYSYMBOL_T_OP_STP = 223,                 /* T_OP_STP  */
  YYSYMBOL_T_OP_LDIB = 224,                /* T_OP_LDIB  */
  YYSYMBOL_T_OP_G2L = 225,                 /* T_OP_G2L  */
  YYSYMBOL_T_OP_L2G = 226,                 /* T_OP_L2G  */
  YYSYMBOL_T_OP_PREFETCH = 227,            /* T_OP_PREFETCH  */
  YYSYMBOL_T_OP_LDLW = 228,                /* T_OP_LDLW  */
  YYSYMBOL_T_OP_STLW = 229,                /* T_OP_STLW  */
  YYSYMBOL_T_OP_RESFMT = 230,              /* T_OP_RESFMT  */
  YYSYMBOL_T_OP_RESINFO = 231,             /* T_OP_RESINFO  */
  YYSYMBOL_T_OP_RESBASE = 232,             /* T_OP_RESBASE  */
  YYSYMBOL_T_OP_ATOMIC_ADD = 233,          /* T_OP_ATOMIC_ADD  */
  YYSYMBOL_T_OP_ATOMIC_SUB = 234,          /* T_OP_ATOMIC_SUB  */
  YYSYMBOL_T_OP_ATOMIC_XCHG = 235,         /* T_OP_ATOMIC_XCHG  */
  YYSYMBOL_T_OP_ATOMIC_INC = 236,          /* T_OP_ATOMIC_INC  */
  YYSYMBOL_T_OP_ATOMIC_DEC = 237,          /* T_OP_ATOMIC_DEC  */
  YYSYMBOL_T_OP_ATOMIC_CMPXCHG = 238,      /* T_OP_ATOMIC_CMPXCHG  */
  YYSYMBOL_T_OP_ATOMIC_MIN = 239,          /* T_OP_ATOMIC_MIN  */
  YYSYMBOL_T_OP_ATOMIC_MAX = 240,          /* T_OP_ATOMIC_MAX  */
  YYSYMBOL_T_OP_ATOMIC_AND = 241,          /* T_OP_ATOMIC_AND  */
  YYSYMBOL_T_OP_ATOMIC_OR = 242,           /* T_OP_ATOMIC_OR  */
  YYSYMBOL_T_OP_ATOMIC_XOR = 243,          /* T_OP_ATOMIC_XOR  */
  YYSYMBOL_T_OP_RESINFO_B = 244,           /* T_OP_RESINFO_B  */
  YYSYMBOL_T_OP_LDIB_B = 245,              /* T_OP_LDIB_B  */
  YYSYMBOL_T_OP_STIB_B = 246,              /* T_OP_STIB_B  */
  YYSYMBOL_T_OP_ATOMIC_B_ADD = 247,        /* T_OP_ATOMIC_B_ADD  */
  YYSYMBOL_T_OP_ATOMIC_B_SUB = 248,        /* T_OP_ATOMIC_B_SUB  */
  YYSYMBOL_T_OP_ATOMIC_B_XCHG = 249,       /* T_OP_ATOMIC_B_XCHG  */
  YYSYMBOL_T_OP_ATOMIC_B_INC = 250,        /* T_OP_ATOMIC_B_INC  */
  YYSYMBOL_T_OP_ATOMIC_B_DEC = 251,        /* T_OP_ATOMIC_B_DEC  */
  YYSYMBOL_T_OP_ATOMIC_B_CMPXCHG = 252,    /* T_OP_ATOMIC_B_CMPXCHG  */
  YYSYMBOL_T_OP_ATOMIC_B_MIN = 253,        /* T_OP_ATOMIC_B_MIN  */
  YYSYMBOL_T_OP_ATOMIC_B_MAX = 254,        /* T_OP_ATOMIC_B_MAX  */
  YYSYMBOL_T_OP_ATOMIC_B_AND = 255,        /* T_OP_ATOMIC_B_AND  */
  YYSYMBOL_T_OP_ATOMIC_B_OR = 256,         /* T_OP_ATOMIC_B_OR  */
  YYSYMBOL_T_OP_ATOMIC_B_XOR = 257,        /* T_OP_ATOMIC_B_XOR  */
  YYSYMBOL_T_OP_ATOMIC_S_ADD = 258,        /* T_OP_ATOMIC_S_ADD  */
  YYSYMBOL_T_OP_ATOMIC_S_SUB = 259,        /* T_OP_ATOMIC_S_SUB  */
  YYSYMBOL_T_OP_ATOMIC_S_XCHG = 260,       /* T_OP_ATOMIC_S_XCHG  */
  YYSYMBOL_T_OP_ATOMIC_S_INC = 261,        /* T_OP_ATOMIC_S_INC  */
  YYSYMBOL_T_OP_ATOMIC_S_DEC = 262,        /* T_OP_ATOMIC_S_DEC  */
  YYSYMBOL_T_OP_ATOMIC_S_CMPXCHG = 263,    /* T_OP_ATOMIC_S_CMPXCHG  */
  YYSYMBOL_T_OP_ATOMIC_S_MIN = 264,        /* T_OP_ATOMIC_S_MIN  */
  YYSYMBOL_T_OP_ATOMIC_S_MAX = 265,        /* T_OP_ATOMIC_S_MAX  */
  YYSYMBOL_T_OP_ATOMIC_S_AND = 266,        /* T_OP_ATOMIC_S_AND  */
  YYSYMBOL_T_OP_ATOMIC_S_OR = 267,         /* T_OP_ATOMIC_S_OR  */
  YYSYMBOL_T_OP_ATOMIC_S_XOR = 268,        /* T_OP_ATOMIC_S_XOR  */
  YYSYMBOL_T_OP_ATOMIC_G_ADD = 269,        /* T_OP_ATOMIC_G_ADD  */
  YYSYMBOL_T_OP_ATOMIC_G_SUB = 270,        /* T_OP_ATOMIC_G_SUB  */
  YYSYMBOL_T_OP_ATOMIC_G_XCHG = 271,       /* T_OP_ATOMIC_G_XCHG  */
  YYSYMBOL_T_OP_ATOMIC_G_INC = 272,        /* T_OP_ATOMIC_G_INC  */
  YYSYMBOL_T_OP_ATOMIC_G_DEC = 273,        /* T_OP_ATOMIC_G_DEC  */
  YYSYMBOL_T_OP_ATOMIC_G_CMPXCHG = 274,    /* T_OP_ATOMIC_G_CMPXCHG  */
  YYSYMBOL_T_OP_ATOMIC_G_MIN = 275,        /* T_OP_ATOMIC_G_MIN  */
  YYSYMBOL_T_OP_ATOMIC_G_MAX = 276,        /* T_OP_ATOMIC_G_MAX  */
  YYSYMBOL_T_OP_ATOMIC_G_AND = 277,        /* T_OP_ATOMIC_G_AND  */
  YYSYMBOL_T_OP_ATOMIC_G_OR = 278,         /* T_OP_ATOMIC_G_OR  */
  YYSYMBOL_T_OP_ATOMIC_G_XOR = 279,        /* T_OP_ATOMIC_G_XOR  */
  YYSYMBOL_T_OP_LDGB = 280,                /* T_OP_LDGB  */
  YYSYMBOL_T_OP_STGB = 281,                /* T_OP_STGB  */
  YYSYMBOL_T_OP_STIB = 282,                /* T_OP_STIB  */
  YYSYMBOL_T_OP_LDC = 283,                 /* T_OP_LDC  */
  YYSYMBOL_T_OP_LDLV = 284,                /* T_OP_LDLV  */
  YYSYMBOL_T_OP_GETSPID = 285,             /* T_OP_GETSPID  */
  YYSYMBOL_T_OP_GETWID = 286,              /* T_OP_GETWID  */
  YYSYMBOL_T_OP_GETFIBERID = 287,          /* T_OP_GETFIBERID  */
  YYSYMBOL_T_OP_STC = 288,                 /* T_OP_STC  */
  YYSYMBOL_T_OP_STSC = 289,                /* T_OP_STSC  */
  YYSYMBOL_T_OP_SHFL = 290,                /* T_OP_SHFL  */
  YYSYMBOL_T_OP_RAY_INTERSECTION = 291,    /* T_OP_RAY_INTERSECTION  */
  YYSYMBOL_T_OP_BAR = 292,                 /* T_OP_BAR  */
  YYSYMBOL_T_OP_FENCE = 293,               /* T_OP_FENCE  */
  YYSYMBOL_T_OP_SLEEP = 294,               /* T_OP_SLEEP  */
  YYSYMBOL_T_OP_ICINV = 295,               /* T_OP_ICINV  */
  YYSYMBOL_T_OP_DCCLN = 296,               /* T_OP_DCCLN  */
  YYSYMBOL_T_OP_DCINV = 297,               /* T_OP_DCINV  */
  YYSYMBOL_T_OP_DCFLU = 298,               /* T_OP_DCFLU  */
  YYSYMBOL_T_OP_CCINV = 299,               /* T_OP_CCINV  */
  YYSYMBOL_T_OP_LOCK = 300,                /* T_OP_LOCK  */
  YYSYMBOL_T_OP_UNLOCK = 301,              /* T_OP_UNLOCK  */
  YYSYMBOL_T_OP_ALIAS = 302,               /* T_OP_ALIAS  */
  YYSYMBOL_T_RAW = 303,                    /* T_RAW  */
  YYSYMBOL_T_OP_PRINT = 304,               /* T_OP_PRINT  */
  YYSYMBOL_T_TYPE_F16 = 305,               /* T_TYPE_F16  */
  YYSYMBOL_T_TYPE_F32 = 306,               /* T_TYPE_F32  */
  YYSYMBOL_T_TYPE_U16 = 307,               /* T_TYPE_U16  */
  YYSYMBOL_T_TYPE_U32 = 308,               /* T_TYPE_U32  */
  YYSYMBOL_T_TYPE_S16 = 309,               /* T_TYPE_S16  */
  YYSYMBOL_T_TYPE_S32 = 310,               /* T_TYPE_S32  */
  YYSYMBOL_T_TYPE_U8 = 311,                /* T_TYPE_U8  */
  YYSYMBOL_T_TYPE_U8_32 = 312,             /* T_TYPE_U8_32  */
  YYSYMBOL_T_TYPE_U64 = 313,               /* T_TYPE_U64  */
  YYSYMBOL_T_TYPE_B16 = 314,               /* T_TYPE_B16  */
  YYSYMBOL_T_TYPE_B32 = 315,               /* T_TYPE_B32  */
  YYSYMBOL_T_UNTYPED = 316,                /* T_UNTYPED  */
  YYSYMBOL_T_TYPED = 317,                  /* T_TYPED  */
  YYSYMBOL_T_MIXED = 318,                  /* T_MIXED  */
  YYSYMBOL_T_UNSIGNED = 319,               /* T_UNSIGNED  */
  YYSYMBOL_T_LOW = 320,                    /* T_LOW  */
  YYSYMBOL_T_HIGH = 321,                   /* T_HIGH  */
  YYSYMBOL_T_1D = 322,                     /* T_1D  */
  YYSYMBOL_T_2D = 323,                     /* T_2D  */
  YYSYMBOL_T_3D = 324,                     /* T_3D  */
  YYSYMBOL_T_4D = 325,                     /* T_4D  */
  YYSYMBOL_T_LT = 326,                     /* T_LT  */
  YYSYMBOL_T_LE = 327,                     /* T_LE  */
  YYSYMBOL_T_GT = 328,                     /* T_GT  */
  YYSYMBOL_T_GE = 329,                     /* T_GE  */
  YYSYMBOL_T_EQ = 330,                     /* T_EQ  */
  YYSYMBOL_T_NE = 331,                     /* T_NE  */
  YYSYMBOL_T_S2EN = 332,                   /* T_S2EN  */
  YYSYMBOL_T_SAMP = 333,                   /* T_SAMP  */
  YYSYMBOL_T_TEX = 334,                    /* T_TEX  */
  YYSYMBOL_T_BASE = 335,                   /* T_BASE  */
  YYSYMBOL_T_OFFSET = 336,                 /* T_OFFSET  */
  YYSYMBOL_T_UNIFORM = 337,                /* T_UNIFORM  */
  YYSYMBOL_T_NONUNIFORM = 338,             /* T_NONUNIFORM  */
  YYSYMBOL_T_IMM = 339,                    /* T_IMM  */
  YYSYMBOL_T_NAN = 340,                    /* T_NAN  */
  YYSYMBOL_T_INF = 341,                    /* T_INF  */
  YYSYMBOL_T_A0 = 342,                     /* T_A0  */
  YYSYMBOL_T_A1 = 343,                     /* T_A1  */
  YYSYMBOL_T_P0 = 344,                     /* T_P0  */
  YYSYMBOL_T_W = 345,                      /* T_W  */
  YYSYMBOL_T_CAT1_TYPE_TYPE = 346,         /* T_CAT1_TYPE_TYPE  */
  YYSYMBOL_T_MOD_TEX = 347,                /* T_MOD_TEX  */
  YYSYMBOL_T_MOD_MEM = 348,                /* T_MOD_MEM  */
  YYSYMBOL_T_MOD_RT = 349,                 /* T_MOD_RT  */
  YYSYMBOL_T_MOD_XOR = 350,                /* T_MOD_XOR  */
  YYSYMBOL_T_MOD_UP = 351,                 /* T_MOD_UP  */
  YYSYMBOL_T_MOD_DOWN = 352,               /* T_MOD_DOWN  */
  YYSYMBOL_T_MOD_RUP = 353,                /* T_MOD_RUP  */
  YYSYMBOL_T_MOD_RDOWN = 354,              /* T_MOD_RDOWN  */
  YYSYMBOL_355_ = 355,                     /* '-'  */
  YYSYMBOL_356_ = 356,                     /* ','  */
  YYSYMBOL_357_ = 357,                     /* '('  */
  YYSYMBOL_358_ = 358,                     /* ')'  */
  YYSYMBOL_359_ = 359,                     /* '='  */
  YYSYMBOL_360_ = 360,                     /* ':'  */
  YYSYMBOL_361_ = 361,                     /* '!'  */
  YYSYMBOL_362_ = 362,                     /* '#'  */
  YYSYMBOL_363_ = 363,                     /* '.'  */
  YYSYMBOL_364_a_ = 364,                   /* 'a'  */
  YYSYMBOL_365_o_ = 365,                   /* 'o'  */
  YYSYMBOL_366_p_ = 366,                   /* 'p'  */
  YYSYMBOL_367_s_ = 367,                   /* 's'  */
  YYSYMBOL_368_v_ = 368,                   /* 'v'  */
  YYSYMBOL_369_ = 369,                     /* '+'  */
  YYSYMBOL_370_ = 370,                     /* '<'  */
  YYSYMBOL_371_g_ = 371,                   /* 'g'  */
  YYSYMBOL_372_ = 372,                     /* '['  */
  YYSYMBOL_373_ = 373,                     /* ']'  */
  YYSYMBOL_374_c_ = 374,                   /* 'c'  */
  YYSYMBOL_375_l_ = 375,                   /* 'l'  */
  YYSYMBOL_376_u_ = 376,                   /* 'u'  */
  YYSYMBOL_377_k_ = 377,                   /* 'k'  */
  YYSYMBOL_378_w_ = 378,                   /* 'w'  */
  YYSYMBOL_379_r_ = 379,                   /* 'r'  */
  YYSYMBOL_380_ = 380,                     /* '>'  */
  YYSYMBOL_381_h_ = 381,                   /* 'h'  */
  YYSYMBOL_YYACCEPT = 382,                 /* $accept  */
  YYSYMBOL_shader = 383,                   /* shader  */
  YYSYMBOL_384_1 = 384,                    /* $@1  */
  YYSYMBOL_headers = 385,                  /* headers  */
  YYSYMBOL_header = 386,                   /* header  */
  YYSYMBOL_const_val = 387,                /* const_val  */
  YYSYMBOL_localsize_header = 388,         /* localsize_header  */
  YYSYMBOL_const_header = 389,             /* const_header  */
  YYSYMBOL_buf_header_init_val = 390,      /* buf_header_init_val  */
  YYSYMBOL_buf_header_init_vals = 391,     /* buf_header_init_vals  */
  YYSYMBOL_buf_header_addr_reg = 392,      /* buf_header_addr_reg  */
  YYSYMBOL_buf_header = 393,               /* buf_header  */
  YYSYMBOL_394_2 = 394,                    /* $@2  */
  YYSYMBOL_invocationid_header = 395,      /* invocationid_header  */
  YYSYMBOL_wgid_header = 396,              /* wgid_header  */
  YYSYMBOL_numwg_header = 397,             /* numwg_header  */
  YYSYMBOL_branchstack_header = 398,       /* branchstack_header  */
  YYSYMBOL_pvtmem_header = 399,            /* pvtmem_header  */
  YYSYMBOL_localmem_header = 400,          /* localmem_header  */
  YYSYMBOL_earlypreamble_header = 401,     /* earlypreamble_header  */
  YYSYMBOL_in_header = 402,                /* in_header  */
  YYSYMBOL_out_header = 403,               /* out_header  */
  YYSYMBOL_tex_header_opc = 404,           /* tex_header_opc  */
  YYSYMBOL_tex_header = 405,               /* tex_header  */
  YYSYMBOL_fullnop_start_section = 406,    /* fullnop_start_section  */
  YYSYMBOL_fullnop_end_section = 407,      /* fullnop_end_section  */
  YYSYMBOL_fullsync_start_section = 408,   /* fullsync_start_section  */
  YYSYMBOL_fullsync_end_section = 409,     /* fullsync_end_section  */
  YYSYMBOL_iflag = 410,                    /* iflag  */
  YYSYMBOL_iflags = 411,                   /* iflags  */
  YYSYMBOL_instrs = 412,                   /* instrs  */
  YYSYMBOL_instr = 413,                    /* instr  */
  YYSYMBOL_label = 414,                    /* label  */
  YYSYMBOL_cat0_src1 = 415,                /* cat0_src1  */
  YYSYMBOL_cat0_src2 = 416,                /* cat0_src2  */
  YYSYMBOL_cat0_immed = 417,               /* cat0_immed  */
  YYSYMBOL_cat0_instr = 418,               /* cat0_instr  */
  YYSYMBOL_419_3 = 419,                    /* $@3  */
  YYSYMBOL_420_4 = 420,                    /* $@4  */
  YYSYMBOL_421_5 = 421,                    /* $@5  */
  YYSYMBOL_422_6 = 422,                    /* $@6  */
  YYSYMBOL_423_7 = 423,                    /* $@7  */
  YYSYMBOL_424_8 = 424,                    /* $@8  */
  YYSYMBOL_425_9 = 425,                    /* $@9  */
  YYSYMBOL_426_10 = 426,                   /* $@10  */
  YYSYMBOL_427_11 = 427,                   /* $@11  */
  YYSYMBOL_428_12 = 428,                   /* $@12  */
  YYSYMBOL_429_13 = 429,                   /* $@13  */
  YYSYMBOL_430_14 = 430,                   /* $@14  */
  YYSYMBOL_431_15 = 431,                   /* $@15  */
  YYSYMBOL_432_16 = 432,                   /* $@16  */
  YYSYMBOL_cat1_opc = 433,                 /* cat1_opc  */
  YYSYMBOL_cat1_src = 434,                 /* cat1_src  */
  YYSYMBOL_cat1_movmsk = 435,              /* cat1_movmsk  */
  YYSYMBOL_436_17 = 436,                   /* $@17  */
  YYSYMBOL_mova_src = 437,                 /* mova_src  */
  YYSYMBOL_cat1_mova1 = 438,               /* cat1_mova1  */
  YYSYMBOL_439_18 = 439,                   /* $@18  */
  YYSYMBOL_cat1_mova = 440,                /* cat1_mova  */
  YYSYMBOL_441_19 = 441,                   /* $@19  */
  YYSYMBOL_cat1_swz = 442,                 /* cat1_swz  */
  YYSYMBOL_443_20 = 443,                   /* $@20  */
  YYSYMBOL_cat1_gat = 444,                 /* cat1_gat  */
  YYSYMBOL_445_21 = 445,                   /* $@21  */
  YYSYMBOL_cat1_sct = 446,                 /* cat1_sct  */
  YYSYMBOL_447_22 = 447,                   /* $@22  */
  YYSYMBOL_movs_invocation = 448,          /* movs_invocation  */
  YYSYMBOL_cat1_movs = 449,                /* cat1_movs  */
  YYSYMBOL_450_23 = 450,                   /* $@23  */
  YYSYMBOL_cat1_instr = 451,               /* cat1_instr  */
  YYSYMBOL_cat2_opc_1src = 452,            /* cat2_opc_1src  */
  YYSYMBOL_cat2_opc_2src_cnd = 453,        /* cat2_opc_2src_cnd  */
  YYSYMBOL_cat2_opc_2src = 454,            /* cat2_opc_2src  */
  YYSYMBOL_cond = 455,                     /* cond  */
  YYSYMBOL_cat2_instr = 456,               /* cat2_instr  */
  YYSYMBOL_cat3_dp_signedness = 457,       /* cat3_dp_signedness  */
  YYSYMBOL_cat3_dp_pack = 458,             /* cat3_dp_pack  */
  YYSYMBOL_cat3_opc = 459,                 /* cat3_opc  */
  YYSYMBOL_cat3_imm_reg_opc = 460,         /* cat3_imm_reg_opc  */
  YYSYMBOL_cat3_wmm = 461,                 /* cat3_wmm  */
  YYSYMBOL_cat3_dp = 462,                  /* cat3_dp  */
  YYSYMBOL_cat3_instr = 463,               /* cat3_instr  */
  YYSYMBOL_cat4_opc = 464,                 /* cat4_opc  */
  YYSYMBOL_cat4_instr = 465,               /* cat4_instr  */
  YYSYMBOL_cat5_opc_dsxypp = 466,          /* cat5_opc_dsxypp  */
  YYSYMBOL_cat5_opc_isam = 467,            /* cat5_opc_isam  */
  YYSYMBOL_cat5_opc = 468,                 /* cat5_opc  */
  YYSYMBOL_cat5_flag = 469,                /* cat5_flag  */
  YYSYMBOL_cat5_flags = 470,               /* cat5_flags  */
  YYSYMBOL_cat5_samp = 471,                /* cat5_samp  */
  YYSYMBOL_cat5_tex = 472,                 /* cat5_tex  */
  YYSYMBOL_cat5_type = 473,                /* cat5_type  */
  YYSYMBOL_cat5_a1 = 474,                  /* cat5_a1  */
  YYSYMBOL_cat5_samp_tex = 475,            /* cat5_samp_tex  */
  YYSYMBOL_cat5_samp_tex_all = 476,        /* cat5_samp_tex_all  */
  YYSYMBOL_cat5_instr = 477,               /* cat5_instr  */
  YYSYMBOL_cat6_typed = 478,               /* cat6_typed  */
  YYSYMBOL_cat6_dim = 479,                 /* cat6_dim  */
  YYSYMBOL_cat6_type = 480,                /* cat6_type  */
  YYSYMBOL_cat6_imm_offset = 481,          /* cat6_imm_offset  */
  YYSYMBOL_cat6_offset = 482,              /* cat6_offset  */
  YYSYMBOL_cat6_dst_offset = 483,          /* cat6_dst_offset  */
  YYSYMBOL_cat6_immed = 484,               /* cat6_immed  */
  YYSYMBOL_cat6_src_shift = 485,           /* cat6_src_shift  */
  YYSYMBOL_cat6_a6xx_global_address_pt2 = 486, /* cat6_a6xx_global_address_pt2  */
  YYSYMBOL_cat6_a6xx_global_address = 487, /* cat6_a6xx_global_address  */
  YYSYMBOL_cat6_load = 488,                /* cat6_load  */
  YYSYMBOL_489_24 = 489,                   /* $@24  */
  YYSYMBOL_490_25 = 490,                   /* $@25  */
  YYSYMBOL_491_26 = 491,                   /* $@26  */
  YYSYMBOL_492_27 = 492,                   /* $@27  */
  YYSYMBOL_493_28 = 493,                   /* $@28  */
  YYSYMBOL_494_29 = 494,                   /* $@29  */
  YYSYMBOL_495_30 = 495,                   /* $@30  */
  YYSYMBOL_496_31 = 496,                   /* $@31  */
  YYSYMBOL_cat6_store = 497,               /* cat6_store  */
  YYSYMBOL_498_32 = 498,                   /* $@32  */
  YYSYMBOL_499_33 = 499,                   /* $@33  */
  YYSYMBOL_500_34 = 500,                   /* $@34  */
  YYSYMBOL_501_35 = 501,                   /* $@35  */
  YYSYMBOL_502_36 = 502,                   /* $@36  */
  YYSYMBOL_cat6_loadib = 503,              /* cat6_loadib  */
  YYSYMBOL_504_37 = 504,                   /* $@37  */
  YYSYMBOL_cat6_storeib = 505,             /* cat6_storeib  */
  YYSYMBOL_506_38 = 506,                   /* $@38  */
  YYSYMBOL_cat6_prefetch = 507,            /* cat6_prefetch  */
  YYSYMBOL_508_39 = 508,                   /* $@39  */
  YYSYMBOL_cat6_atomic_opc = 509,          /* cat6_atomic_opc  */
  YYSYMBOL_cat6_a3xx_atomic_opc = 510,     /* cat6_a3xx_atomic_opc  */
  YYSYMBOL_cat6_a6xx_atomic_opc = 511,     /* cat6_a6xx_atomic_opc  */
  YYSYMBOL_cat6_a3xx_atomic_s = 512,       /* cat6_a3xx_atomic_s  */
  YYSYMBOL_cat6_a6xx_atomic_g = 513,       /* cat6_a6xx_atomic_g  */
  YYSYMBOL_cat6_atomic_l = 514,            /* cat6_atomic_l  */
  YYSYMBOL_cat6_atomic = 515,              /* cat6_atomic  */
  YYSYMBOL_cat6_ibo_opc_1src = 516,        /* cat6_ibo_opc_1src  */
  YYSYMBOL_cat6_ibo_opc_ldgb = 517,        /* cat6_ibo_opc_ldgb  */
  YYSYMBOL_cat6_ibo_opc_stgb = 518,        /* cat6_ibo_opc_stgb  */
  YYSYMBOL_cat6_ibo = 519,                 /* cat6_ibo  */
  YYSYMBOL_520_40 = 520,                   /* $@40  */
  YYSYMBOL_cat6_id_opc = 521,              /* cat6_id_opc  */
  YYSYMBOL_cat6_id = 522,                  /* cat6_id  */
  YYSYMBOL_cat6_bindless_base = 523,       /* cat6_bindless_base  */
  YYSYMBOL_cat6_bindless_mode = 524,       /* cat6_bindless_mode  */
  YYSYMBOL_cat6_reg_or_immed = 525,        /* cat6_reg_or_immed  */
  YYSYMBOL_cat6_bindless_ibo_opc_1src = 526, /* cat6_bindless_ibo_opc_1src  */
  YYSYMBOL_cat6_bindless_ibo_opc_2src = 527, /* cat6_bindless_ibo_opc_2src  */
  YYSYMBOL_cat6_bindless_ibo_opc_3src = 528, /* cat6_bindless_ibo_opc_3src  */
  YYSYMBOL_cat6_bindless_ibo_opc_3src_dst = 529, /* cat6_bindless_ibo_opc_3src_dst  */
  YYSYMBOL_cat6_bindless_ibo = 530,        /* cat6_bindless_ibo  */
  YYSYMBOL_cat6_bindless_ldc_opc = 531,    /* cat6_bindless_ldc_opc  */
  YYSYMBOL_cat6_bindless_ldc_middle = 532, /* cat6_bindless_ldc_middle  */
  YYSYMBOL_cat6_bindless_ldc = 533,        /* cat6_bindless_ldc  */
  YYSYMBOL_const_dst = 534,                /* const_dst  */
  YYSYMBOL_cat6_stc = 535,                 /* cat6_stc  */
  YYSYMBOL_536_41 = 536,                   /* $@41  */
  YYSYMBOL_537_42 = 537,                   /* $@42  */
  YYSYMBOL_cat6_shfl_mode = 538,           /* cat6_shfl_mode  */
  YYSYMBOL_cat6_shfl = 539,                /* cat6_shfl  */
  YYSYMBOL_540_43 = 540,                   /* $@43  */
  YYSYMBOL_cat6_ray_intersection = 541,    /* cat6_ray_intersection  */
  YYSYMBOL_542_44 = 542,                   /* $@44  */
  YYSYMBOL_cat6_todo = 543,                /* cat6_todo  */
  YYSYMBOL_cat6_instr = 544,               /* cat6_instr  */
  YYSYMBOL_cat7_scope = 545,               /* cat7_scope  */
  YYSYMBOL_cat7_scopes = 546,              /* cat7_scopes  */
  YYSYMBOL_cat7_barrier = 547,             /* cat7_barrier  */
  YYSYMBOL_548_45 = 548,                   /* $@45  */
  YYSYMBOL_549_46 = 549,                   /* $@46  */
  YYSYMBOL_cat7_data_cache = 550,          /* cat7_data_cache  */
  YYSYMBOL_cat7_alias_dst = 551,           /* cat7_alias_dst  */
  YYSYMBOL_cat7_alias_src = 552,           /* cat7_alias_src  */
  YYSYMBOL_cat7_alias_scope = 553,         /* cat7_alias_scope  */
  YYSYMBOL_cat7_alias_int_type = 554,      /* cat7_alias_int_type  */
  YYSYMBOL_cat7_alias_float_type = 555,    /* cat7_alias_float_type  */
  YYSYMBOL_cat7_alias_type = 556,          /* cat7_alias_type  */
  YYSYMBOL_cat7_alias_table_size_minus_one = 557, /* cat7_alias_table_size_minus_one  */
  YYSYMBOL_cat7_instr = 558,               /* cat7_instr  */
  YYSYMBOL_559_47 = 559,                   /* $@47  */
  YYSYMBOL_raw_instr = 560,                /* raw_instr  */
  YYSYMBOL_meta_print_regs = 561,          /* meta_print_regs  */
  YYSYMBOL_meta_print_reg = 562,           /* meta_print_reg  */
  YYSYMBOL_meta_print_start = 563,         /* meta_print_start  */
  YYSYMBOL_meta_print = 564,               /* meta_print  */
  YYSYMBOL_src_gpr = 565,                  /* src_gpr  */
  YYSYMBOL_src_a0 = 566,                   /* src_a0  */
  YYSYMBOL_src_a1 = 567,                   /* src_a1  */
  YYSYMBOL_src_p0 = 568,                   /* src_p0  */
  YYSYMBOL_src = 569,                      /* src  */
  YYSYMBOL_dst = 570,                      /* dst  */
  YYSYMBOL_const = 571,                    /* const  */
  YYSYMBOL_dst_reg_flag = 572,             /* dst_reg_flag  */
  YYSYMBOL_dst_reg_flags = 573,            /* dst_reg_flags  */
  YYSYMBOL_dst_reg = 574,                  /* dst_reg  */
  YYSYMBOL_src_reg_flag = 575,             /* src_reg_flag  */
  YYSYMBOL_src_reg_flags = 576,            /* src_reg_flags  */
  YYSYMBOL_src_reg = 577,                  /* src_reg  */
  YYSYMBOL_src_reg_gpr = 578,              /* src_reg_gpr  */
  YYSYMBOL_src_const = 579,                /* src_const  */
  YYSYMBOL_src_reg_or_const = 580,         /* src_reg_or_const  */
  YYSYMBOL_src_reg_or_const_or_rel = 581,  /* src_reg_or_const_or_rel  */
  YYSYMBOL_src_reg_or_const_or_rel_or_imm = 582, /* src_reg_or_const_or_rel_or_imm  */
  YYSYMBOL_src_reg_or_rel_or_imm = 583,    /* src_reg_or_rel_or_imm  */
  YYSYMBOL_uoffset = 584,                  /* uoffset  */
  YYSYMBOL_offset = 585,                   /* offset  */
  YYSYMBOL_src_uoffset = 586,              /* src_uoffset  */
  YYSYMBOL_relative_gpr_src = 587,         /* relative_gpr_src  */
  YYSYMBOL_relative_gpr_dst = 588,         /* relative_gpr_dst  */
  YYSYMBOL_relative_const = 589,           /* relative_const  */
  YYSYMBOL_relative = 590,                 /* relative  */
  YYSYMBOL_immediate_cat1 = 591,           /* immediate_cat1  */
  YYSYMBOL_immediate = 592,                /* immediate  */
  YYSYMBOL_flut_immed = 593,               /* flut_immed  */
  YYSYMBOL_uinteger = 594,                 /* uinteger  */
  YYSYMBOL_integer = 595,                  /* integer  */
  YYSYMBOL_float = 596,                    /* float  */
  YYSYMBOL_type = 597                      /* type  */
};
typedef enum yysymbol_kind_t yysymbol_kind_t;


/* Second part of user prologue.  */
#line 383 "../src/freedreno/ir3/ir3_parser.y"

#if YYDEBUG
static void print_token(FILE *file, int type, YYSTYPE value)
{
	fprintf(file, "\ntype: %d\n", type);
}

#define YYPRINT(file, type, value) print_token(file, type, value)
#endif

#line 1056 "src/freedreno/ir3/ir3_parser.c"


#ifdef short
# undef short
#endif

/* On compilers that do not define __PTRDIFF_MAX__ etc., make sure
   <limits.h> and (if available) <stdint.h> are included
   so that the code can choose integer types of a good width.  */

#ifndef __PTRDIFF_MAX__
# include <limits.h> /* INFRINGES ON USER NAME SPACE */
# if defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stdint.h> /* INFRINGES ON USER NAME SPACE */
#  define YY_STDINT_H
# endif
#endif

/* Narrow types that promote to a signed type and that can represent a
   signed or unsigned integer of at least N bits.  In tables they can
   save space and decrease cache pressure.  Promoting to a signed type
   helps avoid bugs in integer arithmetic.  */

#ifdef __INT_LEAST8_MAX__
typedef __INT_LEAST8_TYPE__ yytype_int8;
#elif defined YY_STDINT_H
typedef int_least8_t yytype_int8;
#else
typedef signed char yytype_int8;
#endif

#ifdef __INT_LEAST16_MAX__
typedef __INT_LEAST16_TYPE__ yytype_int16;
#elif defined YY_STDINT_H
typedef int_least16_t yytype_int16;
#else
typedef short yytype_int16;
#endif

/* Work around bug in HP-UX 11.23, which defines these macros
   incorrectly for preprocessor constants.  This workaround can likely
   be removed in 2023, as HPE has promised support for HP-UX 11.23
   (aka HP-UX 11i v2) only through the end of 2022; see Table 2 of
   <https://h20195.www2.hpe.com/V2/getpdf.aspx/4AA4-7673ENW.pdf>.  */
#ifdef __hpux
# undef UINT_LEAST8_MAX
# undef UINT_LEAST16_MAX
# define UINT_LEAST8_MAX 255
# define UINT_LEAST16_MAX 65535
#endif

#if defined __UINT_LEAST8_MAX__ && __UINT_LEAST8_MAX__ <= __INT_MAX__
typedef __UINT_LEAST8_TYPE__ yytype_uint8;
#elif (!defined __UINT_LEAST8_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST8_MAX <= INT_MAX)
typedef uint_least8_t yytype_uint8;
#elif !defined __UINT_LEAST8_MAX__ && UCHAR_MAX <= INT_MAX
typedef unsigned char yytype_uint8;
#else
typedef short yytype_uint8;
#endif

#if defined __UINT_LEAST16_MAX__ && __UINT_LEAST16_MAX__ <= __INT_MAX__
typedef __UINT_LEAST16_TYPE__ yytype_uint16;
#elif (!defined __UINT_LEAST16_MAX__ && defined YY_STDINT_H \
       && UINT_LEAST16_MAX <= INT_MAX)
typedef uint_least16_t yytype_uint16;
#elif !defined __UINT_LEAST16_MAX__ && USHRT_MAX <= INT_MAX
typedef unsigned short yytype_uint16;
#else
typedef int yytype_uint16;
#endif

#ifndef YYPTRDIFF_T
# if defined __PTRDIFF_TYPE__ && defined __PTRDIFF_MAX__
#  define YYPTRDIFF_T __PTRDIFF_TYPE__
#  define YYPTRDIFF_MAXIMUM __PTRDIFF_MAX__
# elif defined PTRDIFF_MAX
#  ifndef ptrdiff_t
#   include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  endif
#  define YYPTRDIFF_T ptrdiff_t
#  define YYPTRDIFF_MAXIMUM PTRDIFF_MAX
# else
#  define YYPTRDIFF_T long
#  define YYPTRDIFF_MAXIMUM LONG_MAX
# endif
#endif

#ifndef YYSIZE_T
# ifdef __SIZE_TYPE__
#  define YYSIZE_T __SIZE_TYPE__
# elif defined size_t
#  define YYSIZE_T size_t
# elif defined __STDC_VERSION__ && 199901 <= __STDC_VERSION__
#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
#  define YYSIZE_T size_t
# else
#  define YYSIZE_T unsigned
# endif
#endif

#define YYSIZE_MAXIMUM                                  \
  YY_CAST (YYPTRDIFF_T,                                 \
           (YYPTRDIFF_MAXIMUM < YY_CAST (YYSIZE_T, -1)  \
            ? YYPTRDIFF_MAXIMUM                         \
            : YY_CAST (YYSIZE_T, -1)))

#define YYSIZEOF(X) YY_CAST (YYPTRDIFF_T, sizeof (X))


/* Stored state numbers (used for stacks). */
typedef yytype_int16 yy_state_t;

/* State numbers in computations.  */
typedef int yy_state_fast_t;

#ifndef YY_
# if defined YYENABLE_NLS && YYENABLE_NLS
#  if ENABLE_NLS
#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
#   define YY_(Msgid) dgettext ("bison-runtime", Msgid)
#  endif
# endif
# ifndef YY_
#  define YY_(Msgid) Msgid
# endif
#endif


#ifndef YY_ATTRIBUTE_PURE
# if defined __GNUC__ && 2 < __GNUC__ + (96 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_PURE __attribute__ ((__pure__))
# else
#  define YY_ATTRIBUTE_PURE
# endif
#endif

#ifndef YY_ATTRIBUTE_UNUSED
# if defined __GNUC__ && 2 < __GNUC__ + (7 <= __GNUC_MINOR__)
#  define YY_ATTRIBUTE_UNUSED __attribute__ ((__unused__))
# else
#  define YY_ATTRIBUTE_UNUSED
# endif
#endif

/* Suppress unused-variable warnings by "using" E.  */
#if ! defined lint || defined __GNUC__
# define YY_USE(E) ((void) (E))
#else
# define YY_USE(E) /* empty */
#endif

/* Suppress an incorrect diagnostic about yylval being uninitialized.  */
#if defined __GNUC__ && ! defined __ICC && 406 <= __GNUC__ * 100 + __GNUC_MINOR__
# if __GNUC__ * 100 + __GNUC_MINOR__ < 407
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")
# else
#  define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN                           \
    _Pragma ("GCC diagnostic push")                                     \
    _Pragma ("GCC diagnostic ignored \"-Wuninitialized\"")              \
    _Pragma ("GCC diagnostic ignored \"-Wmaybe-uninitialized\"")
# endif
# define YY_IGNORE_MAYBE_UNINITIALIZED_END      \
    _Pragma ("GCC diagnostic pop")
#else
# define YY_INITIAL_VALUE(Value) Value
#endif
#ifndef YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
# define YY_IGNORE_MAYBE_UNINITIALIZED_END
#endif
#ifndef YY_INITIAL_VALUE
# define YY_INITIAL_VALUE(Value) /* Nothing. */
#endif

#if defined __cplusplus && defined __GNUC__ && ! defined __ICC && 6 <= __GNUC__
# define YY_IGNORE_USELESS_CAST_BEGIN                          \
    _Pragma ("GCC diagnostic push")                            \
    _Pragma ("GCC diagnostic ignored \"-Wuseless-cast\"")
# define YY_IGNORE_USELESS_CAST_END            \
    _Pragma ("GCC diagnostic pop")
#endif
#ifndef YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_BEGIN
# define YY_IGNORE_USELESS_CAST_END
#endif


#define YY_ASSERT(E) ((void) (0 && (E)))

#if 1

/* The parser invokes alloca or malloc; define the necessary symbols.  */

# ifdef YYSTACK_USE_ALLOCA
#  if YYSTACK_USE_ALLOCA
#   ifdef __GNUC__
#    define YYSTACK_ALLOC __builtin_alloca
#   elif defined __BUILTIN_VA_ARG_INCR
#    include <alloca.h> /* INFRINGES ON USER NAME SPACE */
#   elif defined _AIX
#    define YYSTACK_ALLOC __alloca
#   elif defined _MSC_VER
#    include <malloc.h> /* INFRINGES ON USER NAME SPACE */
#    define alloca _alloca
#   else
#    define YYSTACK_ALLOC alloca
#    if ! defined _ALLOCA_H && ! defined EXIT_SUCCESS
#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
      /* Use EXIT_SUCCESS as a witness for stdlib.h.  */
#     ifndef EXIT_SUCCESS
#      define EXIT_SUCCESS 0
#     endif
#    endif
#   endif
#  endif
# endif

# ifdef YYSTACK_ALLOC
   /* Pacify GCC's 'empty if-body' warning.  */
#  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
#  ifndef YYSTACK_ALLOC_MAXIMUM
    /* The OS might guarantee only one guard page at the bottom of the stack,
       and a page size can be as small as 4096 bytes.  So we cannot safely
       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
       to allow for a few compiler-allocated temporary stack slots.  */
#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2006 */
#  endif
# else
#  define YYSTACK_ALLOC YYMALLOC
#  define YYSTACK_FREE YYFREE
#  ifndef YYSTACK_ALLOC_MAXIMUM
#   define YYSTACK_ALLOC_MAXIMUM YYSIZE_MAXIMUM
#  endif
#  if (defined __cplusplus && ! defined EXIT_SUCCESS \
       && ! ((defined YYMALLOC || defined malloc) \
             && (defined YYFREE || defined free)))
#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
#   ifndef EXIT_SUCCESS
#    define EXIT_SUCCESS 0
#   endif
#  endif
#  ifndef YYMALLOC
#   define YYMALLOC malloc
#   if ! defined malloc && ! defined EXIT_SUCCESS
void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
#  ifndef YYFREE
#   define YYFREE free
#   if ! defined free && ! defined EXIT_SUCCESS
void free (void *); /* INFRINGES ON USER NAME SPACE */
#   endif
#  endif
# endif
#endif /* 1 */

#if (! defined yyoverflow \
     && (! defined __cplusplus \
         || (defined YYSTYPE_IS_TRIVIAL && YYSTYPE_IS_TRIVIAL)))

/* A type that is properly aligned for any stack member.  */
union yyalloc
{
  yy_state_t yyss_alloc;
  YYSTYPE yyvs_alloc;
};

/* The size of the maximum gap between one aligned stack and the next.  */
# define YYSTACK_GAP_MAXIMUM (YYSIZEOF (union yyalloc) - 1)

/* The size of an array large to enough to hold all stacks, each with
   N elements.  */
# define YYSTACK_BYTES(N) \
     ((N) * (YYSIZEOF (yy_state_t) + YYSIZEOF (YYSTYPE)) \
      + YYSTACK_GAP_MAXIMUM)

# define YYCOPY_NEEDED 1

/* Relocate STACK from its old location to the new one.  The
   local variables YYSIZE and YYSTACKSIZE give the old and new number of
   elements in the stack, and YYPTR gives the new location of the
   stack.  Advance YYPTR to a properly aligned location for the next
   stack.  */
# define YYSTACK_RELOCATE(Stack_alloc, Stack)                           \
    do                                                                  \
      {                                                                 \
        YYPTRDIFF_T yynewbytes;                                         \
        YYCOPY (&yyptr->Stack_alloc, Stack, yysize);                    \
        Stack = &yyptr->Stack_alloc;                                    \
        yynewbytes = yystacksize * YYSIZEOF (*Stack) + YYSTACK_GAP_MAXIMUM; \
        yyptr += yynewbytes / YYSIZEOF (*yyptr);                        \
      }                                                                 \
    while (0)

#endif

#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from SRC to DST.  The source and destination do
   not overlap.  */
# ifndef YYCOPY
#  if defined __GNUC__ && 1 < __GNUC__
#   define YYCOPY(Dst, Src, Count) \
      __builtin_memcpy (Dst, Src, YY_CAST (YYSIZE_T, (Count)) * sizeof (*(Src)))
#  else
#   define YYCOPY(Dst, Src, Count)              \
      do                                        \
        {                                       \
          YYPTRDIFF_T yyi;                      \
          for (yyi = 0; yyi < (Count); yyi++)   \
            (Dst)[yyi] = (Src)[yyi];            \
        }                                       \
      while (0)
#  endif
# endif
#endif /* !YYCOPY_NEEDED */

/* YYFINAL -- State number of the termination state.  */
#define YYFINAL  3
/* YYLAST -- Last index in YYTABLE.  */
#define YYLAST   1800

/* YYNTOKENS -- Number of terminals.  */
#define YYNTOKENS  382
/* YYNNTS -- Number of nonterminals.  */
#define YYNNTS  216
/* YYNRULES -- Number of rules.  */
#define YYNRULES  637
/* YYNSTATES -- Number of states.  */
#define YYNSTATES  1348

/* YYMAXUTOK -- Last valid token kind.  */
#define YYMAXUTOK   609


/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex, with out-of-bounds checking.  */
#define YYTRANSLATE(YYX)                                \
  (0 <= (YYX) && (YYX) <= YYMAXUTOK                     \
   ? YY_CAST (yysymbol_kind_t, yytranslate[YYX])        \
   : YYSYMBOL_YYUNDEF)

/* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
   as returned by yylex.  */
static const yytype_int16 yytranslate[] =
{
       0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,   361,     2,   362,     2,     2,     2,     2,
     357,   358,     2,   369,   356,   355,   363,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,   360,     2,
     370,   359,   380,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,   372,     2,   373,     2,     2,     2,   364,     2,   374,
       2,     2,     2,   371,   381,     2,     2,   377,   375,     2,
       2,   365,   366,     2,   379,   367,     2,   376,   368,   378,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     2,     2,     1,     2,     3,     4,
       5,     6,     7,     8,     9,    10,    11,    12,    13,    14,
      15,    16,    17,    18,    19,    20,    21,    22,    23,    24,
      25,    26,    27,    28,    29,    30,    31,    32,    33,    34,
      35,    36,    37,    38,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    51,    52,    53,    54,
      55,    56,    57,    58,    59,    60,    61,    62,    63,    64,
      65,    66,    67,    68,    69,    70,    71,    72,    73,    74,
      75,    76,    77,    78,    79,    80,    81,    82,    83,    84,
      85,    86,    87,    88,    89,    90,    91,    92,    93,    94,
      95,    96,    97,    98,    99,   100,   101,   102,   103,   104,
     105,   106,   107,   108,   109,   110,   111,   112,   113,   114,
     115,   116,   117,   118,   119,   120,   121,   122,   123,   124,
     125,   126,   127,   128,   129,   130,   131,   132,   133,   134,
     135,   136,   137,   138,   139,   140,   141,   142,   143,   144,
     145,   146,   147,   148,   149,   150,   151,   152,   153,   154,
     155,   156,   157,   158,   159,   160,   161,   162,   163,   164,
     165,   166,   167,   168,   169,   170,   171,   172,   173,   174,
     175,   176,   177,   178,   179,   180,   181,   182,   183,   184,
     185,   186,   187,   188,   189,   190,   191,   192,   193,   194,
     195,   196,   197,   198,   199,   200,   201,   202,   203,   204,
     205,   206,   207,   208,   209,   210,   211,   212,   213,   214,
     215,   216,   217,   218,   219,   220,   221,   222,   223,   224,
     225,   226,   227,   228,   229,   230,   231,   232,   233,   234,
     235,   236,   237,   238,   239,   240,   241,   242,   243,   244,
     245,   246,   247,   248,   249,   250,   251,   252,   253,   254,
     255,   256,   257,   258,   259,   260,   261,   262,   263,   264,
     265,   266,   267,   268,   269,   270,   271,   272,   273,   274,
     275,   276,   277,   278,   279,   280,   281,   282,   283,   284,
     285,   286,   287,   288,   289,   290,   291,   292,   293,   294,
     295,   296,   297,   298,   299,   300,   301,   302,   303,   304,
     305,   306,   307,   308,   309,   310,   311,   312,   313,   314,
     315,   316,   317,   318,   319,   320,   321,   322,   323,   324,
     325,   326,   327,   328,   329,   330,   331,   332,   333,   334,
     335,   336,   337,   338,   339,   340,   341,   342,   343,   344,
     345,   346,   347,   348,   349,   350,   351,   352,   353,   354
};

#if YYDEBUG
/* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
static const yytype_int16 yyrline[] =
{
       0,   806,   806,   806,   808,   809,   811,   812,   813,   814,
     815,   816,   817,   818,   819,   820,   821,   822,   823,   825,
     826,   827,   828,   830,   836,   840,   841,   842,   843,   846,
     854,   856,   856,   862,   868,   875,   882,   891,   893,   895,
     897,   900,   902,   905,   907,   915,   916,   917,   918,   920,
     921,   922,   923,   924,   925,   926,   927,   929,   930,   932,
     933,   935,   936,   937,   938,   939,   940,   941,   942,   943,
     944,   945,   946,   947,   948,   949,   951,   953,   954,   956,
     957,   959,   960,   962,   963,   963,   964,   964,   965,   965,
     966,   966,   967,   967,   968,   968,   969,   969,   970,   970,
     971,   971,   972,   973,   973,   974,   975,   976,   977,   978,
     979,   980,   980,   981,   982,   983,   984,   985,   985,   986,
     987,   987,   988,   989,   990,   991,   992,   992,   994,   997,
    1001,  1002,  1004,  1004,  1020,  1021,  1022,  1024,  1024,  1031,
    1031,  1038,  1038,  1040,  1040,  1042,  1042,  1044,  1045,  1047,
    1047,  1050,  1051,  1052,  1053,  1054,  1055,  1056,  1057,  1058,
    1060,  1061,  1062,  1063,  1064,  1065,  1066,  1067,  1068,  1069,
    1070,  1071,  1072,  1073,  1075,  1076,  1077,  1078,  1079,  1080,
    1082,  1083,  1084,  1085,  1086,  1087,  1088,  1089,  1090,  1091,
    1092,  1093,  1094,  1095,  1096,  1097,  1098,  1099,  1100,  1101,
    1102,  1103,  1104,  1105,  1106,  1107,  1108,  1110,  1111,  1112,
    1113,  1114,  1115,  1117,  1118,  1119,  1121,  1122,  1124,  1125,
    1127,  1128,  1129,  1130,  1131,  1132,  1133,  1134,  1135,  1136,
    1137,  1138,  1139,  1140,  1141,  1142,  1144,  1145,  1146,  1147,
    1148,  1150,  1151,  1153,  1154,  1156,  1157,  1158,  1159,  1161,
    1162,  1163,  1164,  1165,  1166,  1167,  1168,  1169,  1170,  1172,
    1174,  1175,  1177,  1179,  1180,  1181,  1182,  1183,  1184,  1185,
    1186,  1187,  1188,  1189,  1190,  1191,  1192,  1193,  1194,  1195,
    1196,  1197,  1198,  1199,  1200,  1201,  1202,  1203,  1204,  1205,
    1206,  1207,  1208,  1210,  1211,  1212,  1213,  1214,  1215,  1216,
    1217,  1218,  1219,  1220,  1221,  1222,  1224,  1225,  1226,  1227,
    1229,  1230,  1231,  1232,  1234,  1235,  1236,  1237,  1239,  1240,
    1241,  1242,  1243,  1244,  1245,  1246,  1247,  1249,  1250,  1252,
    1253,  1254,  1255,  1257,  1258,  1259,  1260,  1261,  1262,  1264,
    1266,  1267,  1270,  1275,  1280,  1286,  1298,  1300,  1300,  1301,
    1301,  1302,  1302,  1303,  1303,  1304,  1304,  1305,  1305,  1306,
    1306,  1306,  1310,  1310,  1311,  1311,  1312,  1312,  1313,  1313,
    1314,  1314,  1316,  1316,  1317,  1317,  1319,  1319,  1321,  1322,
    1323,  1324,  1325,  1326,  1327,  1328,  1329,  1330,  1331,  1333,
    1334,  1335,  1336,  1337,  1338,  1339,  1340,  1341,  1342,  1343,
    1345,  1346,  1347,  1348,  1349,  1350,  1351,  1352,  1353,  1354,
    1355,  1357,  1359,  1361,  1363,  1364,  1365,  1367,  1369,  1370,
    1372,  1373,  1374,  1374,  1377,  1378,  1379,  1381,  1383,  1384,
    1386,  1387,  1388,  1390,  1391,  1393,  1394,  1396,  1397,  1398,
    1399,  1400,  1401,  1402,  1403,  1404,  1405,  1406,  1408,  1410,
    1412,  1413,  1414,  1415,  1417,  1421,  1422,  1423,  1425,  1431,
    1432,  1433,  1436,  1436,  1437,  1437,  1439,  1440,  1441,  1442,
    1443,  1447,  1450,  1450,  1452,  1452,  1456,  1457,  1458,  1460,
    1461,  1462,  1463,  1464,  1465,  1466,  1467,  1468,  1469,  1470,
    1471,  1472,  1473,  1475,  1476,  1477,  1478,  1480,  1481,  1483,
    1483,  1484,  1484,  1486,  1487,  1488,  1490,  1491,  1493,  1494,
    1496,  1497,  1498,  1500,  1501,  1503,  1504,  1506,  1507,  1509,
    1511,  1512,  1513,  1514,  1515,  1516,  1517,  1518,  1518,  1522,
    1524,  1525,  1527,  1531,  1538,  1596,  1597,  1598,  1599,  1601,
    1602,  1603,  1604,  1606,  1607,  1608,  1609,  1611,  1613,  1614,
    1615,  1616,  1617,  1619,  1620,  1623,  1624,  1626,  1627,  1628,
    1629,  1630,  1632,  1633,  1635,  1636,  1638,  1639,  1641,  1642,
    1644,  1645,  1647,  1648,  1649,  1651,  1652,  1653,  1655,  1656,
    1657,  1659,  1660,  1662,  1663,  1665,  1667,  1668,  1670,  1671,
    1673,  1674,  1676,  1677,  1686,  1687,  1688,  1689,  1690,  1691,
    1692,  1693,  1694,  1695,  1696,  1697,  1699,  1700,  1701,  1702,
    1703,  1706,  1707,  1708,  1709,  1710,  1711,  1712,  1713,  1714,
    1715,  1716,  1717,  1719,  1720,  1722,  1723,  1725,  1726,  1728,
    1729,  1730,  1731,  1732,  1733,  1734,  1735,  1736
};
#endif

/** Accessing symbol of state STATE.  */
#define YY_ACCESSING_SYMBOL(State) YY_CAST (yysymbol_kind_t, yystos[State])

#if 1
/* The user-facing name of the symbol whose (internal) number is
   YYSYMBOL.  No bounds checking.  */
static const char *yysymbol_name (yysymbol_kind_t yysymbol) YY_ATTRIBUTE_UNUSED;

/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
   First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
static const char *const yytname[] =
{
  "\"end of file\"", "error", "\"invalid token\"", "T_INT", "T_HEX",
  "T_FLOAT", "T_IDENTIFIER", "T_REGISTER", "T_CONSTANT", "T_RT",
  "T_A_LOCALSIZE", "T_A_CONST", "T_A_BUF", "T_A_INVOCATIONID", "T_A_WGID",
  "T_A_NUMWG", "T_A_BRANCHSTACK", "T_A_IN", "T_A_OUT", "T_A_TEX",
  "T_A_PVTMEM", "T_A_LOCALMEM", "T_A_EARLYPREAMBLE", "T_A_FULLNOPSTART",
  "T_A_FULLNOPEND", "T_A_FULLSYNCSTART", "T_A_FULLSYNCEND", "T_ABSNEG",
  "T_NEG", "T_ABS", "T_R", "T_LAST", "T_HR", "T_HC", "T_EVEN",
  "T_POS_INFINITY", "T_NEG_INFINITY", "T_EI", "T_WRMASK", "T_FLUT_0_0",
  "T_FLUT_0_5", "T_FLUT_1_0", "T_FLUT_2_0", "T_FLUT_E", "T_FLUT_PI",
  "T_FLUT_INV_PI", "T_FLUT_INV_LOG2_E", "T_FLUT_LOG2_E",
  "T_FLUT_INV_LOG2_10", "T_FLUT_LOG2_10", "T_FLUT_4_0", "T_SY", "T_SS",
  "T_JP", "T_EQ_FLAG", "T_SAT", "T_RPT", "T_UL", "T_NOP", "T_OP_NOP",
  "T_OP_BR", "T_OP_BRAO", "T_OP_BRAA", "T_OP_BRAC", "T_OP_BANY",
  "T_OP_BALL", "T_OP_BRAX", "T_OP_JUMP", "T_OP_CALL", "T_OP_RET",
  "T_OP_KILL", "T_OP_END", "T_OP_EMIT", "T_OP_CUT", "T_OP_CHMASK",
  "T_OP_CHSH", "T_OP_FLOW_REV", "T_OP_BKT", "T_OP_STKS", "T_OP_STKR",
  "T_OP_XSET", "T_OP_XCLR", "T_OP_GETLAST", "T_OP_GETONE", "T_OP_DBG",
  "T_OP_SHPS", "T_OP_SHPE", "T_OP_PREDT", "T_OP_PREDF", "T_OP_PREDE",
  "T_OP_MOVMSK", "T_OP_MOVA1", "T_OP_MOVA", "T_OP_MOV", "T_OP_COV",
  "T_OP_SWZ", "T_OP_GAT", "T_OP_SCT", "T_OP_MOVS", "T_OP_ADD_F",
  "T_OP_MIN_F", "T_OP_MAX_F", "T_OP_MUL_F", "T_OP_SIGN_F", "T_OP_CMPS_F",
  "T_OP_ABSNEG_F", "T_OP_CMPV_F", "T_OP_FLOOR_F", "T_OP_CEIL_F",
  "T_OP_RNDNE_F", "T_OP_RNDAZ_F", "T_OP_TRUNC_F", "T_OP_ADD_U",
  "T_OP_ADD_S", "T_OP_SUB_U", "T_OP_SUB_S", "T_OP_CMPS_U", "T_OP_CMPS_S",
  "T_OP_MIN_U", "T_OP_MIN_S", "T_OP_MAX_U", "T_OP_MAX_S", "T_OP_ABSNEG_S",
  "T_OP_AND_B", "T_OP_OR_B", "T_OP_NOT_B", "T_OP_XOR_B", "T_OP_CMPV_U",
  "T_OP_CMPV_S", "T_OP_MUL_U24", "T_OP_MUL_S24", "T_OP_MULL_U",
  "T_OP_BFREV_B", "T_OP_CLZ_S", "T_OP_CLZ_B", "T_OP_SHL_B", "T_OP_SHR_B",
  "T_OP_ASHR_B", "T_OP_BARY_F", "T_OP_FLAT_B", "T_OP_MGEN_B",
  "T_OP_GETBIT_B", "T_OP_SETRM", "T_OP_CBITS_B", "T_OP_SHB", "T_OP_MSAD",
  "T_OP_MAD_U16", "T_OP_MADSH_U16", "T_OP_MAD_S16", "T_OP_MADSH_M16",
  "T_OP_MAD_U24", "T_OP_MAD_S24", "T_OP_MAD_F16", "T_OP_MAD_F32",
  "T_OP_SEL_B16", "T_OP_SEL_B32", "T_OP_SEL_S16", "T_OP_SEL_S32",
  "T_OP_SEL_F16", "T_OP_SEL_F32", "T_OP_SAD_S16", "T_OP_SAD_S32",
  "T_OP_SHRM", "T_OP_SHLM", "T_OP_SHRG", "T_OP_SHLG", "T_OP_ANDG",
  "T_OP_DP2ACC", "T_OP_DP4ACC", "T_OP_WMM", "T_OP_WMM_ACCU", "T_OP_RCP",
  "T_OP_RSQ", "T_OP_LOG2", "T_OP_EXP2", "T_OP_SIN", "T_OP_COS",
  "T_OP_SQRT", "T_OP_HRSQ", "T_OP_HLOG2", "T_OP_HEXP2", "T_OP_ISAM",
  "T_OP_ISAML", "T_OP_ISAMM", "T_OP_SAM", "T_OP_SAMB", "T_OP_SAML",
  "T_OP_SAMGQ", "T_OP_GETLOD", "T_OP_CONV", "T_OP_CONVM", "T_OP_GETSIZE",
  "T_OP_GETBUF", "T_OP_GETPOS", "T_OP_GETINFO", "T_OP_DSX", "T_OP_DSY",
  "T_OP_GATHER4R", "T_OP_GATHER4G", "T_OP_GATHER4B", "T_OP_GATHER4A",
  "T_OP_SAMGP0", "T_OP_SAMGP1", "T_OP_SAMGP2", "T_OP_SAMGP3",
  "T_OP_DSXPP_1", "T_OP_DSYPP_1", "T_OP_RGETPOS", "T_OP_RGETINFO",
  "T_OP_BRCST_A", "T_OP_QSHUFFLE_BRCST", "T_OP_QSHUFFLE_H",
  "T_OP_QSHUFFLE_V", "T_OP_QSHUFFLE_DIAG", "T_OP_TCINV", "T_OP_LDG",
  "T_OP_LDG_A", "T_OP_LDG_K", "T_OP_LDL", "T_OP_LDP", "T_OP_STG",
  "T_OP_STG_A", "T_OP_STL", "T_OP_STP", "T_OP_LDIB", "T_OP_G2L",
  "T_OP_L2G", "T_OP_PREFETCH", "T_OP_LDLW", "T_OP_STLW", "T_OP_RESFMT",
  "T_OP_RESINFO", "T_OP_RESBASE", "T_OP_ATOMIC_ADD", "T_OP_ATOMIC_SUB",
  "T_OP_ATOMIC_XCHG", "T_OP_ATOMIC_INC", "T_OP_ATOMIC_DEC",
  "T_OP_ATOMIC_CMPXCHG", "T_OP_ATOMIC_MIN", "T_OP_ATOMIC_MAX",
  "T_OP_ATOMIC_AND", "T_OP_ATOMIC_OR", "T_OP_ATOMIC_XOR", "T_OP_RESINFO_B",
  "T_OP_LDIB_B", "T_OP_STIB_B", "T_OP_ATOMIC_B_ADD", "T_OP_ATOMIC_B_SUB",
  "T_OP_ATOMIC_B_XCHG", "T_OP_ATOMIC_B_INC", "T_OP_ATOMIC_B_DEC",
  "T_OP_ATOMIC_B_CMPXCHG", "T_OP_ATOMIC_B_MIN", "T_OP_ATOMIC_B_MAX",
  "T_OP_ATOMIC_B_AND", "T_OP_ATOMIC_B_OR", "T_OP_ATOMIC_B_XOR",
  "T_OP_ATOMIC_S_ADD", "T_OP_ATOMIC_S_SUB", "T_OP_ATOMIC_S_XCHG",
  "T_OP_ATOMIC_S_INC", "T_OP_ATOMIC_S_DEC", "T_OP_ATOMIC_S_CMPXCHG",
  "T_OP_ATOMIC_S_MIN", "T_OP_ATOMIC_S_MAX", "T_OP_ATOMIC_S_AND",
  "T_OP_ATOMIC_S_OR", "T_OP_ATOMIC_S_XOR", "T_OP_ATOMIC_G_ADD",
  "T_OP_ATOMIC_G_SUB", "T_OP_ATOMIC_G_XCHG", "T_OP_ATOMIC_G_INC",
  "T_OP_ATOMIC_G_DEC", "T_OP_ATOMIC_G_CMPXCHG", "T_OP_ATOMIC_G_MIN",
  "T_OP_ATOMIC_G_MAX", "T_OP_ATOMIC_G_AND", "T_OP_ATOMIC_G_OR",
  "T_OP_ATOMIC_G_XOR", "T_OP_LDGB", "T_OP_STGB", "T_OP_STIB", "T_OP_LDC",
  "T_OP_LDLV", "T_OP_GETSPID", "T_OP_GETWID", "T_OP_GETFIBERID",
  "T_OP_STC", "T_OP_STSC", "T_OP_SHFL", "T_OP_RAY_INTERSECTION",
  "T_OP_BAR", "T_OP_FENCE", "T_OP_SLEEP", "T_OP_ICINV", "T_OP_DCCLN",
  "T_OP_DCINV", "T_OP_DCFLU", "T_OP_CCINV", "T_OP_LOCK", "T_OP_UNLOCK",
  "T_OP_ALIAS", "T_RAW", "T_OP_PRINT", "T_TYPE_F16", "T_TYPE_F32",
  "T_TYPE_U16", "T_TYPE_U32", "T_TYPE_S16", "T_TYPE_S32", "T_TYPE_U8",
  "T_TYPE_U8_32", "T_TYPE_U64", "T_TYPE_B16", "T_TYPE_B32", "T_UNTYPED",
  "T_TYPED", "T_MIXED", "T_UNSIGNED", "T_LOW", "T_HIGH", "T_1D", "T_2D",
  "T_3D", "T_4D", "T_LT", "T_LE", "T_GT", "T_GE", "T_EQ", "T_NE", "T_S2EN",
  "T_SAMP", "T_TEX", "T_BASE", "T_OFFSET", "T_UNIFORM", "T_NONUNIFORM",
  "T_IMM", "T_NAN", "T_INF", "T_A0", "T_A1", "T_P0", "T_W",
  "T_CAT1_TYPE_TYPE", "T_MOD_TEX", "T_MOD_MEM", "T_MOD_RT", "T_MOD_XOR",
  "T_MOD_UP", "T_MOD_DOWN", "T_MOD_RUP", "T_MOD_RDOWN", "'-'", "','",
  "'('", "')'", "'='", "':'", "'!'", "'#'", "'.'", "'a'", "'o'", "'p'",
  "'s'", "'v'", "'+'", "'<'", "'g'", "'['", "']'", "'c'", "'l'", "'u'",
  "'k'", "'w'", "'r'", "'>'", "'h'", "$accept", "shader", "$@1", "headers",
  "header", "const_val", "localsize_header", "const_header",
  "buf_header_init_val", "buf_header_init_vals", "buf_header_addr_reg",
  "buf_header", "$@2", "invocationid_header", "wgid_header",
  "numwg_header", "branchstack_header", "pvtmem_header", "localmem_header",
  "earlypreamble_header", "in_header", "out_header", "tex_header_opc",
  "tex_header", "fullnop_start_section", "fullnop_end_section",
  "fullsync_start_section", "fullsync_end_section", "iflag", "iflags",
  "instrs", "instr", "label", "cat0_src1", "cat0_src2", "cat0_immed",
  "cat0_instr", "$@3", "$@4", "$@5", "$@6", "$@7", "$@8", "$@9", "$@10",
  "$@11", "$@12", "$@13", "$@14", "$@15", "$@16", "cat1_opc", "cat1_src",
  "cat1_movmsk", "$@17", "mova_src", "cat1_mova1", "$@18", "cat1_mova",
  "$@19", "cat1_swz", "$@20", "cat1_gat", "$@21", "cat1_sct", "$@22",
  "movs_invocation", "cat1_movs", "$@23", "cat1_instr", "cat2_opc_1src",
  "cat2_opc_2src_cnd", "cat2_opc_2src", "cond", "cat2_instr",
  "cat3_dp_signedness", "cat3_dp_pack", "cat3_opc", "cat3_imm_reg_opc",
  "cat3_wmm", "cat3_dp", "cat3_instr", "cat4_opc", "cat4_instr",
  "cat5_opc_dsxypp", "cat5_opc_isam", "cat5_opc", "cat5_flag",
  "cat5_flags", "cat5_samp", "cat5_tex", "cat5_type", "cat5_a1",
  "cat5_samp_tex", "cat5_samp_tex_all", "cat5_instr", "cat6_typed",
  "cat6_dim", "cat6_type", "cat6_imm_offset", "cat6_offset",
  "cat6_dst_offset", "cat6_immed", "cat6_src_shift",
  "cat6_a6xx_global_address_pt2", "cat6_a6xx_global_address", "cat6_load",
  "$@24", "$@25", "$@26", "$@27", "$@28", "$@29", "$@30", "$@31",
  "cat6_store", "$@32", "$@33", "$@34", "$@35", "$@36", "cat6_loadib",
  "$@37", "cat6_storeib", "$@38", "cat6_prefetch", "$@39",
  "cat6_atomic_opc", "cat6_a3xx_atomic_opc", "cat6_a6xx_atomic_opc",
  "cat6_a3xx_atomic_s", "cat6_a6xx_atomic_g", "cat6_atomic_l",
  "cat6_atomic", "cat6_ibo_opc_1src", "cat6_ibo_opc_ldgb",
  "cat6_ibo_opc_stgb", "cat6_ibo", "$@40", "cat6_id_opc", "cat6_id",
  "cat6_bindless_base", "cat6_bindless_mode", "cat6_reg_or_immed",
  "cat6_bindless_ibo_opc_1src", "cat6_bindless_ibo_opc_2src",
  "cat6_bindless_ibo_opc_3src", "cat6_bindless_ibo_opc_3src_dst",
  "cat6_bindless_ibo", "cat6_bindless_ldc_opc", "cat6_bindless_ldc_middle",
  "cat6_bindless_ldc", "const_dst", "cat6_stc", "$@41", "$@42",
  "cat6_shfl_mode", "cat6_shfl", "$@43", "cat6_ray_intersection", "$@44",
  "cat6_todo", "cat6_instr", "cat7_scope", "cat7_scopes", "cat7_barrier",
  "$@45", "$@46", "cat7_data_cache", "cat7_alias_dst", "cat7_alias_src",
  "cat7_alias_scope", "cat7_alias_int_type", "cat7_alias_float_type",
  "cat7_alias_type", "cat7_alias_table_size_minus_one", "cat7_instr",
  "$@47", "raw_instr", "meta_print_regs", "meta_print_reg",
  "meta_print_start", "meta_print", "src_gpr", "src_a0", "src_a1",
  "src_p0", "src", "dst", "const", "dst_reg_flag", "dst_reg_flags",
  "dst_reg", "src_reg_flag", "src_reg_flags", "src_reg", "src_reg_gpr",
  "src_const", "src_reg_or_const", "src_reg_or_const_or_rel",
  "src_reg_or_const_or_rel_or_imm", "src_reg_or_rel_or_imm", "uoffset",
  "offset", "src_uoffset", "relative_gpr_src", "relative_gpr_dst",
  "relative_const", "relative", "immediate_cat1", "immediate",
  "flut_immed", "uinteger", "integer", "float", "type", YY_NULLPTR
};

static const char *
yysymbol_name (yysymbol_kind_t yysymbol)
{
  return yytname[yysymbol];
}
#endif

#define YYPACT_NINF (-1106)

#define yypact_value_is_default(Yyn) \
  ((Yyn) == YYPACT_NINF)

#define YYTABLE_NINF (-4)

#define yytable_value_is_error(Yyn) \
  0

/* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
   STATE-NUM.  */
static const yytype_int16 yypact[] =
{
   -1106,    45,  1096, -1106,    39,  -307,    39,  -289,  -274,  -271,
      39,  -241,  -233,  -208,    39,    39, -1106,  1208,  1096, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106,   149,  -181,   164, -1106,   173,
     219,   193, -1106,   199,   212,   222, -1106, -1106,  -122, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106,   227, -1106, -1106, -1106, -1106,   641,  1498,  1185,
   -1106, -1106, -1106,  -116, -1106, -1106, -1106,    39,  -113,  -106,
     -90,   -85,   -68,   -30,   -24,   -21,   -12, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106,     0, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106,     2, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106,     4,    27,    29,    13,    15,    23,    25,    43,    46,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106,   347, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106,   514,    49,   514, -1106,   514,   514,
     514,    52, -1106,   514, -1106,    64,    66,    64, -1106, -1106,
   -1106, -1106, -1106, -1106,    68,    68,    68, -1106, -1106, -1106,
   -1106,    71,    68,    68, -1106,    71, -1106,    68,    68,    68,
      68, -1106,    76, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106,   385, -1106,  -116,    63,    39,   433,    39,
   -1106, -1106, -1106, -1106,   439,   441,   442,  -251,  -251,  -251,
      81,  -251,  -251,    90,    90,    90,  -251,    90,   108,    90,
      90,   118,   115,   119,   130,   135,   139,   141,   146,   148,
      71,    71,    71,    71,    71,    71,    71,    71,    71,    68,
     125,    71,    71,    68,    71,    71,    71,   137,   514,   157,
     157,   160, -1106,   154, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106,   156, -1106,   306,    30,   171,   179,   180,  -114,
     181,   187,   188,   189,  -129,   195,   203,  1019,    64,   514,
     569,   204,   204,   -51,   205,   205,   205,   281,   205,   205,
     205,   514,   205,   205,   205,   205,    32, -1106, -1106,    39,
     214,   202, -1106,   215, -1106,   220,   241,   210, -1106,   255,
     244,   247,   248, -1106, -1106,   298, -1106, -1106,   249,   251,
      73, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,   514,   514,
     234,   514,   514,   238,   239,   236,   246,   205,   250,   514,
     254,   205,   514,   242,   245,   229,   265,  -132,   157, -1106,
   -1106,   -32,   282,   283, -1106, -1106,   995,   995,   781, -1106,
   -1106, -1106, -1106, -1106, -1106,   514,   781,   112,   914,   167,
   -1106, -1106,   -36,   514,   781, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106,   267,    64,   281,
     514,   514, -1106, -1106,   182,    71,    71,    71, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,   514,    71,
      71, -1106,    71,    71,    71,    71,   263,   268,   269,   274,
   -1106, -1106,    39, -1106,    39,   627,   629,    81, -1106,    90,
    -229,  -229, -1106,    90,    90,    90, -1106, -1106,    90,   514,
     995,   995,   514,   514,   514,   514,   286,   289,   266,   290,
     293,   276,   284,   294,   299,    71,   213,   297,   300,    71,
     309,   301,   302, -1106, -1106, -1106, -1106, -1106,    71, -1106,
     316, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,   291,
    -243,  -243, -1106, -1106, -1106, -1106, -1106, -1106, -1106,   285,
     331, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,   133,
     336,   339,   353, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
     485,    59, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106,    81,  1055,   636, -1106, -1106, -1106,
   -1106, -1106,   355,   356,   357,   213, -1106,   358, -1106, -1106,
   -1106,   361, -1106, -1106, -1106,   366, -1106,   716,   204,   367,
     368,   371, -1106, -1106, -1106, -1106,   369,   370,   372,   373,
     374,   375,   381,   383,   384,   386,    81,   394,   359,   175,
     378, -1106,   391,   396,   400, -1106, -1106,   413,   402,   403,
   -1106, -1106, -1106, -1106, -1106, -1106,    56, -1106, -1106, -1106,
     404,   405,   407,   411,   397,   398,    67,   399,   406,   213,
     100,   213,   213,   408,  -234,   401,   213,   412,   415,    67,
      67,    30,   100,   -52,    81,    81, -1106,   414,   416,   435,
     438, -1106,   423,   425,   292,   428,   443,   449,   451,    77,
   -1106, -1106, -1106, -1106,   444,    81, -1106, -1106,   781,   781,
     100,   100,   230,   914, -1106,   514, -1106,   716,    62,    81,
      81,    81,   432,    81,    81,    81,    81,    81,    81,   452,
     454,   455,   448, -1106, -1106,    39,    81,    81,   799, -1106,
      90,    90, -1106,   514,   230,   514,   230,   434,   447,   464,
     461, -1106,   463,   468,  -243,   469,   197,   467,  -184,  -184,
      81,   175, -1106,   471, -1106,   475,  -184,    81,   477,   481,
     486,   504,   488, -1106, -1106, -1106, -1106, -1106, -1106,   478,
   -1106, -1106, -1106, -1106,  -243,  -243, -1106, -1106, -1106, -1106,
   -1106,  -243,  -243,   506,   507, -1106,   510,   513, -1106,   516,
     517,   520,   521,   522,   523, -1106, -1106,   524, -1106, -1106,
     527,   526,   529,   531,   512,   514, -1106,   532,   534,   535,
     536,   194,    81,   194,   175,   544,   547,   550,   528, -1106,
   -1106,   555,   557,   559,   564,   213,   100,    81,   566,   213,
     213,   551,   567,     7,   175,   552, -1106,   553,   514, -1106,
     571,   213,   565,   436,    81,   572,   576,   213,   592,   887,
     570,   597,   601,   602, -1106, -1106, -1106,   781,   112,   914,
     926,   100,   716,    62,   615,    62,   577,   580,   612,   175,
     628,   614,   194,   194,   194,   194,   623,   623,   623,   514,
     624,   616, -1106,    39, -1106, -1106,    81,   230,   230,   514,
      24,  -234,   619, -1106,   617,  -234,  -234,   633,   213,    47,
   -1106,  -243, -1106,   638,   639,   640,    81,  -234,   644,   625,
     631,   230,   926,   645,   230, -1106,   271, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106,   649,   650,   651,   653, -1106,
   -1106,   657, -1106, -1106,   662,   514,   514,   514,   647,   658,
     660,   514,   230,   230,   514,   695, -1106, -1106, -1106, -1106,
     194,   661, -1106,   684,   685,   686,   687, -1106, -1106, -1106,
     671,   690,   675,   676,   677,   213,   692,   140,   681, -1106,
     213,   213,   682, -1106,   688,   213,   926, -1106,   702,   703,
     175,   704, -1106,   706, -1106,   914, -1106,   707,  -170,   721,
       5,     5,   709,   710,   714, -1106,   696,   175,   715,   717,
     718,   719, -1106,   514,   729,  1070,   230,   230,   514,   723,
     926,   213,   730,   735,   736,   926,   213,   681,   749,   762,
     765,   766,   705,   770,   771,   755,   773,    81,    81, -1106,
     230,   712, -1106,    62, -1106, -1106, -1106, -1106, -1106,   774,
   -1106,   756,   761,   213,   175,   760,   175,   175,   175,   175,
   -1106,   764,   775, -1106,   779,   783,   926, -1106,  -234,   926,
     926,   926, -1106,   681,  -243,    81, -1106,   926,   926,   926,
     926,   926,   784,   926, -1106, -1106,   785, -1106, -1106, -1106,
   -1106,   721,   772,   776,   786,   778,   787, -1106,   791,   650,
     650, -1106,    81,   230,   230, -1106,   788, -1106, -1106, -1106,
     800,   801, -1106, -1106, -1106,   790, -1106, -1106,   213, -1106,
     230,   175,   175,   213,   808,   213,   175,   809,   810,   811,
   -1106, -1106,   814,  -243,   803,   815,   818, -1106,   804,   805,
   -1106,   213,   824, -1106,   175,   175,   836,   926,   826,   817,
     213,   213,   832,   833,   834,   175, -1106, -1106,   835, -1106,
     822,    81,   837,   842,   213,   213,   213,   843,    81,   830,
     846,   213,   213, -1106,   845, -1106,   213,   849,    81, -1106,
   -1106, -1106,   213, -1106,  1200,   854,   859,   857, -1106,   213,
      81, -1106,   861,  1212,   860,  1037, -1106, -1106
};

/* YYDEFACT[STATE-NUM] -- Default reduction number in state STATE-NUM.
   Performed when YYTABLE does not specify something else to do.  Zero
   means the default is an error.  */
static const yytype_int16 yydefact[] =
{
       2,     0,     4,     1,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,    40,    57,     4,     6,
       7,     8,     9,    10,    11,    12,    16,    17,    18,    13,
      14,    15,    20,    22,    19,     0,     0,     0,    31,     0,
       0,     0,    37,     0,     0,     0,    38,    39,     0,    45,
      46,    47,    48,    49,    50,    51,    52,    53,    54,    55,
      56,   529,     0,    72,    73,    74,    75,    57,     0,    57,
      60,    71,    69,     0,    70,     5,    21,     0,     0,    30,
       0,     0,     0,     0,     0,     0,     0,    76,   533,    58,
      83,    84,    86,    88,     0,    92,    94,    96,    98,   100,
     102,   103,   105,   106,   107,   108,   109,   110,   111,   113,
     114,   115,   116,     0,   117,   119,   120,   122,   123,   124,
     125,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     180,   181,   182,   183,   164,   174,   160,   177,   165,   166,
     167,   168,   169,   184,   185,   186,   187,   175,   176,   188,
     189,   190,   191,   161,   192,   193,   170,   194,   178,   179,
     195,   196,   197,   171,   163,   162,   198,   199,   200,   201,
     202,   203,   204,   172,   173,   205,   206,   220,   221,   222,
     223,   224,   225,   226,   227,   228,   229,   230,   231,   232,
     233,   234,   235,   236,   237,   238,   239,   240,   243,   244,
     241,   242,   249,   250,   251,   252,   253,   254,   255,   256,
     257,   258,   262,   263,   264,   265,   266,   267,   268,   269,
     270,   271,   272,   273,   274,   275,   276,   277,   278,   279,
     280,   281,   282,   283,   284,   285,   260,   261,   286,   287,
     288,   289,   290,   291,   292,   326,   347,   349,   351,   355,
     353,   362,   364,   368,   366,   372,   476,   477,   376,   357,
     370,   478,   417,   436,   378,   379,   380,   381,   382,   383,
     384,   385,   386,   387,   388,   435,   449,   448,   437,   438,
     439,   440,   441,   442,   443,   444,   445,   446,   447,   389,
     390,   391,   392,   393,   394,   395,   396,   397,   398,   399,
     400,   401,   402,   403,   404,   405,   406,   407,   408,   409,
     410,   418,   419,   374,   454,   359,   424,   425,   426,   462,
     464,   472,   474,   499,   501,   522,   524,   503,   504,   505,
     523,   525,   526,   527,    61,     0,   151,   152,   153,   154,
     155,   156,   159,    62,     0,     0,     0,    63,     0,     0,
       0,     0,    64,     0,    65,   304,   304,   304,    66,   479,
     481,   480,   482,   483,     0,     0,     0,   415,   416,   414,
     484,     0,     0,     0,   485,     0,   486,     0,     0,     0,
       0,   488,     0,   487,   489,   490,   491,   492,    67,   520,
     521,    68,    59,     0,   534,   530,     0,     0,     0,    28,
      33,    34,    35,    36,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   497,
     497,     0,   543,     0,   548,   549,   550,   551,   552,   544,
     545,   546,     0,   555,   553,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,   304,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   532,   531,     0,
       0,     0,    25,    26,    32,     0,     0,     0,    78,     0,
       0,     0,     0,   623,   624,     0,   625,    90,     0,     0,
       0,    97,    99,   101,   104,   112,   126,   118,   121,   132,
     137,   139,   128,   129,   141,   143,   145,   149,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,   497,   500,
     502,     0,     0,     0,   554,   556,     0,     0,     0,   207,
     208,   209,   210,   211,   212,     0,     0,     0,     0,     0,
     216,   217,     0,     0,     0,   299,   293,   298,   302,   300,
     301,   303,   294,   295,   296,   297,   305,     0,   304,     0,
       0,     0,   327,   328,     0,     0,     0,     0,   629,   630,
     631,   632,   633,   634,   635,   636,   637,   333,     0,     0,
       0,   427,     0,     0,     0,     0,     0,     0,     0,     0,
     339,    23,     0,    29,    28,     0,     0,     0,    77,     0,
       0,     0,   626,     0,     0,     0,    82,    81,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   466,   467,   468,   469,   470,     0,   471,
       0,   496,   495,   493,   494,   498,   510,   511,   512,     0,
     581,   581,   535,   547,   557,   558,   559,   560,   561,     0,
       0,   601,   602,   603,   604,   605,   536,   537,   538,     0,
       0,     0,     0,   157,   539,   540,   541,   542,   564,   568,
     562,     0,   570,   571,   572,   130,   592,   593,   573,   131,
     594,   158,   611,   612,   613,   614,   615,   616,   617,   618,
     619,   620,   621,   622,     0,     0,     0,   575,   213,   577,
     608,   606,     0,     0,     0,     0,   578,     0,   579,   580,
     566,     0,   567,   218,   219,     0,   259,     0,     0,     0,
       0,   322,   329,   330,   331,   332,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,    27,     0,     0,     0,    85,    80,     0,     0,     0,
      91,    93,    95,   127,   133,   138,     0,   134,   135,   140,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   581,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   583,     0,     0,     0,
       0,   627,     0,     0,     0,     0,     0,     0,     0,     0,
     563,   565,   569,   574,     0,     0,   610,   576,     0,     0,
       0,     0,     0,     0,   318,     0,   308,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   433,   434,     0,     0,     0,     0,    79,
       0,     0,   136,     0,     0,     0,     0,     0,     0,   460,
       0,   459,     0,     0,   581,     0,     0,     0,   581,   581,
       0,     0,   335,     0,   334,     0,   581,     0,     0,     0,
       0,     0,     0,   515,   516,   513,   514,   517,   518,     0,
     584,   582,   589,   588,   581,   581,   599,   600,   628,   595,
     596,   581,   581,     0,     0,   607,     0,     0,   215,     0,
       0,     0,     0,     0,     0,   306,   307,   312,   313,   321,
     310,     0,     0,     0,     0,     0,   422,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,    87,
      89,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   337,     0,     0,   336,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,   597,   598,   609,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   428,   428,   428,     0,
       0,     0,   458,     0,    41,    42,     0,     0,     0,     0,
       0,   581,     0,   461,     0,   581,   581,     0,     0,     0,
     346,   581,   338,     0,     0,     0,     0,   581,     0,     0,
       0,     0,     0,     0,     0,   519,     0,   587,   591,   590,
     586,   214,   245,   246,   247,     0,   581,   312,   313,   314,
     324,   310,   311,   320,   310,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   431,   432,   430,   455,
       0,     0,    24,     0,     0,     0,     0,   150,   148,   147,
       0,     0,     0,     0,     0,     0,     0,     0,   341,   345,
       0,     0,     0,   377,     0,     0,     0,   360,     0,     0,
       0,     0,   507,     0,   506,     0,   585,     0,     0,     0,
       0,     0,     0,     0,     0,   420,     0,     0,     0,     0,
       0,     0,   429,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   341,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,   473,
       0,     0,   248,     0,   315,   309,   316,   317,   323,   310,
     319,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     456,     0,     0,   142,     0,     0,     0,   350,   581,     0,
       0,     0,   365,   341,   581,     0,   344,     0,     0,     0,
       0,     0,     0,     0,   463,   465,     0,   528,   508,   509,
     325,     0,     0,     0,     0,     0,     0,   450,     0,   581,
     581,   457,     0,     0,     0,   348,     0,   356,   354,   363,
       0,     0,   340,   369,   367,     0,   358,   371,     0,   361,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
     144,   146,     0,   581,     0,     0,     0,   475,     0,     0,
     412,     0,     0,   451,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,   452,   453,     0,   352,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   413,     0,   421,     0,     0,     0,   343,
     373,   375,     0,   423,     0,     0,     0,     0,   342,     0,
       0,   411,     0,     0,     0,     0,    43,    44
};

/* YYPGOTO[NTERM-NUM].  */
static const yytype_int16 yypgoto[] =
{
   -1106, -1106, -1106,  1204, -1106,    -4, -1106, -1106, -1106,   589,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,  1157,
   -1106,  1156, -1106,  -137,   585,  -362, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106,   663, -1106, -1106,   578, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,  -295,   360,
    -836,  -441,  -838,   376,  -926, -1106,   473,  -133,   878,   323,
    -942,  -725,  -708, -1105, -1106,   259, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106,  -718,  -879,  -126, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106,  -504, -1106, -1106, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106,  -399, -1106, -1106, -1106, -1106, -1106,
   -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106, -1106,   840,
   -1106, -1106, -1106,  -734,   196, -1048, -1106,  -119,  -462,  -656,
   -1106,   806,  -331, -1106,  -528,  -549, -1106, -1106,  -786,  -546,
    -560,  -816, -1063,  -686,  -826,   668, -1106, -1106,  -570,  -625,
    -569,   503,  -508,  -409,   418,   652
};

/* YYDEFGOTO[NTERM-NUM].  */
static const yytype_int16 yydefgoto[] =
{
       0,     1,     2,    17,    18,   502,    19,    20,   503,   504,
     399,    21,    79,    22,    23,    24,    25,    26,    27,    28,
      29,    30,  1347,    31,    63,    64,    65,    66,    67,    68,
      69,    70,    71,   510,   798,   521,   334,   407,   408,   409,
     643,   411,   412,   413,   414,   415,   416,   417,   419,   420,
     648,   335,   713,   336,   649,   805,   337,   650,   338,   651,
     339,   652,   340,   653,   341,   654,  1117,   342,   655,   343,
     344,   345,   346,   575,   347,   475,   583,   348,   349,   350,
     351,   352,   353,   354,   355,   356,   357,   478,   479,  1087,
    1088,   600,  1197,  1089,  1090,   358,   484,   605,   488,   912,
     913,   995,   628,  1179,  1060,   905,   359,   430,   431,   432,
     434,   433,   441,   444,  1186,   360,   435,   436,   438,   437,
     442,   361,   439,   362,   443,   363,   440,   364,   365,   366,
     367,   368,   369,   370,   371,   372,   373,   374,  1031,   375,
     376,  1106,  1039,   882,   377,   378,   379,   380,   381,   382,
     629,   383,   900,   384,   445,   446,   678,   385,   447,   386,
     448,   387,   388,   558,   559,   389,   449,   450,   390,  1143,
    1237,   689,   927,   928,   929,  1076,   391,   451,    72,   394,
     395,    73,    74,   714,   715,   716,   717,   718,   463,   719,
     464,   465,   466,   720,   755,   722,   761,   723,   724,   747,
     748,   757,   836,   914,  1147,   726,   467,   727,   728,   729,
     749,   750,   516,   751,   846,   617
};

/* YYTABLE[YYPACT[STATE-NUM]] -- What to do in state STATE-NUM.  If
   positive, shift that token.  If negative, reduce the rule whose
   number is the opposite.  If YYTABLE_NINF, syntax error.  */
static const yytype_int16 yytable[] =
{
      36,   517,    38,   565,   837,   838,    42,   642,   758,   759,
      46,    47,   692,   468,   692,   470,   753,   471,   472,   473,
     725,   725,   476,  1146,   766,   808,   808,   513,   514,   756,
     760,   754,   958,   864,   907,   513,   514,   452,   721,   721,
     746,   601,    32,    33,    34,     3,   922,   952,   746,   721,
      37,   560,   522,   523,   692,   525,   746,   527,   528,   513,
     514,   481,   482,   692,   693,   852,   692,   693,    39,   692,
     513,   514,  1224,   396,   949,   950,   513,   514,   879,   646,
     513,   514,   841,    40,   513,   514,    41,   630,   699,   700,
     852,   699,   700,   508,  1041,   701,   702,   703,   704,  1093,
    1195,  1195,  1195,  1195,   807,   807,   705,   692,   693,  1120,
     509,   647,   834,  1123,  1124,   796,    43,   556,  1260,   692,
     693,   834,   806,   806,    44,  1134,   835,   694,   695,   696,
     697,   698,   797,   954,   960,   911,   513,   514,   841,   694,
     695,   696,   697,   698,   699,   700,   679,   692,   597,    45,
     852,   853,    76,  1101,  1102,  1103,  1104,   730,   730,   685,
     621,   961,   962,   963,   956,   965,   966,   967,   968,   969,
     970,   834,    78,   707,   692,    77,   853,   857,   513,   514,
      80,   892,   692,   596,   997,   994,  1146,  1146,  1092,   580,
     581,  1002,   850,  1195,   694,   695,   696,   697,   698,   699,
     907,    83,   998,  1083,   692,   693,    84,   656,   657,  1003,
     659,   660,   569,   570,   571,   572,   573,   574,   667,    85,
     692,   670,   996,   996,  1198,  1200,    81,    82,   794,    86,
     996,  1163,   513,   514,    88,  1085,   853,   692,    87,   681,
     393,   730,   730,   682,   752,   397,   683,   684,  1010,  1011,
     852,   398,   765,   923,   924,  1012,  1013,   694,   695,   696,
     697,   698,   925,   926,  1040,   602,   603,  1240,   400,   770,
     771,   511,   512,   401,   518,   519,  1256,   795,   452,   524,
    1142,   800,   801,   802,   763,   764,   803,   779,  1086,  1091,
     402,  1094,   906,   758,   759,   513,   514,   938,   947,   948,
     845,   513,   514,   768,   906,   454,   455,   456,   457,   458,
    1194,  1196,  1092,   951,   756,   686,   687,   688,   804,  1107,
    1108,   810,   811,   812,   813,   919,   920,   865,   403,  1192,
     746,   746,   906,   906,   404,   854,   642,   405,   955,   956,
     454,   455,   456,   457,   458,   982,   406,   984,   707,   706,
     707,   708,   606,   607,   452,   618,   619,   620,  1133,   622,
     623,   624,   625,   410,  1059,   418,   706,   421,   626,   921,
     422,   423,   459,   460,   461,  1129,   424,   630,   425,   453,
     884,   454,   455,   456,   457,   458,   426,   515,   427,   706,
     707,   708,   497,   500,    35,   955,   956,   730,   706,   707,
     708,   706,   707,   708,  1127,  1238,   428,   901,   627,   429,
     899,   515,   469,   709,   665,   474,  1199,  1199,   669,   499,
     901,   901,   515,  1277,  1278,   930,   931,   477,   515,   480,
     710,   483,   844,   710,   487,   711,   515,   712,   711,   496,
     943,   501,   706,   707,   708,   505,   946,   506,   507,   758,
     759,  1084,   520,   526,   706,   707,   708,  1081,   906,  1199,
     630,   630,   630,   529,   630,   630,   630,   630,   630,   630,
     756,   530,  1082,   842,   843,   531,   532,   976,   977,  1234,
    1235,   533,   706,   707,   708,   534,   710,   535,   844,   746,
     721,   711,   536,   906,   537,   631,   548,  1176,  1114,  1115,
     555,   630,   931,  1139,   772,   773,   774,   775,   630,   706,
     707,   708,   694,   695,   696,   697,   698,   706,   707,   708,
     557,   452,  1138,   561,   562,  1141,   563,   566,   979,   980,
     515,  1036,  1037,  1038,   953,   567,   568,   576,  1261,   706,
     707,   708,  1119,   577,   578,   579,   711,   824,   454,   455,
     456,   457,   458,  1159,  1160,   706,   707,   708,   582,   584,
     633,   599,   981,   630,   983,   884,  1239,  1185,   604,   637,
     632,   634,   706,   707,   708,   758,   759,   635,  1053,   673,
     674,   675,   676,   677,   515,   931,   608,   609,   610,   611,
     612,   613,   614,   615,   616,  1070,   756,  1298,   636,   638,
     639,  1217,   851,   640,   641,   644,  1222,   645,   658,   661,
     662,   663,   664,   459,   460,   461,   671,  1213,  1214,   672,
     884,   680,   666,   767,   690,   691,   786,   851,   790,   668,
     789,   787,   788,   792,  1030,   793,   851,  1113,   816,   513,
     514,  1236,   814,   692,   693,   815,   817,  1255,   819,   818,
    1257,  1258,  1259,   825,   833,   839,   820,   630,  1263,  1264,
    1265,  1266,  1267,   906,  1269,   828,   821,  1065,   699,   700,
     883,   822,   826,   829,   830,   732,   733,   734,   735,   736,
     737,   738,   739,   740,   741,   742,   743,   851,   832,   459,
     460,   461,    53,    54,    55,    56,    57,    58,    59,    60,
     904,   840,   908,   909,  1280,  1281,   847,   916,  1109,   848,
     849,   858,   859,   860,   861,   513,   514,   862,  1116,   692,
     693,  1287,   863,   692,   867,   866,   462,   868,  1309,   872,
     880,   884,   869,   870,   885,   871,   881,   873,   874,   694,
     695,   696,   697,   698,   875,  1144,   876,   877,   884,   878,
     886,   701,   702,   703,   704,   887,   888,   889,   890,   891,
     893,   894,   705,   895,  1152,  1153,  1154,   896,   897,   898,
    1158,   910,   903,  1161,   902,   917,   915,   934,   630,   630,
     935,   936,   730,   937,   513,   514,   939,   851,   692,   693,
     918,   941,   999,   942,   932,   884,   933,   884,   884,   884,
     884,   940,   945,   964,   974,   978,   985,  1069,   694,   695,
     696,   697,   698,   699,   700,   971,  1262,   972,   973,   986,
     732,   733,   734,   735,   736,   737,   738,   739,   740,   741,
     742,   743,  1210,   987,   988,   989,   993,  1215,   485,   486,
     990,  1009,   992,  1279,  1000,   489,   490,  1001,  1042,  1004,
     492,   493,   494,   495,  1005,   883,   459,   460,   461,  1006,
    1007,  1008,   884,   884,  1014,  1015,  1051,   884,  1016,  1017,
    1055,  1056,  1018,  1019,  1061,  1062,  1020,  1021,  1022,  1023,
    1024,   975,  1067,  1025,  1029,   884,   884,  1046,  1073,  1026,
    1075,   585,  1027,   586,  1028,  1032,   884,  1033,  1034,  1035,
    1043,   587,  1320,  1098,   588,  1044,   589,   590,  1045,  1327,
     883,  1047,   547,  1048,   591,  1049,   551,   513,   514,  1335,
    1050,   692,  1054,  1058,  1057,  1063,  1064,  1066,  1071,   513,
     514,  1342,  1072,   592,   593,   594,   595,   598,  1068,  1126,
    1128,   694,   695,   696,   697,   698,   699,   700,  1074,   956,
    1077,  1096,  1095,   732,   733,   734,   735,   736,   737,   738,
     739,   740,   741,   742,   743,   732,   733,   734,   735,   736,
     737,   738,   739,   740,   741,   742,   743,  1078,   706,   707,
     708,  1079,  1080,  1097,  1099,  1100,  1105,  1110,  1122,  1125,
    1111,   515,  1121,   744,  1130,  1131,  1132,  1136,   513,   514,
    1135,  1140,   692,   693,  1137,  1145,  1174,  1148,  1177,  1149,
     710,  1180,  1181,  1150,  1189,   711,  1184,   745,  1151,   835,
    1155,   883,   694,   695,   696,   697,   698,   699,   700,  1156,
    1162,  1205,  1157,  1164,   701,   702,   703,   704,   883,  1112,
    1165,  1166,  1167,  1168,  1169,   705,  1170,  1171,  1175,  1172,
    1173,  1178,  1218,  1182,   706,   707,   708,  1223,  1187,  1188,
    1190,  1183,  1191,  1193,   707,  1201,  1202,   515,  1204,   709,
    1203,  1206,  1211,  1207,  1208,  1209,  1212,  1229,  1245,  1216,
    1247,  1248,  1249,  1250,  1244,   883,  1219,   883,   883,   883,
     883,  1220,  1221,   712,   732,   733,   734,   735,   736,   737,
     738,   739,   740,   741,   742,   743,     4,     5,     6,     7,
       8,     9,    10,    11,    12,    13,    14,    15,    16,  1225,
    1226,  1227,  1228,   706,   707,   708,  1230,  1231,  1232,  1233,
    1241,  1242,  1243,  1246,  1252,  1253,   515,  1251,   744,  1254,
    1268,  1270,  1273,  1275,  1271,  1288,  1289,  1276,  1272,  1286,
    1293,  1274,   883,   883,  1290,   710,  1292,   883,  1283,  1284,
     711,  1282,   745,  1285,  1291,  1294,  1295,  1296,  1306,  1307,
    1297,  1300,  1304,  1299,  1301,   883,   883,  1302,  1303,  1317,
    1305,  1312,  1313,  1308,  1310,    -3,   883,  1311,  1314,  1315,
    1316,    48,  1319,  1321,  1318,  1323,  1324,  1325,  1322,  1326,
    1328,  1332,  1330,  1331,  1329,  1334,  1337,  1333,    49,    50,
      51,    52,  1338,  1336,    48,  1339,  1340,  1343,  1344,  1345,
    1341,  1346,    75,   791,    89,   392,   799,   991,   957,   809,
     731,    49,    50,    51,    52,   498,    53,    54,    55,    56,
      57,    58,    59,    60,   959,  1052,  1118,   762,   856,     0,
       0,   769,     0,   491,     0,     0,   706,   707,   708,    53,
      54,    55,    56,    57,    58,    59,    60,   944,     0,   515,
     564,   744,     0,     0,     0,     0,     0,     0,     0,     0,
       0,   515,     0,   744,     0,     0,     0,     0,   710,     0,
       0,     0,     0,   711,     0,   745,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   745,   538,   539,
     540,   541,   542,   543,   544,   545,   546,     0,     0,   549,
     550,     0,   552,   553,   554,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,   706,   707,   708,
       0,   585,     0,   586,     0,     0,     0,     0,     0,     0,
     515,   587,   709,     0,   588,     0,   589,   590,     0,     0,
       0,     0,     0,     0,   591,     0,     0,     0,     0,   710,
       0,     0,     0,     0,   711,     0,   712,     0,     0,     0,
       0,     0,     0,   592,   593,   594,   595,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,   855,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   776,   777,   778,     0,     0,    61,    62,
       0,     0,     0,     0,     0,     0,     0,   780,   781,     0,
     782,   783,   784,   785,     0,     0,     0,     0,     0,     0,
       0,    61,    62,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,     0,     0,     0,     0,     0,     0,     0,
       0,     0,     0,   823,     0,     0,     0,   827,     0,     0,
       0,     0,     0,     0,     0,     0,   831,    90,    91,    92,
      93,    94,    95,    96,    97,    98,    99,   100,   101,   102,
     103,   104,   105,   106,   107,   108,   109,   110,   111,   112,
     113,   114,   115,   116,   117,   118,   119,   120,   121,   122,
     123,   124,   125,   126,   127,   128,   129,   130,   131,   132,
     133,   134,   135,   136,   137,   138,   139,   140,   141,   142,
     143,   144,   145,   146,   147,   148,   149,   150,   151,   152,
     153,   154,   155,   156,   157,   158,   159,   160,   161,   162,
     163,   164,   165,   166,   167,   168,   169,   170,   171,   172,
     173,   174,   175,   176,   177,   178,   179,   180,   181,   182,
     183,   184,   185,   186,   187,   188,   189,   190,   191,   192,
     193,   194,   195,   196,   197,   198,   199,   200,   201,   202,
     203,   204,   205,   206,   207,   208,   209,   210,   211,   212,
     213,   214,   215,   216,   217,   218,   219,   220,   221,   222,
     223,   224,   225,   226,   227,   228,   229,   230,   231,   232,
     233,   234,   235,   236,   237,   238,   239,   240,   241,   242,
     243,   244,   245,   246,   247,   248,   249,   250,   251,   252,
     253,   254,   255,   256,   257,   258,   259,   260,   261,   262,
     263,   264,   265,   266,   267,   268,   269,   270,   271,   272,
     273,   274,   275,   276,   277,   278,   279,   280,   281,   282,
     283,   284,   285,   286,   287,   288,   289,   290,   291,   292,
     293,   294,   295,   296,   297,   298,   299,   300,   301,   302,
     303,   304,   305,   306,   307,   308,   309,   310,   311,   312,
     313,   314,   315,   316,   317,   318,   319,   320,   321,   322,
     323,   324,   325,   326,   327,   328,   329,   330,   331,   332,
     333
};

static const yytype_int16 yycheck[] =
{
       4,   410,     6,   465,   690,   691,    10,   515,   578,   578,
      14,    15,     7,   344,     7,   346,   576,   348,   349,   350,
     566,   567,   353,  1086,   584,   650,   651,     3,     4,   578,
     579,   577,   868,   767,   820,     3,     4,     7,   566,   567,
     568,   482,     3,     4,     5,     0,   832,   863,   576,   577,
     357,   450,   414,   415,     7,   417,   584,   419,   420,     3,
       4,   356,   357,     7,     8,   721,     7,     8,   357,     7,
       3,     4,  1177,    77,   860,   861,     3,     4,   786,     6,
       3,     4,     5,   357,     3,     4,   357,   496,    32,    33,
     746,    32,    33,   344,   973,    39,    40,    41,    42,  1025,
    1148,  1149,  1150,  1151,   650,   651,    50,     7,     8,  1051,
     361,   520,   355,  1055,  1056,   344,   357,   448,  1223,     7,
       8,   355,   650,   651,   357,  1067,   369,    27,    28,    29,
      30,    31,   361,   867,   868,   369,     3,     4,     5,    27,
      28,    29,    30,    31,    32,    33,   555,     7,   479,   357,
     806,   721,     3,  1032,  1033,  1034,  1035,   566,   567,   558,
     491,   869,   870,   871,   334,   873,   874,   875,   876,   877,
     878,   355,     8,   343,     7,   356,   746,   746,     3,     4,
       7,   806,     7,   478,   909,   369,  1249,  1250,  1024,   318,
     319,   916,   720,  1241,    27,    28,    29,    30,    31,    32,
     986,     8,   910,  1019,     7,     8,     7,   538,   539,   917,
     541,   542,   326,   327,   328,   329,   330,   331,   549,     7,
       7,   552,   908,   909,  1150,  1151,     7,     8,   637,     7,
     916,  1110,     3,     4,     7,  1021,   806,     7,   360,   371,
     356,   650,   651,   375,   575,   358,   378,   379,   934,   935,
     906,   357,   583,   305,   306,   941,   942,    27,    28,    29,
      30,    31,   314,   315,   972,   316,   317,  1193,   358,   600,
     601,   408,   409,   358,   411,   412,  1218,   639,     7,   416,
       9,   643,   644,   645,   320,   321,   648,   618,  1022,  1023,
     358,  1025,   820,   863,   863,     3,     4,     5,   858,   859,
     709,     3,     4,   598,   832,    34,    35,    36,    37,    38,
    1148,  1149,  1148,   862,   863,   347,   348,   349,   649,  1037,
    1038,   652,   653,   654,   655,   829,   830,   768,   358,  1145,
     858,   859,   860,   861,   358,   744,   844,   358,   333,   334,
      34,    35,    36,    37,    38,   894,   358,   896,   343,   342,
     343,   344,   485,   486,     7,   488,   489,   490,  1066,   492,
     493,   494,   495,   363,   357,   363,   342,   363,   336,   831,
     343,   342,   342,   343,   344,  1061,   363,   786,   363,    32,
     789,    34,    35,    36,    37,    38,   363,   355,   363,   342,
     343,   344,     7,   397,   355,   333,   334,   806,   342,   343,
     344,   342,   343,   344,   357,  1191,   363,   816,   376,   363,
     343,   355,   363,   357,   547,   363,  1150,  1151,   551,   356,
     829,   830,   355,  1249,  1250,   834,   835,   363,   355,   363,
     374,   363,   355,   374,   363,   379,   355,   381,   379,   363,
     849,     8,   342,   343,   344,     6,   855,     6,     6,  1019,
    1019,  1020,   362,   345,   342,   343,   344,  1017,   986,  1193,
     869,   870,   871,   345,   873,   874,   875,   876,   877,   878,
    1019,   356,  1018,   340,   341,   356,   346,   886,   887,  1187,
    1188,   346,   342,   343,   344,   346,   374,   346,   355,  1017,
    1018,   379,   346,  1021,   346,   499,   371,   357,  1047,  1048,
     363,   910,   911,  1072,   322,   323,   324,   325,   917,   342,
     343,   344,    27,    28,    29,    30,    31,   342,   343,   344,
     363,     7,  1071,   363,   370,  1074,   370,   356,   890,   891,
     355,   337,   338,   339,   865,   356,   356,   356,  1224,   342,
     343,   344,  1050,   356,   356,   356,   379,   666,    34,    35,
      36,    37,    38,  1102,  1103,   342,   343,   344,   363,   356,
     358,   357,   893,   972,   895,   974,  1191,  1136,   363,   359,
     356,   356,   342,   343,   344,  1145,  1145,   357,   987,   350,
     351,   352,   353,   354,   355,   994,   305,   306,   307,   308,
     309,   310,   311,   312,   313,  1004,  1145,  1283,   357,   344,
     356,  1170,   721,   356,   356,   356,  1175,   356,   374,   371,
     371,   375,   366,   342,   343,   344,   374,  1166,  1167,   374,
    1029,   356,   372,   356,   342,   342,   363,   746,   632,   375,
     356,   363,   363,     6,   965,     6,   755,  1046,   372,     3,
       4,  1190,   356,     7,     8,   356,   356,  1216,   372,   356,
    1219,  1220,  1221,   356,   363,   370,   372,  1066,  1227,  1228,
    1229,  1230,  1231,  1191,  1233,   356,   372,   998,    32,    33,
     789,   372,   372,   372,   372,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    48,    49,    50,   806,   372,   342,
     343,   344,    51,    52,    53,    54,    55,    56,    57,    58,
     819,   370,   821,   822,  1253,  1254,   370,   826,  1039,   370,
     357,   356,   356,   356,   356,     3,     4,   356,  1049,     7,
       8,  1270,   356,     7,   356,   358,   379,   356,  1297,   356,
     336,  1140,   363,   363,   356,   363,   377,   363,   363,    27,
      28,    29,    30,    31,   363,  1076,   363,   363,  1157,   363,
     359,    39,    40,    41,    42,   359,   356,   344,   356,   356,
     356,   356,    50,   356,  1095,  1096,  1097,   356,   371,   371,
    1101,   363,   366,  1104,   375,   363,   375,   342,  1187,  1188,
     342,   358,  1191,   358,     3,     4,   358,   906,     7,     8,
     375,   342,   911,   342,   380,  1204,   380,  1206,  1207,  1208,
    1209,   358,   358,   371,   356,     6,   372,   371,    27,    28,
      29,    30,    31,    32,    33,   363,  1225,   363,   363,   372,
      39,    40,    41,    42,    43,    44,    45,    46,    47,    48,
      49,    50,  1163,   369,   373,   372,   369,  1168,   365,   366,
     372,   363,   373,  1252,   373,   372,   373,   372,   974,   372,
     377,   378,   379,   380,   373,   974,   342,   343,   344,   373,
     356,   373,  1271,  1272,   358,   358,   985,  1276,   358,   356,
     989,   990,   356,   356,   993,   994,   356,   356,   356,   356,
     356,   885,  1001,   356,   372,  1294,  1295,   359,  1007,   363,
       3,   322,   363,   324,   363,   363,  1305,   363,   363,   363,
     356,   332,  1311,  1029,   335,   358,   337,   338,   358,  1318,
    1029,   356,   439,   356,   345,   356,   443,     3,     4,  1328,
     356,     7,   356,   356,   373,   373,   373,   356,   356,     3,
       4,  1340,   356,   364,   365,   366,   367,   368,   373,  1058,
    1059,    27,    28,    29,    30,    31,    32,    33,   356,   334,
     380,   371,   375,    39,    40,    41,    42,    43,    44,    45,
      46,    47,    48,    49,    50,    39,    40,    41,    42,    43,
      44,    45,    46,    47,    48,    49,    50,   380,   342,   343,
     344,   380,   380,   371,   356,   371,   363,   363,   371,   356,
     374,   355,   373,   357,   356,   356,   356,   372,     3,     4,
     356,   356,     7,     8,   373,   356,  1125,   356,  1127,   356,
     374,  1130,  1131,   356,  1140,   379,  1135,   381,   356,   369,
     373,  1140,    27,    28,    29,    30,    31,    32,    33,   371,
     335,  1157,   372,   372,    39,    40,    41,    42,  1157,  1043,
     356,   356,   356,   356,   373,    50,   356,   372,   356,   373,
     373,   370,  1171,   371,   342,   343,   344,  1176,   356,   356,
     356,   373,   356,   356,   343,   356,   356,   355,   372,   357,
     356,   356,   343,   356,   356,   356,     6,   372,  1204,   356,
    1206,  1207,  1208,  1209,  1203,  1204,   356,  1206,  1207,  1208,
    1209,   356,   356,   381,    39,    40,    41,    42,    43,    44,
      45,    46,    47,    48,    49,    50,    10,    11,    12,    13,
      14,    15,    16,    17,    18,    19,    20,    21,    22,   370,
     358,   356,   356,   342,   343,   344,   356,   356,   373,   356,
     356,   375,   371,   373,   359,   356,   355,   373,   357,   356,
     356,   356,   356,   356,   372,  1271,  1272,   356,   372,  1268,
    1276,   373,  1271,  1272,  1273,   374,  1275,  1276,   358,   358,
     379,   373,   381,   373,   356,   356,   356,   356,  1294,  1295,
     356,   356,  1291,   370,   356,  1294,  1295,   373,   373,  1305,
     356,  1300,  1301,   347,   358,     0,  1305,   370,   356,   356,
     356,     6,   370,   356,   359,  1314,  1315,  1316,   356,   356,
     370,   356,  1321,  1322,   358,   356,     6,  1326,    23,    24,
      25,    26,   358,  1332,     6,   356,   359,   356,     6,   359,
    1339,   184,    18,   634,    67,    69,   641,   904,   868,   651,
     567,    23,    24,    25,    26,   395,    51,    52,    53,    54,
      55,    56,    57,    58,   868,   986,  1050,   579,   745,    -1,
      -1,   599,    -1,   375,    -1,    -1,   342,   343,   344,    51,
      52,    53,    54,    55,    56,    57,    58,   849,    -1,   355,
     464,   357,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   355,    -1,   357,    -1,    -1,    -1,    -1,   374,    -1,
      -1,    -1,    -1,   379,    -1,   381,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   381,   430,   431,
     432,   433,   434,   435,   436,   437,   438,    -1,    -1,   441,
     442,    -1,   444,   445,   446,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   342,   343,   344,
      -1,   322,    -1,   324,    -1,    -1,    -1,    -1,    -1,    -1,
     355,   332,   357,    -1,   335,    -1,   337,   338,    -1,    -1,
      -1,    -1,    -1,    -1,   345,    -1,    -1,    -1,    -1,   374,
      -1,    -1,    -1,    -1,   379,    -1,   381,    -1,    -1,    -1,
      -1,    -1,    -1,   364,   365,   366,   367,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,   357,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   605,   606,   607,    -1,    -1,   303,   304,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,   619,   620,    -1,
     622,   623,   624,   625,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,   303,   304,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,    -1,
      -1,    -1,    -1,   665,    -1,    -1,    -1,   669,    -1,    -1,
      -1,    -1,    -1,    -1,    -1,    -1,   678,    59,    60,    61,
      62,    63,    64,    65,    66,    67,    68,    69,    70,    71,
      72,    73,    74,    75,    76,    77,    78,    79,    80,    81,
      82,    83,    84,    85,    86,    87,    88,    89,    90,    91,
      92,    93,    94,    95,    96,    97,    98,    99,   100,   101,
     102,   103,   104,   105,   106,   107,   108,   109,   110,   111,
     112,   113,   114,   115,   116,   117,   118,   119,   120,   121,
     122,   123,   124,   125,   126,   127,   128,   129,   130,   131,
     132,   133,   134,   135,   136,   137,   138,   139,   140,   141,
     142,   143,   144,   145,   146,   147,   148,   149,   150,   151,
     152,   153,   154,   155,   156,   157,   158,   159,   160,   161,
     162,   163,   164,   165,   166,   167,   168,   169,   170,   171,
     172,   173,   174,   175,   176,   177,   178,   179,   180,   181,
     182,   183,   184,   185,   186,   187,   188,   189,   190,   191,
     192,   193,   194,   195,   196,   197,   198,   199,   200,   201,
     202,   203,   204,   205,   206,   207,   208,   209,   210,   211,
     212,   213,   214,   215,   216,   217,   218,   219,   220,   221,
     222,   223,   224,   225,   226,   227,   228,   229,   230,   231,
     232,   233,   234,   235,   236,   237,   238,   239,   240,   241,
     242,   243,   244,   245,   246,   247,   248,   249,   250,   251,
     252,   253,   254,   255,   256,   257,   258,   259,   260,   261,
     262,   263,   264,   265,   266,   267,   268,   269,   270,   271,
     272,   273,   274,   275,   276,   277,   278,   279,   280,   281,
     282,   283,   284,   285,   286,   287,   288,   289,   290,   291,
     292,   293,   294,   295,   296,   297,   298,   299,   300,   301,
     302
};

/* YYSTOS[STATE-NUM] -- The symbol kind of the accessing symbol of
   state STATE-NUM.  */
static const yytype_int16 yystos[] =
{
       0,   383,   384,     0,    10,    11,    12,    13,    14,    15,
      16,    17,    18,    19,    20,    21,    22,   385,   386,   388,
     389,   393,   395,   396,   397,   398,   399,   400,   401,   402,
     403,   405,     3,     4,     5,   355,   387,   357,   387,   357,
     357,   357,   387,   357,   357,   357,   387,   387,     6,    23,
      24,    25,    26,    51,    52,    53,    54,    55,    56,    57,
      58,   303,   304,   406,   407,   408,   409,   410,   411,   412,
     413,   414,   560,   563,   564,   385,     3,   356,     8,   394,
       7,     7,     8,     8,     7,     7,     7,   360,     7,   411,
      59,    60,    61,    62,    63,    64,    65,    66,    67,    68,
      69,    70,    71,    72,    73,    74,    75,    76,    77,    78,
      79,    80,    81,    82,    83,    84,    85,    86,    87,    88,
      89,    90,    91,    92,    93,    94,    95,    96,    97,    98,
      99,   100,   101,   102,   103,   104,   105,   106,   107,   108,
     109,   110,   111,   112,   113,   114,   115,   116,   117,   118,
     119,   120,   121,   122,   123,   124,   125,   126,   127,   128,
     129,   130,   131,   132,   133,   134,   135,   136,   137,   138,
     139,   140,   141,   142,   143,   144,   145,   146,   147,   148,
     149,   150,   151,   152,   153,   154,   155,   156,   157,   158,
     159,   160,   161,   162,   163,   164,   165,   166,   167,   168,
     169,   170,   171,   172,   173,   174,   175,   176,   177,   178,
     179,   180,   181,   182,   183,   184,   185,   186,   187,   188,
     189,   190,   191,   192,   193,   194,   195,   196,   197,   198,
     199,   200,   201,   202,   203,   204,   205,   206,   207,   208,
     209,   210,   211,   212,   213,   214,   215,   216,   217,   218,
     219,   220,   221,   222,   223,   224,   225,   226,   227,   228,
     229,   230,   231,   232,   233,   234,   235,   236,   237,   238,
     239,   240,   241,   242,   243,   244,   245,   246,   247,   248,
     249,   250,   251,   252,   253,   254,   255,   256,   257,   258,
     259,   260,   261,   262,   263,   264,   265,   266,   267,   268,
     269,   270,   271,   272,   273,   274,   275,   276,   277,   278,
     279,   280,   281,   282,   283,   284,   285,   286,   287,   288,
     289,   290,   291,   292,   293,   294,   295,   296,   297,   298,
     299,   300,   301,   302,   418,   433,   435,   438,   440,   442,
     444,   446,   449,   451,   452,   453,   454,   456,   459,   460,
     461,   462,   463,   464,   465,   466,   467,   468,   477,   488,
     497,   503,   505,   507,   509,   510,   511,   512,   513,   514,
     515,   516,   517,   518,   519,   521,   522,   526,   527,   528,
     529,   530,   531,   533,   535,   539,   541,   543,   544,   547,
     550,   558,   413,   356,   561,   562,   387,   358,   357,   392,
     358,   358,   358,   358,   358,   358,   358,   419,   420,   421,
     363,   423,   424,   425,   426,   427,   428,   429,   363,   430,
     431,   363,   343,   342,   363,   363,   363,   363,   363,   363,
     489,   490,   491,   493,   492,   498,   499,   501,   500,   504,
     508,   494,   502,   506,   495,   536,   537,   540,   542,   548,
     549,   559,     7,    32,    34,    35,    36,    37,    38,   342,
     343,   344,   379,   570,   572,   573,   574,   588,   574,   363,
     574,   574,   574,   574,   363,   457,   574,   363,   469,   470,
     363,   470,   470,   363,   478,   478,   478,   363,   480,   478,
     478,   480,   478,   478,   478,   478,   363,     7,   561,   356,
     387,     8,   387,   390,   391,     6,     6,     6,   344,   361,
     415,   415,   415,     3,     4,   355,   594,   595,   415,   415,
     362,   417,   417,   417,   415,   417,   345,   417,   417,   345,
     356,   356,   346,   346,   346,   346,   346,   346,   480,   480,
     480,   480,   480,   480,   480,   480,   480,   478,   371,   480,
     480,   478,   480,   480,   480,   363,   574,   363,   545,   546,
     546,   363,   370,   370,   573,   570,   356,   356,   356,   326,
     327,   328,   329,   330,   331,   455,   356,   356,   356,   356,
     318,   319,   363,   458,   356,   322,   324,   332,   335,   337,
     338,   345,   364,   365,   366,   367,   470,   574,   368,   357,
     473,   473,   316,   317,   363,   479,   479,   479,   305,   306,
     307,   308,   309,   310,   311,   312,   313,   597,   479,   479,
     479,   574,   479,   479,   479,   479,   336,   376,   484,   532,
     595,   387,   356,   358,   356,   357,   357,   359,   344,   356,
     356,   356,   594,   422,   356,   356,     6,   595,   432,   436,
     439,   441,   443,   445,   447,   450,   574,   574,   374,   574,
     574,   371,   371,   375,   366,   479,   372,   574,   375,   479,
     574,   374,   374,   350,   351,   352,   353,   354,   538,   595,
     356,   371,   375,   378,   379,   546,   347,   348,   349,   553,
     342,   342,     7,     8,    27,    28,    29,    30,    31,    32,
      33,    39,    40,    41,    42,    50,   342,   343,   344,   357,
     374,   379,   381,   434,   565,   566,   567,   568,   569,   571,
     575,   576,   577,   579,   580,   581,   587,   589,   590,   591,
     595,   434,    39,    40,    41,    42,    43,    44,    45,    46,
      47,    48,    49,    50,   357,   381,   576,   581,   582,   592,
     593,   595,   574,   582,   581,   576,   577,   583,   590,   592,
     577,   578,   587,   320,   321,   574,   582,   356,   470,   597,
     574,   574,   322,   323,   324,   325,   480,   480,   480,   574,
     480,   480,   480,   480,   480,   480,   363,   363,   363,   356,
     387,   391,     6,     6,   595,   417,   344,   361,   416,   416,
     417,   417,   417,   417,   574,   437,   576,   581,   591,   437,
     574,   574,   574,   574,   356,   356,   372,   356,   356,   372,
     372,   372,   372,   480,   569,   356,   372,   480,   356,   372,
     372,   480,   372,   363,   355,   369,   584,   585,   585,   370,
     370,     5,   340,   341,   355,   595,   596,   370,   370,   357,
     576,   569,   571,   590,   595,   357,   593,   592,   356,   356,
     356,   356,   356,   356,   565,   473,   358,   356,   356,   363,
     363,   363,   356,   363,   363,   363,   363,   363,   363,   484,
     336,   377,   525,   569,   595,   356,   359,   359,   356,   344,
     356,   356,   591,   356,   356,   356,   356,   371,   371,   343,
     534,   595,   375,   366,   569,   487,   576,   580,   569,   569,
     363,   369,   481,   482,   585,   375,   569,   363,   375,   534,
     534,   570,   580,   305,   306,   314,   315,   554,   555,   556,
     595,   595,   380,   380,   342,   342,   358,   358,     5,   358,
     358,   342,   342,   595,   596,   358,   595,   582,   582,   580,
     580,   577,   583,   574,   565,   333,   334,   471,   472,   475,
     565,   484,   484,   484,   371,   484,   484,   484,   484,   484,
     484,   363,   363,   363,   356,   387,   595,   595,     6,   417,
     417,   574,   577,   574,   577,   372,   372,   369,   373,   372,
     372,   481,   373,   369,   369,   483,   585,   483,   484,   569,
     373,   372,   483,   484,   372,   373,   373,   356,   373,   363,
     585,   585,   585,   585,   358,   358,   358,   356,   356,   356,
     356,   356,   356,   356,   356,   356,   363,   363,   363,   372,
     574,   520,   363,   363,   363,   363,   337,   338,   339,   524,
     484,   524,   525,   356,   358,   358,   359,   356,   356,   356,
     356,   569,   487,   595,   356,   569,   569,   373,   356,   357,
     486,   569,   569,   373,   373,   574,   356,   569,   373,   371,
     595,   356,   356,   569,   356,     3,   557,   380,   380,   380,
     380,   582,   581,   583,   592,   580,   565,   471,   472,   475,
     476,   565,   472,   476,   565,   375,   371,   371,   525,   356,
     371,   524,   524,   524,   524,   363,   523,   523,   523,   574,
     363,   374,   387,   595,   577,   577,   574,   448,   566,   594,
     482,   373,   371,   482,   482,   356,   569,   357,   569,   585,
     356,   356,   356,   484,   482,   356,   372,   373,   577,   592,
     356,   577,     9,   551,   574,   356,   584,   586,   356,   356,
     356,   356,   574,   574,   574,   373,   371,   372,   574,   577,
     577,   574,   335,   524,   372,   356,   356,   356,   356,   373,
     356,   372,   373,   373,   569,   356,   357,   569,   370,   485,
     569,   569,   371,   373,   569,   592,   496,   356,   356,   525,
     356,   356,   583,   356,   474,   567,   474,   474,   476,   565,
     476,   356,   356,   356,   372,   525,   356,   356,   356,   356,
     574,   343,     6,   577,   577,   574,   356,   592,   569,   356,
     356,   356,   592,   569,   485,   370,   358,   356,   356,   372,
     356,   356,   373,   356,   484,   484,   577,   552,   580,   591,
     476,   356,   375,   371,   569,   525,   373,   525,   525,   525,
     525,   373,   359,   356,   356,   592,   482,   592,   592,   592,
     485,   585,   595,   592,   592,   592,   592,   592,   356,   592,
     356,   372,   372,   356,   373,   356,   356,   586,   586,   595,
     577,   577,   373,   358,   358,   373,   569,   577,   525,   525,
     569,   356,   569,   525,   356,   356,   356,   356,   585,   370,
     356,   356,   373,   373,   569,   356,   525,   525,   347,   592,
     358,   370,   569,   569,   356,   356,   356,   525,   359,   370,
     595,   356,   356,   569,   569,   569,   356,   595,   370,   358,
     569,   569,   356,   569,   356,   595,   569,     6,   358,   356,
     359,   569,   595,   356,     6,   359,   184,   404
};

/* YYR1[RULE-NUM] -- Symbol kind of the left-hand side of rule RULE-NUM.  */
static const yytype_int16 yyr1[] =
{
       0,   382,   384,   383,   385,   385,   386,   386,   386,   386,
     386,   386,   386,   386,   386,   386,   386,   386,   386,   387,
     387,   387,   387,   388,   389,   390,   391,   391,   391,   392,
     392,   394,   393,   395,   396,   396,   397,   398,   399,   400,
     401,   402,   403,   404,   405,   406,   407,   408,   409,   410,
     410,   410,   410,   410,   410,   410,   410,   411,   411,   412,
     412,   413,   413,   413,   413,   413,   413,   413,   413,   413,
     413,   413,   413,   413,   413,   413,   414,   415,   415,   416,
     416,   417,   417,   418,   419,   418,   420,   418,   421,   418,
     422,   418,   423,   418,   424,   418,   425,   418,   426,   418,
     427,   418,   418,   428,   418,   418,   418,   418,   418,   418,
     418,   429,   418,   418,   418,   418,   418,   430,   418,   418,
     431,   418,   418,   418,   418,   418,   432,   418,   433,   433,
     434,   434,   436,   435,   437,   437,   437,   439,   438,   441,
     440,   443,   442,   445,   444,   447,   446,   448,   448,   450,
     449,   451,   451,   451,   451,   451,   451,   451,   451,   451,
     452,   452,   452,   452,   452,   452,   452,   452,   452,   452,
     452,   452,   452,   452,   453,   453,   453,   453,   453,   453,
     454,   454,   454,   454,   454,   454,   454,   454,   454,   454,
     454,   454,   454,   454,   454,   454,   454,   454,   454,   454,
     454,   454,   454,   454,   454,   454,   454,   455,   455,   455,
     455,   455,   455,   456,   456,   456,   457,   457,   458,   458,
     459,   459,   459,   459,   459,   459,   459,   459,   459,   459,
     459,   459,   459,   459,   459,   459,   460,   460,   460,   460,
     460,   461,   461,   462,   462,   463,   463,   463,   463,   464,
     464,   464,   464,   464,   464,   464,   464,   464,   464,   465,
     466,   466,   467,   468,   468,   468,   468,   468,   468,   468,
     468,   468,   468,   468,   468,   468,   468,   468,   468,   468,
     468,   468,   468,   468,   468,   468,   468,   468,   468,   468,
     468,   468,   468,   469,   469,   469,   469,   469,   469,   469,
     469,   469,   469,   469,   470,   470,   471,   472,   473,   474,
     475,   475,   475,   475,   476,   476,   476,   476,   477,   477,
     477,   477,   477,   477,   477,   477,   477,   478,   478,   479,
     479,   479,   479,   480,   481,   482,   482,   483,   483,   484,
     485,   485,   486,   486,   486,   486,   487,   489,   488,   490,
     488,   491,   488,   492,   488,   493,   488,   494,   488,   495,
     496,   488,   498,   497,   499,   497,   500,   497,   501,   497,
     502,   497,   504,   503,   506,   505,   508,   507,   509,   509,
     509,   509,   509,   509,   509,   509,   509,   509,   509,   510,
     510,   510,   510,   510,   510,   510,   510,   510,   510,   510,
     511,   511,   511,   511,   511,   511,   511,   511,   511,   511,
     511,   512,   513,   514,   515,   515,   515,   516,   517,   518,
     519,   519,   520,   519,   521,   521,   521,   522,   523,   523,
     524,   524,   524,   525,   525,   526,   526,   527,   527,   527,
     527,   527,   527,   527,   527,   527,   527,   527,   528,   529,
     530,   530,   530,   530,   531,   532,   532,   532,   533,   534,
     534,   534,   536,   535,   537,   535,   538,   538,   538,   538,
     538,   538,   540,   539,   542,   541,   543,   543,   543,   544,
     544,   544,   544,   544,   544,   544,   544,   544,   544,   544,
     544,   544,   544,   545,   545,   545,   545,   546,   546,   548,
     547,   549,   547,   550,   550,   550,   551,   551,   552,   552,
     553,   553,   553,   554,   554,   555,   555,   556,   556,   557,
     558,   558,   558,   558,   558,   558,   558,   559,   558,   560,
     561,   561,   562,   563,   564,   565,   566,   567,   568,   569,
     569,   569,   569,   570,   570,   570,   570,   571,   572,   572,
     572,   572,   572,   573,   573,   574,   574,   575,   575,   575,
     575,   575,   576,   576,   577,   577,   578,   578,   579,   579,
     580,   580,   581,   581,   581,   582,   582,   582,   583,   583,
     583,   584,   584,   585,   585,   586,   587,   587,   588,   588,
     589,   589,   590,   590,   591,   591,   591,   591,   591,   591,
     591,   591,   591,   591,   591,   591,   592,   592,   592,   592,
     592,   593,   593,   593,   593,   593,   593,   593,   593,   593,
     593,   593,   593,   594,   594,   595,   595,   596,   596,   597,
     597,   597,   597,   597,   597,   597,   597,   597
};

/* YYR2[RULE-NUM] -- Number of symbols on the right-hand side of rule RULE-NUM.  */
static const yytype_int8 yyr2[] =
{
       0,     2,     0,     3,     0,     2,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     2,     1,     6,    11,     1,     1,     3,     0,     3,
       0,     0,     5,     4,     4,     4,     4,     2,     2,     2,
       1,    10,    10,     1,    27,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     0,     2,     2,
       1,     2,     2,     2,     2,     2,     2,     2,     2,     1,
       1,     1,     1,     1,     1,     1,     2,     2,     1,     2,
       1,     2,     2,     1,     0,     5,     0,     7,     0,     7,
       0,     5,     0,     5,     0,     5,     0,     3,     0,     3,
       0,     3,     1,     0,     3,     1,     1,     1,     1,     1,
       1,     0,     3,     1,     1,     1,     1,     0,     3,     1,
       0,     3,     1,     1,     1,     1,     0,     5,     3,     3,
       1,     1,     0,     5,     1,     1,     2,     0,     5,     0,
       5,     0,    11,     0,    13,     0,    13,     1,     1,     0,
       9,     1,     1,     1,     1,     1,     1,     4,     4,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     4,     8,     6,     2,     2,     2,     2,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     8,     8,     8,    10,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     4,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     2,     2,     2,     2,     2,     2,     2,
       2,     2,     2,     2,     0,     2,     1,     1,     3,     1,
       1,     3,     1,     1,     1,     3,     3,     3,     5,    10,
       8,     6,     4,    10,     8,    11,     1,     2,     2,     2,
       2,     2,     2,     2,     1,     1,     2,     1,     2,     1,
       3,     0,    12,    10,     4,     2,     3,     0,    12,     0,
      11,     0,    15,     0,    12,     0,    12,     0,    12,     0,
       0,    12,     0,    12,     0,    11,     0,    12,     0,    12,
       0,    12,     0,    17,     0,    17,     0,     9,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,    20,    13,    16,     1,     1,     1,     1,     1,     1,
       9,    16,     0,    17,     1,     1,     1,     3,     0,     2,
       2,     2,     2,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
      11,    13,    14,    14,     1,     6,     8,     9,     7,     1,
       1,     3,     0,    11,     0,    11,     1,     1,     1,     1,
       1,     1,     0,    10,     0,    13,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     2,     2,     2,     2,     0,     2,     0,
       3,     0,     3,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     0,    11,     1,
       1,     2,     2,     2,     2,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     2,     1,     2,     1,     1,     1,
       1,     1,     1,     2,     1,     2,     1,     1,     1,     2,
       1,     1,     1,     1,     2,     1,     2,     1,     1,     1,
       1,     0,     2,     1,     2,     1,     5,     5,     5,     5,
       5,     5,     1,     1,     1,     3,     3,     4,     4,     3,
       3,     1,     1,     1,     1,     1,     1,     3,     1,     4,
       2,     1,     1,     1,     1,     1,     1,     1,     1,     1,
       1,     1,     1,     1,     1,     1,     2,     1,     2,     1,
       1,     1,     1,     1,     1,     1,     1,     1
};


enum { YYENOMEM = -2 };

#define yyerrok         (yyerrstatus = 0)
#define yyclearin       (yychar = YYEMPTY)

#define YYACCEPT        goto yyacceptlab
#define YYABORT         goto yyabortlab
#define YYERROR         goto yyerrorlab
#define YYNOMEM         goto yyexhaustedlab


#define YYRECOVERING()  (!!yyerrstatus)

#define YYBACKUP(Token, Value)                                    \
  do                                                              \
    if (yychar == YYEMPTY)                                        \
      {                                                           \
        yychar = (Token);                                         \
        yylval = (Value);                                         \
        YYPOPSTACK (yylen);                                       \
        yystate = *yyssp;                                         \
        goto yybackup;                                            \
      }                                                           \
    else                                                          \
      {                                                           \
        yyerror (YY_("syntax error: cannot back up")); \
        YYERROR;                                                  \
      }                                                           \
  while (0)

/* Backward compatibility with an undocumented macro.
   Use YYerror or YYUNDEF. */
#define YYERRCODE YYUNDEF


/* Enable debugging if requested.  */
#if YYDEBUG

# ifndef YYFPRINTF
#  include <stdio.h> /* INFRINGES ON USER NAME SPACE */
#  define YYFPRINTF fprintf
# endif

# define YYDPRINTF(Args)                        \
do {                                            \
  if (yydebug)                                  \
    YYFPRINTF Args;                             \
} while (0)




# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)                    \
do {                                                                      \
  if (yydebug)                                                            \
    {                                                                     \
      YYFPRINTF (stderr, "%s ", Title);                                   \
      yy_symbol_print (stderr,                                            \
                  Kind, Value); \
      YYFPRINTF (stderr, "\n");                                           \
    }                                                                     \
} while (0)


/*-----------------------------------.
| Print this symbol's value on YYO.  |
`-----------------------------------*/

static void
yy_symbol_value_print (FILE *yyo,
                       yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  FILE *yyoutput = yyo;
  YY_USE (yyoutput);
  if (!yyvaluep)
    return;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/*---------------------------.
| Print this symbol on YYO.  |
`---------------------------*/

static void
yy_symbol_print (FILE *yyo,
                 yysymbol_kind_t yykind, YYSTYPE const * const yyvaluep)
{
  YYFPRINTF (yyo, "%s %s (",
             yykind < YYNTOKENS ? "token" : "nterm", yysymbol_name (yykind));

  yy_symbol_value_print (yyo, yykind, yyvaluep);
  YYFPRINTF (yyo, ")");
}

/*------------------------------------------------------------------.
| yy_stack_print -- Print the state stack from its BOTTOM up to its |
| TOP (included).                                                   |
`------------------------------------------------------------------*/

static void
yy_stack_print (yy_state_t *yybottom, yy_state_t *yytop)
{
  YYFPRINTF (stderr, "Stack now");
  for (; yybottom <= yytop; yybottom++)
    {
      int yybot = *yybottom;
      YYFPRINTF (stderr, " %d", yybot);
    }
  YYFPRINTF (stderr, "\n");
}

# define YY_STACK_PRINT(Bottom, Top)                            \
do {                                                            \
  if (yydebug)                                                  \
    yy_stack_print ((Bottom), (Top));                           \
} while (0)


/*------------------------------------------------.
| Report that the YYRULE is going to be reduced.  |
`------------------------------------------------*/

static void
yy_reduce_print (yy_state_t *yyssp, YYSTYPE *yyvsp,
                 int yyrule)
{
  int yylno = yyrline[yyrule];
  int yynrhs = yyr2[yyrule];
  int yyi;
  YYFPRINTF (stderr, "Reducing stack by rule %d (line %d):\n",
             yyrule - 1, yylno);
  /* The symbols being reduced.  */
  for (yyi = 0; yyi < yynrhs; yyi++)
    {
      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
      yy_symbol_print (stderr,
                       YY_ACCESSING_SYMBOL (+yyssp[yyi + 1 - yynrhs]),
                       &yyvsp[(yyi + 1) - (yynrhs)]);
      YYFPRINTF (stderr, "\n");
    }
}

# define YY_REDUCE_PRINT(Rule)          \
do {                                    \
  if (yydebug)                          \
    yy_reduce_print (yyssp, yyvsp, Rule); \
} while (0)

/* Nonzero means print parse trace.  It is left uninitialized so that
   multiple parsers can coexist.  */
int yydebug;
#else /* !YYDEBUG */
# define YYDPRINTF(Args) ((void) 0)
# define YY_SYMBOL_PRINT(Title, Kind, Value, Location)
# define YY_STACK_PRINT(Bottom, Top)
# define YY_REDUCE_PRINT(Rule)
#endif /* !YYDEBUG */


/* YYINITDEPTH -- initial size of the parser's stacks.  */
#ifndef YYINITDEPTH
# define YYINITDEPTH 200
#endif

/* YYMAXDEPTH -- maximum size the stacks can grow to (effective only
   if the built-in stack extension method is used).

   Do not make this value too large; the results are undefined if
   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
   evaluated with infinite-precision integer arithmetic.  */

#ifndef YYMAXDEPTH
# define YYMAXDEPTH 10000
#endif


/* Context of a parse error.  */
typedef struct
{
  yy_state_t *yyssp;
  yysymbol_kind_t yytoken;
} yypcontext_t;

/* Put in YYARG at most YYARGN of the expected tokens given the
   current YYCTX, and return the number of tokens stored in YYARG.  If
   YYARG is null, return the number of expected tokens (guaranteed to
   be less than YYNTOKENS).  Return YYENOMEM on memory exhaustion.
   Return 0 if there are more than YYARGN expected tokens, yet fill
   YYARG up to YYARGN. */
static int
yypcontext_expected_tokens (const yypcontext_t *yyctx,
                            yysymbol_kind_t yyarg[], int yyargn)
{
  /* Actual size of YYARG. */
  int yycount = 0;
  int yyn = yypact[+*yyctx->yyssp];
  if (!yypact_value_is_default (yyn))
    {
      /* Start YYX at -YYN if negative to avoid negative indexes in
         YYCHECK.  In other words, skip the first -YYN actions for
         this state because they are default actions.  */
      int yyxbegin = yyn < 0 ? -yyn : 0;
      /* Stay within bounds of both yycheck and yytname.  */
      int yychecklim = YYLAST - yyn + 1;
      int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
      int yyx;
      for (yyx = yyxbegin; yyx < yyxend; ++yyx)
        if (yycheck[yyx + yyn] == yyx && yyx != YYSYMBOL_YYerror
            && !yytable_value_is_error (yytable[yyx + yyn]))
          {
            if (!yyarg)
              ++yycount;
            else if (yycount == yyargn)
              return 0;
            else
              yyarg[yycount++] = YY_CAST (yysymbol_kind_t, yyx);
          }
    }
  if (yyarg && yycount == 0 && 0 < yyargn)
    yyarg[0] = YYSYMBOL_YYEMPTY;
  return yycount;
}




#ifndef yystrlen
# if defined __GLIBC__ && defined _STRING_H
#  define yystrlen(S) (YY_CAST (YYPTRDIFF_T, strlen (S)))
# else
/* Return the length of YYSTR.  */
static YYPTRDIFF_T
yystrlen (const char *yystr)
{
  YYPTRDIFF_T yylen;
  for (yylen = 0; yystr[yylen]; yylen++)
    continue;
  return yylen;
}
# endif
#endif

#ifndef yystpcpy
# if defined __GLIBC__ && defined _STRING_H && defined _GNU_SOURCE
#  define yystpcpy stpcpy
# else
/* Copy YYSRC to YYDEST, returning the address of the terminating '\0' in
   YYDEST.  */
static char *
yystpcpy (char *yydest, const char *yysrc)
{
  char *yyd = yydest;
  const char *yys = yysrc;

  while ((*yyd++ = *yys++) != '\0')
    continue;

  return yyd - 1;
}
# endif
#endif

#ifndef yytnamerr
/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
   quotes and backslashes, so that it's suitable for yyerror.  The
   heuristic is that double-quoting is unnecessary unless the string
   contains an apostrophe, a comma, or backslash (other than
   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
   null, do not copy; instead, return the length of what the result
   would have been.  */
static YYPTRDIFF_T
yytnamerr (char *yyres, const char *yystr)
{
  if (*yystr == '"')
    {
      YYPTRDIFF_T yyn = 0;
      char const *yyp = yystr;
      for (;;)
        switch (*++yyp)
          {
          case '\'':
          case ',':
            goto do_not_strip_quotes;

          case '\\':
            if (*++yyp != '\\')
              goto do_not_strip_quotes;
            else
              goto append;

          append:
          default:
            if (yyres)
              yyres[yyn] = *yyp;
            yyn++;
            break;

          case '"':
            if (yyres)
              yyres[yyn] = '\0';
            return yyn;
          }
    do_not_strip_quotes: ;
    }

  if (yyres)
    return yystpcpy (yyres, yystr) - yyres;
  else
    return yystrlen (yystr);
}
#endif


static int
yy_syntax_error_arguments (const yypcontext_t *yyctx,
                           yysymbol_kind_t yyarg[], int yyargn)
{
  /* Actual size of YYARG. */
  int yycount = 0;
  /* There are many possibilities here to consider:
     - If this state is a consistent state with a default action, then
       the only way this function was invoked is if the default action
       is an error action.  In that case, don't check for expected
       tokens because there are none.
     - The only way there can be no lookahead present (in yychar) is if
       this state is a consistent state with a default action.  Thus,
       detecting the absence of a lookahead is sufficient to determine
       that there is no unexpected or expected token to report.  In that
       case, just report a simple "syntax error".
     - Don't assume there isn't a lookahead just because this state is a
       consistent state with a default action.  There might have been a
       previous inconsistent state, consistent state with a non-default
       action, or user semantic action that manipulated yychar.
     - Of course, the expected token list depends on states to have
       correct lookahead information, and it depends on the parser not
       to perform extra reductions after fetching a lookahead from the
       scanner and before detecting a syntax error.  Thus, state merging
       (from LALR or IELR) and default reductions corrupt the expected
       token list.  However, the list is correct for canonical LR with
       one exception: it will still contain any token that will not be
       accepted due to an error action in a later state.
  */
  if (yyctx->yytoken != YYSYMBOL_YYEMPTY)
    {
      int yyn;
      if (yyarg)
        yyarg[yycount] = yyctx->yytoken;
      ++yycount;
      yyn = yypcontext_expected_tokens (yyctx,
                                        yyarg ? yyarg + 1 : yyarg, yyargn - 1);
      if (yyn == YYENOMEM)
        return YYENOMEM;
      else
        yycount += yyn;
    }
  return yycount;
}

/* Copy into *YYMSG, which is of size *YYMSG_ALLOC, an error message
   about the unexpected token YYTOKEN for the state stack whose top is
   YYSSP.

   Return 0 if *YYMSG was successfully written.  Return -1 if *YYMSG is
   not large enough to hold the message.  In that case, also set
   *YYMSG_ALLOC to the required number of bytes.  Return YYENOMEM if the
   required number of bytes is too large to store.  */
static int
yysyntax_error (YYPTRDIFF_T *yymsg_alloc, char **yymsg,
                const yypcontext_t *yyctx)
{
  enum { YYARGS_MAX = 5 };
  /* Internationalized format string. */
  const char *yyformat = YY_NULLPTR;
  /* Arguments of yyformat: reported tokens (one for the "unexpected",
     one per "expected"). */
  yysymbol_kind_t yyarg[YYARGS_MAX];
  /* Cumulated lengths of YYARG.  */
  YYPTRDIFF_T yysize = 0;

  /* Actual size of YYARG. */
  int yycount = yy_syntax_error_arguments (yyctx, yyarg, YYARGS_MAX);
  if (yycount == YYENOMEM)
    return YYENOMEM;

  switch (yycount)
    {
#define YYCASE_(N, S)                       \
      case N:                               \
        yyformat = S;                       \
        break
    default: /* Avoid compiler warnings. */
      YYCASE_(0, YY_("syntax error"));
      YYCASE_(1, YY_("syntax error, unexpected %s"));
      YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
      YYCASE_(3, YY_("syntax error, unexpected %s, expecting %s or %s"));
      YYCASE_(4, YY_("syntax error, unexpected %s, expecting %s or %s or %s"));
      YYCASE_(5, YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s"));
#undef YYCASE_
    }

  /* Compute error message size.  Don't count the "%s"s, but reserve
     room for the terminator.  */
  yysize = yystrlen (yyformat) - 2 * yycount + 1;
  {
    int yyi;
    for (yyi = 0; yyi < yycount; ++yyi)
      {
        YYPTRDIFF_T yysize1
          = yysize + yytnamerr (YY_NULLPTR, yytname[yyarg[yyi]]);
        if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
          yysize = yysize1;
        else
          return YYENOMEM;
      }
  }

  if (*yymsg_alloc < yysize)
    {
      *yymsg_alloc = 2 * yysize;
      if (! (yysize <= *yymsg_alloc
             && *yymsg_alloc <= YYSTACK_ALLOC_MAXIMUM))
        *yymsg_alloc = YYSTACK_ALLOC_MAXIMUM;
      return -1;
    }

  /* Avoid sprintf, as that infringes on the user's name space.
     Don't have undefined behavior even if the translation
     produced a string with the wrong number of "%s"s.  */
  {
    char *yyp = *yymsg;
    int yyi = 0;
    while ((*yyp = *yyformat) != '\0')
      if (*yyp == '%' && yyformat[1] == 's' && yyi < yycount)
        {
          yyp += yytnamerr (yyp, yytname[yyarg[yyi++]]);
          yyformat += 2;
        }
      else
        {
          ++yyp;
          ++yyformat;
        }
  }
  return 0;
}


/*-----------------------------------------------.
| Release the memory associated to this symbol.  |
`-----------------------------------------------*/

static void
yydestruct (const char *yymsg,
            yysymbol_kind_t yykind, YYSTYPE *yyvaluep)
{
  YY_USE (yyvaluep);
  if (!yymsg)
    yymsg = "Deleting";
  YY_SYMBOL_PRINT (yymsg, yykind, yyvaluep, yylocationp);

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  YY_USE (yykind);
  YY_IGNORE_MAYBE_UNINITIALIZED_END
}


/* Lookahead token kind.  */
int yychar;

/* The semantic value of the lookahead symbol.  */
YYSTYPE yylval;
/* Number of syntax errors so far.  */
int yynerrs;




/*----------.
| yyparse.  |
`----------*/

int
yyparse (void)
{
    yy_state_fast_t yystate = 0;
    /* Number of tokens to shift before error messages enabled.  */
    int yyerrstatus = 0;

    /* Refer to the stacks through separate pointers, to allow yyoverflow
       to reallocate them elsewhere.  */

    /* Their size.  */
    YYPTRDIFF_T yystacksize = YYINITDEPTH;

    /* The state stack: array, bottom, top.  */
    yy_state_t yyssa[YYINITDEPTH];
    yy_state_t *yyss = yyssa;
    yy_state_t *yyssp = yyss;

    /* The semantic value stack: array, bottom, top.  */
    YYSTYPE yyvsa[YYINITDEPTH];
    YYSTYPE *yyvs = yyvsa;
    YYSTYPE *yyvsp = yyvs;

  int yyn;
  /* The return value of yyparse.  */
  int yyresult;
  /* Lookahead symbol kind.  */
  yysymbol_kind_t yytoken = YYSYMBOL_YYEMPTY;
  /* The variables used to return semantic value and location from the
     action routines.  */
  YYSTYPE yyval;

  /* Buffer for error messages, and its allocated size.  */
  char yymsgbuf[128];
  char *yymsg = yymsgbuf;
  YYPTRDIFF_T yymsg_alloc = sizeof yymsgbuf;

#define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))

  /* The number of symbols on the RHS of the reduced rule.
     Keep to zero when no symbol should be popped.  */
  int yylen = 0;

  YYDPRINTF ((stderr, "Starting parse\n"));

  yychar = YYEMPTY; /* Cause a token to be read.  */

  goto yysetstate;


/*------------------------------------------------------------.
| yynewstate -- push a new state, which is found in yystate.  |
`------------------------------------------------------------*/
yynewstate:
  /* In all cases, when you get here, the value and location stacks
     have just been pushed.  So pushing a state here evens the stacks.  */
  yyssp++;


/*--------------------------------------------------------------------.
| yysetstate -- set current state (the top of the stack) to yystate.  |
`--------------------------------------------------------------------*/
yysetstate:
  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
  YY_IGNORE_USELESS_CAST_BEGIN
  *yyssp = YY_CAST (yy_state_t, yystate);
  YY_IGNORE_USELESS_CAST_END
  YY_STACK_PRINT (yyss, yyssp);

  if (yyss + yystacksize - 1 <= yyssp)
#if !defined yyoverflow && !defined YYSTACK_RELOCATE
    YYNOMEM;
#else
    {
      /* Get the current used size of the three stacks, in elements.  */
      YYPTRDIFF_T yysize = yyssp - yyss + 1;

# if defined yyoverflow
      {
        /* Give user a chance to reallocate the stack.  Use copies of
           these so that the &'s don't force the real ones into
           memory.  */
        yy_state_t *yyss1 = yyss;
        YYSTYPE *yyvs1 = yyvs;

        /* Each stack pointer address is followed by the size of the
           data in use in that stack, in bytes.  This used to be a
           conditional around just the two extra args, but that might
           be undefined if yyoverflow is a macro.  */
        yyoverflow (YY_("memory exhausted"),
                    &yyss1, yysize * YYSIZEOF (*yyssp),
                    &yyvs1, yysize * YYSIZEOF (*yyvsp),
                    &yystacksize);
        yyss = yyss1;
        yyvs = yyvs1;
      }
# else /* defined YYSTACK_RELOCATE */
      /* Extend the stack our own way.  */
      if (YYMAXDEPTH <= yystacksize)
        YYNOMEM;
      yystacksize *= 2;
      if (YYMAXDEPTH < yystacksize)
        yystacksize = YYMAXDEPTH;

      {
        yy_state_t *yyss1 = yyss;
        union yyalloc *yyptr =
          YY_CAST (union yyalloc *,
                   YYSTACK_ALLOC (YY_CAST (YYSIZE_T, YYSTACK_BYTES (yystacksize))));
        if (! yyptr)
          YYNOMEM;
        YYSTACK_RELOCATE (yyss_alloc, yyss);
        YYSTACK_RELOCATE (yyvs_alloc, yyvs);
#  undef YYSTACK_RELOCATE
        if (yyss1 != yyssa)
          YYSTACK_FREE (yyss1);
      }
# endif

      yyssp = yyss + yysize - 1;
      yyvsp = yyvs + yysize - 1;

      YY_IGNORE_USELESS_CAST_BEGIN
      YYDPRINTF ((stderr, "Stack size increased to %ld\n",
                  YY_CAST (long, yystacksize)));
      YY_IGNORE_USELESS_CAST_END

      if (yyss + yystacksize - 1 <= yyssp)
        YYABORT;
    }
#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */


  if (yystate == YYFINAL)
    YYACCEPT;

  goto yybackup;


/*-----------.
| yybackup.  |
`-----------*/
yybackup:
  /* Do appropriate processing given the current state.  Read a
     lookahead token if we need one and don't already have one.  */

  /* First try to decide what to do without reference to lookahead token.  */
  yyn = yypact[yystate];
  if (yypact_value_is_default (yyn))
    goto yydefault;

  /* Not known => get a lookahead token if don't already have one.  */

  /* YYCHAR is either empty, or end-of-input, or a valid lookahead.  */
  if (yychar == YYEMPTY)
    {
      YYDPRINTF ((stderr, "Reading a token\n"));
      yychar = yylex ();
    }

  if (yychar <= YYEOF)
    {
      yychar = YYEOF;
      yytoken = YYSYMBOL_YYEOF;
      YYDPRINTF ((stderr, "Now at end of input.\n"));
    }
  else if (yychar == YYerror)
    {
      /* The scanner already issued an error message, process directly
         to error recovery.  But do not keep the error token as
         lookahead, it is too special and may lead us to an endless
         loop in error recovery. */
      yychar = YYUNDEF;
      yytoken = YYSYMBOL_YYerror;
      goto yyerrlab1;
    }
  else
    {
      yytoken = YYTRANSLATE (yychar);
      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
    }

  /* If the proper action on seeing token YYTOKEN is to reduce or to
     detect an error, take that action.  */
  yyn += yytoken;
  if (yyn < 0 || YYLAST < yyn || yycheck[yyn] != yytoken)
    goto yydefault;
  yyn = yytable[yyn];
  if (yyn <= 0)
    {
      if (yytable_value_is_error (yyn))
        goto yyerrlab;
      yyn = -yyn;
      goto yyreduce;
    }

  /* Count tokens shifted since error; after three, turn off error
     status.  */
  if (yyerrstatus)
    yyerrstatus--;

  /* Shift the lookahead token.  */
  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
  yystate = yyn;
  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END

  /* Discard the shifted token.  */
  yychar = YYEMPTY;
  goto yynewstate;


/*-----------------------------------------------------------.
| yydefault -- do the default action for the current state.  |
`-----------------------------------------------------------*/
yydefault:
  yyn = yydefact[yystate];
  if (yyn == 0)
    goto yyerrlab;
  goto yyreduce;


/*-----------------------------.
| yyreduce -- do a reduction.  |
`-----------------------------*/
yyreduce:
  /* yyn is the number of a rule to reduce with.  */
  yylen = yyr2[yyn];

  /* If YYLEN is nonzero, implement the default value of the action:
     '$$ = $1'.

     Otherwise, the following line sets YYVAL to garbage.
     This behavior is undocumented and Bison
     users should not rely upon it.  Assigning to YYVAL
     unconditionally makes the parser a bit smaller, and it avoids a
     GCC warning that YYVAL may be used uninitialized.  */
  yyval = yyvsp[1-yylen];


  YY_REDUCE_PRINT (yyn);
  switch (yyn)
    {
  case 2: /* $@1: %empty  */
#line 806 "../src/freedreno/ir3/ir3_parser.y"
                   { new_shader(); }
#line 3422 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 19: /* const_val: T_FLOAT  */
#line 825 "../src/freedreno/ir3/ir3_parser.y"
                             { (yyval.unum) = fui((yyvsp[0].flt)); }
#line 3428 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 20: /* const_val: T_INT  */
#line 826 "../src/freedreno/ir3/ir3_parser.y"
                             { (yyval.unum) = (yyvsp[0].num);      }
#line 3434 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 21: /* const_val: '-' T_INT  */
#line 827 "../src/freedreno/ir3/ir3_parser.y"
                             { (yyval.unum) = -(yyvsp[0].num);     }
#line 3440 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 22: /* const_val: T_HEX  */
#line 828 "../src/freedreno/ir3/ir3_parser.y"
                             { (yyval.unum) = (yyvsp[0].unum);      }
#line 3446 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 23: /* localsize_header: T_A_LOCALSIZE const_val ',' const_val ',' const_val  */
#line 830 "../src/freedreno/ir3/ir3_parser.y"
                                                                       {
                       variant->local_size[0] = (yyvsp[-4].unum);
                       variant->local_size[1] = (yyvsp[-2].unum);
                       variant->local_size[2] = (yyvsp[0].unum);
}
#line 3456 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 24: /* const_header: T_A_CONST '(' T_CONSTANT ')' const_val ',' const_val ',' const_val ',' const_val  */
#line 836 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                    {
                       add_const((yyvsp[-8].num), (yyvsp[-6].unum), (yyvsp[-4].unum), (yyvsp[-2].unum), (yyvsp[0].unum));
}
#line 3464 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 25: /* buf_header_init_val: const_val  */
#line 840 "../src/freedreno/ir3/ir3_parser.y"
                                { add_buf_init_val((yyvsp[0].unum)); }
#line 3470 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 29: /* buf_header_addr_reg: '(' T_CONSTANT ')'  */
#line 846 "../src/freedreno/ir3/ir3_parser.y"
                                      {
                       assert(((yyvsp[-1].num) & 0x1) == 0);  /* half-reg not allowed */
                       unsigned reg = (yyvsp[-1].num) >> 1;

                       info->buf_addr_regs[info->num_bufs - 1] = reg;
                       /* reserve space in immediates for the actual value to be plugged in later: */
                       add_const((yyvsp[-1].num), 0, 0, 0, 0);
}
#line 3483 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 31: /* $@2: %empty  */
#line 856 "../src/freedreno/ir3/ir3_parser.y"
                                     {
                       int idx = info->num_bufs++;
                       assert(idx < MAX_BUFS);
                       info->buf_sizes[idx] = (yyvsp[0].unum);
}
#line 3493 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 33: /* invocationid_header: T_A_INVOCATIONID '(' T_REGISTER ')'  */
#line 862 "../src/freedreno/ir3/ir3_parser.y"
                                                         {
                       assert(((yyvsp[-1].num) & 0x1) == 0);  /* half-reg not allowed */
                       unsigned reg = (yyvsp[-1].num) >> 1;
                       add_sysval(reg, 0x7, SYSTEM_VALUE_LOCAL_INVOCATION_ID);
}
#line 3503 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 34: /* wgid_header: T_A_WGID '(' T_REGISTER ')'  */
#line 868 "../src/freedreno/ir3/ir3_parser.y"
                                               {
                       assert(((yyvsp[-1].num) & 0x1) == 0);  /* half-reg not allowed */
                       unsigned reg = (yyvsp[-1].num) >> 1;
                       assert(variant->compiler->gen >= 5);
                       assert(reg >= regid(48, 0)); /* must be a high reg */
                       add_sysval(reg, 0x7, SYSTEM_VALUE_WORKGROUP_ID);
}
#line 3515 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 35: /* wgid_header: T_A_WGID '(' T_CONSTANT ')'  */
#line 875 "../src/freedreno/ir3/ir3_parser.y"
                                               {
                       assert(((yyvsp[-1].num) & 0x1) == 0);  /* half-reg not allowed */
                       unsigned reg = (yyvsp[-1].num) >> 1;
                       assert(variant->compiler->gen < 5);
                       info->wgid = reg;
}
#line 3526 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 36: /* numwg_header: T_A_NUMWG '(' T_CONSTANT ')'  */
#line 882 "../src/freedreno/ir3/ir3_parser.y"
                                                {
                       assert(((yyvsp[-1].num) & 0x1) == 0);  /* half-reg not allowed */
                       unsigned reg = (yyvsp[-1].num) >> 1;
                       info->numwg = reg;
                       /* reserve space in immediates for the actual value to be plugged in later: */
                       if (variant->compiler->gen >= 5)
                          add_const((yyvsp[-1].num), 0, 0, 0, 0);
}
#line 3539 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 37: /* branchstack_header: T_A_BRANCHSTACK const_val  */
#line 891 "../src/freedreno/ir3/ir3_parser.y"
                                              { variant->branchstack = (yyvsp[0].unum); }
#line 3545 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 38: /* pvtmem_header: T_A_PVTMEM const_val  */
#line 893 "../src/freedreno/ir3/ir3_parser.y"
                                    { variant->pvtmem_size = (yyvsp[0].unum); }
#line 3551 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 39: /* localmem_header: T_A_LOCALMEM const_val  */
#line 895 "../src/freedreno/ir3/ir3_parser.y"
                                        { variant->shared_size = (yyvsp[0].unum); }
#line 3557 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 40: /* earlypreamble_header: T_A_EARLYPREAMBLE  */
#line 897 "../src/freedreno/ir3/ir3_parser.y"
                                        { variant->early_preamble = 1; }
#line 3563 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 41: /* in_header: T_A_IN '(' T_REGISTER ')' T_IDENTIFIER '(' T_IDENTIFIER '=' integer ')'  */
#line 900 "../src/freedreno/ir3/ir3_parser.y"
                                                                                           { }
#line 3569 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 42: /* out_header: T_A_OUT '(' T_REGISTER ')' T_IDENTIFIER '(' T_IDENTIFIER '=' integer ')'  */
#line 902 "../src/freedreno/ir3/ir3_parser.y"
                                                                                            { }
#line 3575 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 44: /* tex_header: T_A_TEX '(' T_REGISTER ')' T_IDENTIFIER '=' integer ',' T_IDENTIFIER '=' integer ',' T_IDENTIFIER '=' integer ',' T_MOD_TEX '=' integer ',' T_IDENTIFIER '=' integer ',' T_IDENTIFIER '=' tex_header_opc  */
#line 913 "../src/freedreno/ir3/ir3_parser.y"
                                                                 { }
#line 3581 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 45: /* fullnop_start_section: T_A_FULLNOPSTART  */
#line 915 "../src/freedreno/ir3/ir3_parser.y"
                                        { is_in_fullnop_section = true; }
#line 3587 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 46: /* fullnop_end_section: T_A_FULLNOPEND  */
#line 916 "../src/freedreno/ir3/ir3_parser.y"
                                    { is_in_fullnop_section = false; }
#line 3593 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 47: /* fullsync_start_section: T_A_FULLSYNCSTART  */
#line 917 "../src/freedreno/ir3/ir3_parser.y"
                                          { is_in_fullsync_section = true; }
#line 3599 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 48: /* fullsync_end_section: T_A_FULLSYNCEND  */
#line 918 "../src/freedreno/ir3/ir3_parser.y"
                                      { is_in_fullsync_section = false; }
#line 3605 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 49: /* iflag: T_SY  */
#line 920 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.flags |= IR3_INSTR_SY; }
#line 3611 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 50: /* iflag: T_SS  */
#line 921 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.flags |= IR3_INSTR_SS; }
#line 3617 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 51: /* iflag: T_JP  */
#line 922 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.flags |= IR3_INSTR_JP; }
#line 3623 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 52: /* iflag: T_EQ_FLAG  */
#line 923 "../src/freedreno/ir3/ir3_parser.y"
                             { iflags.flags |= IR3_INSTR_EQ; }
#line 3629 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 53: /* iflag: T_SAT  */
#line 924 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.flags |= IR3_INSTR_SAT; }
#line 3635 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 54: /* iflag: T_RPT  */
#line 925 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.repeat = (yyvsp[0].num); }
#line 3641 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 55: /* iflag: T_UL  */
#line 926 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.flags |= IR3_INSTR_UL; }
#line 3647 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 56: /* iflag: T_NOP  */
#line 927 "../src/freedreno/ir3/ir3_parser.y"
                          { iflags.nop = (yyvsp[0].tok); }
#line 3653 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 66: /* instr: iflags cat5_instr  */
#line 940 "../src/freedreno/ir3/ir3_parser.y"
                                     { fixup_cat5_s2en(); }
#line 3659 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 76: /* label: T_IDENTIFIER ':'  */
#line 951 "../src/freedreno/ir3/ir3_parser.y"
                                    { new_label((yyvsp[-1].str)); }
#line 3665 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 77: /* cat0_src1: '!' T_P0  */
#line 953 "../src/freedreno/ir3/ir3_parser.y"
                                   { instr->cat0.inv1 = true; (yyval.reg) = new_src((62 << 3) + (yyvsp[0].num), IR3_REG_PREDICATE); }
#line 3671 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 78: /* cat0_src1: T_P0  */
#line 954 "../src/freedreno/ir3/ir3_parser.y"
                                   { (yyval.reg) = new_src((62 << 3) + (yyvsp[0].num), IR3_REG_PREDICATE); }
#line 3677 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 79: /* cat0_src2: '!' T_P0  */
#line 956 "../src/freedreno/ir3/ir3_parser.y"
                                   { instr->cat0.inv2 = true; (yyval.reg) = new_src((62 << 3) + (yyvsp[0].num), IR3_REG_PREDICATE); }
#line 3683 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 80: /* cat0_src2: T_P0  */
#line 957 "../src/freedreno/ir3/ir3_parser.y"
                                   { (yyval.reg) = new_src((62 << 3) + (yyvsp[0].num), IR3_REG_PREDICATE); }
#line 3689 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 81: /* cat0_immed: '#' integer  */
#line 959 "../src/freedreno/ir3/ir3_parser.y"
                                   { instr->cat0.immed = (yyvsp[0].num); }
#line 3695 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 82: /* cat0_immed: '#' T_IDENTIFIER  */
#line 960 "../src/freedreno/ir3/ir3_parser.y"
                                    { ralloc_steal(instr, (void *)(yyvsp[0].str)); instr->cat0.target_label = (yyvsp[0].str); }
#line 3701 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 83: /* cat0_instr: T_OP_NOP  */
#line 962 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_NOP); }
#line 3707 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 84: /* $@3: %empty  */
#line 963 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BR);   }
#line 3713 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 86: /* $@4: %empty  */
#line 964 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BRAO); }
#line 3719 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 88: /* $@5: %empty  */
#line 965 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BRAA); }
#line 3725 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 90: /* $@6: %empty  */
#line 966 "../src/freedreno/ir3/ir3_parser.y"
                                         { new_instr(OPC_BRAC)->cat0.idx = (yyvsp[0].num); }
#line 3731 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 92: /* $@7: %empty  */
#line 967 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BANY); }
#line 3737 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 94: /* $@8: %empty  */
#line 968 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BALL); }
#line 3743 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 96: /* $@9: %empty  */
#line 969 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BRAX); }
#line 3749 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 98: /* $@10: %empty  */
#line 970 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_JUMP); }
#line 3755 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 100: /* $@11: %empty  */
#line 971 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_CALL); }
#line 3761 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 102: /* cat0_instr: T_OP_RET  */
#line 972 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_RET); }
#line 3767 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 103: /* $@12: %empty  */
#line 973 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_KILL); }
#line 3773 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 105: /* cat0_instr: T_OP_END  */
#line 974 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_END); }
#line 3779 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 106: /* cat0_instr: T_OP_EMIT  */
#line 975 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_EMIT); }
#line 3785 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 107: /* cat0_instr: T_OP_CUT  */
#line 976 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_CUT); }
#line 3791 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 108: /* cat0_instr: T_OP_CHMASK  */
#line 977 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_CHMASK); }
#line 3797 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 109: /* cat0_instr: T_OP_CHSH  */
#line 978 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_CHSH); }
#line 3803 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 110: /* cat0_instr: T_OP_FLOW_REV  */
#line 979 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_FLOW_REV); }
#line 3809 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 111: /* $@13: %empty  */
#line 980 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_BKT); }
#line 3815 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 113: /* cat0_instr: T_OP_STKS  */
#line 981 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_STKS); }
#line 3821 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 114: /* cat0_instr: T_OP_STKR  */
#line 982 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_STKR); }
#line 3827 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 115: /* cat0_instr: T_OP_XSET  */
#line 983 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_XSET); }
#line 3833 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 116: /* cat0_instr: T_OP_XCLR  */
#line 984 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_XCLR); }
#line 3839 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 117: /* $@14: %empty  */
#line 985 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_GETONE); }
#line 3845 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 119: /* cat0_instr: T_OP_DBG  */
#line 986 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_DBG); }
#line 3851 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 120: /* $@15: %empty  */
#line 987 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_SHPS); }
#line 3857 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 122: /* cat0_instr: T_OP_SHPE  */
#line 988 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_SHPE); }
#line 3863 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 123: /* cat0_instr: T_OP_PREDT  */
#line 989 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_PREDT); }
#line 3869 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 124: /* cat0_instr: T_OP_PREDF  */
#line 990 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_PREDF); }
#line 3875 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 125: /* cat0_instr: T_OP_PREDE  */
#line 991 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_PREDE); }
#line 3881 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 126: /* $@16: %empty  */
#line 992 "../src/freedreno/ir3/ir3_parser.y"
                                        { new_instr(OPC_GETLAST); }
#line 3887 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 128: /* cat1_opc: T_OP_MOV '.' T_CAT1_TYPE_TYPE  */
#line 994 "../src/freedreno/ir3/ir3_parser.y"
                                                 {
                       parse_type_type(new_instr(OPC_MOV), (yyvsp[0].str));
}
#line 3895 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 129: /* cat1_opc: T_OP_COV '.' T_CAT1_TYPE_TYPE  */
#line 997 "../src/freedreno/ir3/ir3_parser.y"
                                                 {
                       parse_type_type(new_instr(OPC_MOV), (yyvsp[0].str));
}
#line 3903 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 132: /* $@17: %empty  */
#line 1004 "../src/freedreno/ir3/ir3_parser.y"
                                       {
                       new_instr(OPC_MOVMSK);
                       instr->cat1.src_type = TYPE_U32;
                       instr->cat1.dst_type = TYPE_U32;
                   }
#line 3913 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 133: /* cat1_movmsk: T_OP_MOVMSK '.' T_W $@17 dst_reg  */
#line 1008 "../src/freedreno/ir3/ir3_parser.y"
                             {
                       if (((yyvsp[-2].num) % 32) != 0)
                          yyerror("w# must be multiple of 32");
                       if ((yyvsp[-2].num) < 32)
                          yyerror("w# must be at least 32");

                       int num = (yyvsp[-2].num) / 32;

                       instr->repeat = num - 1;
                       instr->dsts[0]->wrmask = (1 << num) - 1;
                   }
#line 3929 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 137: /* $@18: %empty  */
#line 1024 "../src/freedreno/ir3/ir3_parser.y"
                                       {
                       new_instr(OPC_MOV);
                       instr->cat1.src_type = TYPE_U16;
                       instr->cat1.dst_type = TYPE_U16;
                       new_dst((61 << 3) + 2, IR3_REG_HALF);
                   }
#line 3940 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 139: /* $@19: %empty  */
#line 1031 "../src/freedreno/ir3/ir3_parser.y"
                                      {
                       new_instr(OPC_MOV);
                       instr->cat1.src_type = TYPE_S16;
                       instr->cat1.dst_type = TYPE_S16;
                       new_dst((61 << 3), IR3_REG_HALF);
                   }
#line 3951 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 141: /* $@20: %empty  */
#line 1038 "../src/freedreno/ir3/ir3_parser.y"
                                                 { parse_type_type(new_instr(OPC_SWZ), (yyvsp[0].str)); }
#line 3957 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 143: /* $@21: %empty  */
#line 1040 "../src/freedreno/ir3/ir3_parser.y"
                                                 { parse_type_type(new_instr(OPC_GAT), (yyvsp[0].str)); }
#line 3963 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 145: /* $@22: %empty  */
#line 1042 "../src/freedreno/ir3/ir3_parser.y"
                                                 { parse_type_type(new_instr(OPC_SCT), (yyvsp[0].str)); }
#line 3969 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 147: /* movs_invocation: uinteger  */
#line 1044 "../src/freedreno/ir3/ir3_parser.y"
                          { new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[0].num); }
#line 3975 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 149: /* $@23: %empty  */
#line 1047 "../src/freedreno/ir3/ir3_parser.y"
                                          { parse_type_type(new_instr(OPC_MOVS), (yyvsp[0].str)); }
#line 3981 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 160: /* cat2_opc_1src: T_OP_ABSNEG_F  */
#line 1060 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ABSNEG_F); }
#line 3987 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 161: /* cat2_opc_1src: T_OP_ABSNEG_S  */
#line 1061 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ABSNEG_S); }
#line 3993 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 162: /* cat2_opc_1src: T_OP_CLZ_B  */
#line 1062 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CLZ_B); }
#line 3999 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 163: /* cat2_opc_1src: T_OP_CLZ_S  */
#line 1063 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CLZ_S); }
#line 4005 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 164: /* cat2_opc_1src: T_OP_SIGN_F  */
#line 1064 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SIGN_F); }
#line 4011 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 165: /* cat2_opc_1src: T_OP_FLOOR_F  */
#line 1065 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_FLOOR_F); }
#line 4017 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 166: /* cat2_opc_1src: T_OP_CEIL_F  */
#line 1066 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CEIL_F); }
#line 4023 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 167: /* cat2_opc_1src: T_OP_RNDNE_F  */
#line 1067 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RNDNE_F); }
#line 4029 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 168: /* cat2_opc_1src: T_OP_RNDAZ_F  */
#line 1068 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RNDAZ_F); }
#line 4035 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 169: /* cat2_opc_1src: T_OP_TRUNC_F  */
#line 1069 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_TRUNC_F); }
#line 4041 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 170: /* cat2_opc_1src: T_OP_NOT_B  */
#line 1070 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_NOT_B); }
#line 4047 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 171: /* cat2_opc_1src: T_OP_BFREV_B  */
#line 1071 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_BFREV_B); }
#line 4053 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 172: /* cat2_opc_1src: T_OP_SETRM  */
#line 1072 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SETRM); }
#line 4059 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 173: /* cat2_opc_1src: T_OP_CBITS_B  */
#line 1073 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CBITS_B); }
#line 4065 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 174: /* cat2_opc_2src_cnd: T_OP_CMPS_F  */
#line 1075 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CMPS_F); }
#line 4071 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 175: /* cat2_opc_2src_cnd: T_OP_CMPS_U  */
#line 1076 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CMPS_U); }
#line 4077 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 176: /* cat2_opc_2src_cnd: T_OP_CMPS_S  */
#line 1077 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CMPS_S); }
#line 4083 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 177: /* cat2_opc_2src_cnd: T_OP_CMPV_F  */
#line 1078 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CMPV_F); }
#line 4089 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 178: /* cat2_opc_2src_cnd: T_OP_CMPV_U  */
#line 1079 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CMPV_U); }
#line 4095 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 179: /* cat2_opc_2src_cnd: T_OP_CMPV_S  */
#line 1080 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CMPV_S); }
#line 4101 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 180: /* cat2_opc_2src: T_OP_ADD_F  */
#line 1082 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ADD_F); }
#line 4107 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 181: /* cat2_opc_2src: T_OP_MIN_F  */
#line 1083 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MIN_F); }
#line 4113 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 182: /* cat2_opc_2src: T_OP_MAX_F  */
#line 1084 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAX_F); }
#line 4119 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 183: /* cat2_opc_2src: T_OP_MUL_F  */
#line 1085 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MUL_F); }
#line 4125 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 184: /* cat2_opc_2src: T_OP_ADD_U  */
#line 1086 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ADD_U); }
#line 4131 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 185: /* cat2_opc_2src: T_OP_ADD_S  */
#line 1087 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ADD_S); }
#line 4137 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 186: /* cat2_opc_2src: T_OP_SUB_U  */
#line 1088 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SUB_U); }
#line 4143 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 187: /* cat2_opc_2src: T_OP_SUB_S  */
#line 1089 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SUB_S); }
#line 4149 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 188: /* cat2_opc_2src: T_OP_MIN_U  */
#line 1090 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MIN_U); }
#line 4155 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 189: /* cat2_opc_2src: T_OP_MIN_S  */
#line 1091 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MIN_S); }
#line 4161 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 190: /* cat2_opc_2src: T_OP_MAX_U  */
#line 1092 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAX_U); }
#line 4167 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 191: /* cat2_opc_2src: T_OP_MAX_S  */
#line 1093 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAX_S); }
#line 4173 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 192: /* cat2_opc_2src: T_OP_AND_B  */
#line 1094 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_AND_B); }
#line 4179 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 193: /* cat2_opc_2src: T_OP_OR_B  */
#line 1095 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_OR_B); }
#line 4185 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 194: /* cat2_opc_2src: T_OP_XOR_B  */
#line 1096 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_XOR_B); }
#line 4191 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 195: /* cat2_opc_2src: T_OP_MUL_U24  */
#line 1097 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MUL_U24); }
#line 4197 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 196: /* cat2_opc_2src: T_OP_MUL_S24  */
#line 1098 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MUL_S24); }
#line 4203 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 197: /* cat2_opc_2src: T_OP_MULL_U  */
#line 1099 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MULL_U); }
#line 4209 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 198: /* cat2_opc_2src: T_OP_SHL_B  */
#line 1100 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHL_B); }
#line 4215 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 199: /* cat2_opc_2src: T_OP_SHR_B  */
#line 1101 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHR_B); }
#line 4221 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 200: /* cat2_opc_2src: T_OP_ASHR_B  */
#line 1102 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ASHR_B); }
#line 4227 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 201: /* cat2_opc_2src: T_OP_BARY_F  */
#line 1103 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_BARY_F); }
#line 4233 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 202: /* cat2_opc_2src: T_OP_FLAT_B  */
#line 1104 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_FLAT_B); }
#line 4239 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 203: /* cat2_opc_2src: T_OP_MGEN_B  */
#line 1105 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MGEN_B); }
#line 4245 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 204: /* cat2_opc_2src: T_OP_GETBIT_B  */
#line 1106 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GETBIT_B); }
#line 4251 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 205: /* cat2_opc_2src: T_OP_SHB  */
#line 1107 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHB); }
#line 4257 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 206: /* cat2_opc_2src: T_OP_MSAD  */
#line 1108 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MSAD); }
#line 4263 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 207: /* cond: T_LT  */
#line 1110 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat2.condition = IR3_COND_LT; }
#line 4269 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 208: /* cond: T_LE  */
#line 1111 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat2.condition = IR3_COND_LE; }
#line 4275 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 209: /* cond: T_GT  */
#line 1112 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat2.condition = IR3_COND_GT; }
#line 4281 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 210: /* cond: T_GE  */
#line 1113 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat2.condition = IR3_COND_GE; }
#line 4287 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 211: /* cond: T_EQ  */
#line 1114 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat2.condition = IR3_COND_EQ; }
#line 4293 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 212: /* cond: T_NE  */
#line 1115 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat2.condition = IR3_COND_NE; }
#line 4299 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 216: /* cat3_dp_signedness: '.' T_MIXED  */
#line 1121 "../src/freedreno/ir3/ir3_parser.y"
                                 { instr->cat3.signedness = IR3_SRC_MIXED; }
#line 4305 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 217: /* cat3_dp_signedness: '.' T_UNSIGNED  */
#line 1122 "../src/freedreno/ir3/ir3_parser.y"
                                 { instr->cat3.signedness = IR3_SRC_UNSIGNED; }
#line 4311 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 218: /* cat3_dp_pack: '.' T_LOW  */
#line 1124 "../src/freedreno/ir3/ir3_parser.y"
                                 { instr->cat3.packed = IR3_SRC_PACKED_LOW; }
#line 4317 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 219: /* cat3_dp_pack: '.' T_HIGH  */
#line 1125 "../src/freedreno/ir3/ir3_parser.y"
                                 { instr->cat3.packed = IR3_SRC_PACKED_HIGH; }
#line 4323 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 220: /* cat3_opc: T_OP_MAD_U16  */
#line 1127 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAD_U16); }
#line 4329 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 221: /* cat3_opc: T_OP_MADSH_U16  */
#line 1128 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MADSH_U16); }
#line 4335 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 222: /* cat3_opc: T_OP_MAD_S16  */
#line 1129 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAD_S16); }
#line 4341 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 223: /* cat3_opc: T_OP_MADSH_M16  */
#line 1130 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MADSH_M16); }
#line 4347 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 224: /* cat3_opc: T_OP_MAD_U24  */
#line 1131 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAD_U24); }
#line 4353 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 225: /* cat3_opc: T_OP_MAD_S24  */
#line 1132 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAD_S24); }
#line 4359 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 226: /* cat3_opc: T_OP_MAD_F16  */
#line 1133 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAD_F16); }
#line 4365 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 227: /* cat3_opc: T_OP_MAD_F32  */
#line 1134 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_MAD_F32); }
#line 4371 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 228: /* cat3_opc: T_OP_SEL_B16  */
#line 1135 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SEL_B16); }
#line 4377 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 229: /* cat3_opc: T_OP_SEL_B32  */
#line 1136 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SEL_B32); }
#line 4383 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 230: /* cat3_opc: T_OP_SEL_S16  */
#line 1137 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SEL_S16); }
#line 4389 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 231: /* cat3_opc: T_OP_SEL_S32  */
#line 1138 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SEL_S32); }
#line 4395 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 232: /* cat3_opc: T_OP_SEL_F16  */
#line 1139 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SEL_F16); }
#line 4401 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 233: /* cat3_opc: T_OP_SEL_F32  */
#line 1140 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SEL_F32); }
#line 4407 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 234: /* cat3_opc: T_OP_SAD_S16  */
#line 1141 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAD_S16); }
#line 4413 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 235: /* cat3_opc: T_OP_SAD_S32  */
#line 1142 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAD_S32); }
#line 4419 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 236: /* cat3_imm_reg_opc: T_OP_SHRM  */
#line 1144 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHRM); }
#line 4425 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 237: /* cat3_imm_reg_opc: T_OP_SHLM  */
#line 1145 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHLM); }
#line 4431 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 238: /* cat3_imm_reg_opc: T_OP_SHRG  */
#line 1146 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHRG); }
#line 4437 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 239: /* cat3_imm_reg_opc: T_OP_SHLG  */
#line 1147 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SHLG); }
#line 4443 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 240: /* cat3_imm_reg_opc: T_OP_ANDG  */
#line 1148 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ANDG); }
#line 4449 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 241: /* cat3_wmm: T_OP_WMM  */
#line 1150 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_WMM); }
#line 4455 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 242: /* cat3_wmm: T_OP_WMM_ACCU  */
#line 1151 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_WMM_ACCU); }
#line 4461 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 243: /* cat3_dp: T_OP_DP2ACC  */
#line 1153 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_DP2ACC); }
#line 4467 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 244: /* cat3_dp: T_OP_DP4ACC  */
#line 1154 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_DP4ACC); }
#line 4473 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 249: /* cat4_opc: T_OP_RCP  */
#line 1161 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RCP); }
#line 4479 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 250: /* cat4_opc: T_OP_RSQ  */
#line 1162 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RSQ); }
#line 4485 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 251: /* cat4_opc: T_OP_LOG2  */
#line 1163 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_LOG2); }
#line 4491 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 252: /* cat4_opc: T_OP_EXP2  */
#line 1164 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_EXP2); }
#line 4497 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 253: /* cat4_opc: T_OP_SIN  */
#line 1165 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SIN); }
#line 4503 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 254: /* cat4_opc: T_OP_COS  */
#line 1166 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_COS); }
#line 4509 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 255: /* cat4_opc: T_OP_SQRT  */
#line 1167 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SQRT); }
#line 4515 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 256: /* cat4_opc: T_OP_HRSQ  */
#line 1168 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_HRSQ); }
#line 4521 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 257: /* cat4_opc: T_OP_HLOG2  */
#line 1169 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_HLOG2); }
#line 4527 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 258: /* cat4_opc: T_OP_HEXP2  */
#line 1170 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_HEXP2); }
#line 4533 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 260: /* cat5_opc_dsxypp: T_OP_DSXPP_1  */
#line 1174 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_DSXPP_1)->cat5.type = TYPE_F32; }
#line 4539 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 261: /* cat5_opc_dsxypp: T_OP_DSYPP_1  */
#line 1175 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_DSYPP_1)->cat5.type = TYPE_F32; }
#line 4545 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 262: /* cat5_opc_isam: T_OP_ISAM  */
#line 1177 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ISAM)->flags |= IR3_INSTR_INV_1D; }
#line 4551 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 263: /* cat5_opc: T_OP_ISAML  */
#line 1179 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ISAML); }
#line 4557 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 264: /* cat5_opc: T_OP_ISAMM  */
#line 1180 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_ISAMM); }
#line 4563 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 265: /* cat5_opc: T_OP_SAM  */
#line 1181 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAM); }
#line 4569 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 266: /* cat5_opc: T_OP_SAMB  */
#line 1182 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAMB); }
#line 4575 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 267: /* cat5_opc: T_OP_SAML  */
#line 1183 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAML); }
#line 4581 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 268: /* cat5_opc: T_OP_SAMGQ  */
#line 1184 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAMGQ); }
#line 4587 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 269: /* cat5_opc: T_OP_GETLOD  */
#line 1185 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GETLOD); }
#line 4593 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 270: /* cat5_opc: T_OP_CONV  */
#line 1186 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CONV); }
#line 4599 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 271: /* cat5_opc: T_OP_CONVM  */
#line 1187 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_CONVM); }
#line 4605 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 272: /* cat5_opc: T_OP_GETSIZE  */
#line 1188 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GETSIZE); }
#line 4611 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 273: /* cat5_opc: T_OP_GETBUF  */
#line 1189 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GETBUF); }
#line 4617 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 274: /* cat5_opc: T_OP_GETPOS  */
#line 1190 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GETPOS); }
#line 4623 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 275: /* cat5_opc: T_OP_GETINFO  */
#line 1191 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GETINFO); }
#line 4629 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 276: /* cat5_opc: T_OP_DSX  */
#line 1192 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_DSX); }
#line 4635 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 277: /* cat5_opc: T_OP_DSY  */
#line 1193 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_DSY); }
#line 4641 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 278: /* cat5_opc: T_OP_GATHER4R  */
#line 1194 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GATHER4R); }
#line 4647 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 279: /* cat5_opc: T_OP_GATHER4G  */
#line 1195 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GATHER4G); }
#line 4653 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 280: /* cat5_opc: T_OP_GATHER4B  */
#line 1196 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GATHER4B); }
#line 4659 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 281: /* cat5_opc: T_OP_GATHER4A  */
#line 1197 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_GATHER4A); }
#line 4665 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 282: /* cat5_opc: T_OP_SAMGP0  */
#line 1198 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAMGP0); }
#line 4671 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 283: /* cat5_opc: T_OP_SAMGP1  */
#line 1199 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAMGP1); }
#line 4677 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 284: /* cat5_opc: T_OP_SAMGP2  */
#line 1200 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAMGP2); }
#line 4683 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 285: /* cat5_opc: T_OP_SAMGP3  */
#line 1201 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_SAMGP3); }
#line 4689 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 286: /* cat5_opc: T_OP_RGETPOS  */
#line 1202 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RGETPOS); }
#line 4695 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 287: /* cat5_opc: T_OP_RGETINFO  */
#line 1203 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RGETINFO); }
#line 4701 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 288: /* cat5_opc: T_OP_BRCST_A  */
#line 1204 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_BRCST_ACTIVE); }
#line 4707 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 289: /* cat5_opc: T_OP_QSHUFFLE_BRCST  */
#line 1205 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_QUAD_SHUFFLE_BRCST); }
#line 4713 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 290: /* cat5_opc: T_OP_QSHUFFLE_H  */
#line 1206 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_QUAD_SHUFFLE_HORIZ); }
#line 4719 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 291: /* cat5_opc: T_OP_QSHUFFLE_V  */
#line 1207 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_QUAD_SHUFFLE_VERT); }
#line 4725 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 292: /* cat5_opc: T_OP_QSHUFFLE_DIAG  */
#line 1208 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_QUAD_SHUFFLE_DIAG); }
#line 4731 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 293: /* cat5_flag: '.' T_3D  */
#line 1210 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_3D; }
#line 4737 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 294: /* cat5_flag: '.' 'a'  */
#line 1211 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_A; }
#line 4743 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 295: /* cat5_flag: '.' 'o'  */
#line 1212 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_O; }
#line 4749 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 296: /* cat5_flag: '.' 'p'  */
#line 1213 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_P; }
#line 4755 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 297: /* cat5_flag: '.' 's'  */
#line 1214 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_S; }
#line 4761 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 298: /* cat5_flag: '.' T_S2EN  */
#line 1215 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_S2EN; }
#line 4767 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 299: /* cat5_flag: '.' T_1D  */
#line 1216 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags &= ~IR3_INSTR_INV_1D; }
#line 4773 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 300: /* cat5_flag: '.' T_UNIFORM  */
#line 1217 "../src/freedreno/ir3/ir3_parser.y"
                                  { }
#line 4779 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 301: /* cat5_flag: '.' T_NONUNIFORM  */
#line 1218 "../src/freedreno/ir3/ir3_parser.y"
                                     { instr->flags |= IR3_INSTR_NONUNIF; }
#line 4785 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 302: /* cat5_flag: '.' T_BASE  */
#line 1219 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_B; instr->cat5.tex_base = (yyvsp[0].tok); }
#line 4791 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 303: /* cat5_flag: '.' T_W  */
#line 1220 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat5.cluster_size = (yyvsp[0].num); }
#line 4797 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 306: /* cat5_samp: T_SAMP  */
#line 1224 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat5.samp = (yyvsp[0].tok); }
#line 4803 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 307: /* cat5_tex: T_TEX  */
#line 1225 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat5.tex = (yyvsp[0].tok); }
#line 4809 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 308: /* cat5_type: '(' type ')'  */
#line 1226 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat5.type = (yyvsp[-1].type); }
#line 4815 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 309: /* cat5_a1: src_a1  */
#line 1227 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->flags |= IR3_INSTR_A1EN; }
#line 4821 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 325: /* cat5_instr: cat5_opc_isam '.' 'v' cat5_flags cat5_type dst_reg ',' src_gpr src_uoffset ',' cat5_samp_tex_all  */
#line 1246 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                                    { instr->flags |= IR3_INSTR_V; }
#line 4827 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 326: /* cat5_instr: T_OP_TCINV  */
#line 1247 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_TCINV); }
#line 4833 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 327: /* cat6_typed: '.' T_UNTYPED  */
#line 1249 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat6.typed = 0; }
#line 4839 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 328: /* cat6_typed: '.' T_TYPED  */
#line 1250 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat6.typed = 1; }
#line 4845 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 329: /* cat6_dim: '.' T_1D  */
#line 1252 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.d = 1; }
#line 4851 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 330: /* cat6_dim: '.' T_2D  */
#line 1253 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.d = 2; }
#line 4857 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 331: /* cat6_dim: '.' T_3D  */
#line 1254 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.d = 3; }
#line 4863 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 332: /* cat6_dim: '.' T_4D  */
#line 1255 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.d = 4; }
#line 4869 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 333: /* cat6_type: '.' type  */
#line 1257 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.type = (yyvsp[0].type); }
#line 4875 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 334: /* cat6_imm_offset: offset  */
#line 1258 "../src/freedreno/ir3/ir3_parser.y"
                             { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[0].num); }
#line 4881 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 337: /* cat6_dst_offset: offset  */
#line 1261 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.dst_offset = (yyvsp[0].num); }
#line 4887 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 339: /* cat6_immed: integer  */
#line 1264 "../src/freedreno/ir3/ir3_parser.y"
                             { instr->cat6.iim_val = (yyvsp[0].num); }
#line 4893 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 340: /* cat6_src_shift: '<' '<' integer  */
#line 1266 "../src/freedreno/ir3/ir3_parser.y"
                                {(yyval.unum) = (yyvsp[0].num);}
#line 4899 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 341: /* cat6_src_shift: %empty  */
#line 1267 "../src/freedreno/ir3/ir3_parser.y"
                                {(yyval.unum) = 0;}
#line 4905 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 342: /* cat6_a6xx_global_address_pt2: '(' '(' '(' src cat6_src_shift ')' offset ')' '<' '<' integer ')'  */
#line 1270 "../src/freedreno/ir3/ir3_parser.y"
                                                                                     {
                        illegal_syntax_from(7, "pre-a7xx global offset syntax");
                        new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[-7].unum);
                        new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[-5].num);
                   }
#line 4915 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 343: /* cat6_a6xx_global_address_pt2: '(' '(' src cat6_src_shift offset ')' '<' '<' integer ')'  */
#line 1275 "../src/freedreno/ir3/ir3_parser.y"
                                                                             {
                        illegal_syntax_from(7, "pre-a7xx global offset syntax");
                        new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[-6].unum);
                        new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[-5].num);
                   }
#line 4925 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 344: /* cat6_a6xx_global_address_pt2: '(' src cat6_src_shift ')'  */
#line 1280 "../src/freedreno/ir3/ir3_parser.y"
                                              {
                        illegal_syntax_from(7, "pre-a7xx global offset syntax");
                        // The shift contains the implicit type shift, subtract it.
                        new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[-1].unum) - cat6_type_shift();
                        new_src(0, IR3_REG_IMMED)->uim_val = 0;
                   }
#line 4936 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 345: /* cat6_a6xx_global_address_pt2: src offset  */
#line 1286 "../src/freedreno/ir3/ir3_parser.y"
                              {
                        if (variant->compiler->gen < 7) {
                            new_src(0, IR3_REG_IMMED)->uim_val = 0;
                            new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[0].num);
                        } else {
                            new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[0].num);
                            // Dummy src to smooth the difference between a6xx and a7xx
                            new_src(0, IR3_REG_IMMED)->uim_val = 0;
                        }
                   }
#line 4951 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 347: /* $@24: %empty  */
#line 1300 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDG); }
#line 4957 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 349: /* $@25: %empty  */
#line 1301 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDG_A); }
#line 4963 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 351: /* $@26: %empty  */
#line 1302 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDG_K); }
#line 4969 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 353: /* $@27: %empty  */
#line 1303 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDP); }
#line 4975 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 355: /* $@28: %empty  */
#line 1304 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDL); }
#line 4981 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 357: /* $@29: %empty  */
#line 1305 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDLW); }
#line 4987 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 359: /* $@30: %empty  */
#line 1306 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_LDLV); }
#line 4993 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 360: /* $@31: %empty  */
#line 1306 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                  {
                       new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[-1].num);
                   }
#line 5001 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 362: /* $@32: %empty  */
#line 1310 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_STG); dummy_dst(); }
#line 5007 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 364: /* $@33: %empty  */
#line 1311 "../src/freedreno/ir3/ir3_parser.y"
                              { new_instr(OPC_STG_A); dummy_dst(); }
#line 5013 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 366: /* $@34: %empty  */
#line 1312 "../src/freedreno/ir3/ir3_parser.y"
                             { new_instr(OPC_STP); dummy_dst(); }
#line 5019 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 368: /* $@35: %empty  */
#line 1313 "../src/freedreno/ir3/ir3_parser.y"
                             { new_instr(OPC_STL); dummy_dst(); }
#line 5025 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 370: /* $@36: %empty  */
#line 1314 "../src/freedreno/ir3/ir3_parser.y"
                             { new_instr(OPC_STLW); dummy_dst(); }
#line 5031 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 372: /* $@37: %empty  */
#line 1316 "../src/freedreno/ir3/ir3_parser.y"
                             { new_instr(OPC_LDIB); }
#line 5037 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 374: /* $@38: %empty  */
#line 1317 "../src/freedreno/ir3/ir3_parser.y"
                             { new_instr(OPC_STIB); dummy_dst(); }
#line 5043 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 376: /* $@39: %empty  */
#line 1319 "../src/freedreno/ir3/ir3_parser.y"
                                 { new_instr(OPC_PREFETCH); new_dst(0,0); /* dummy dst */ }
#line 5049 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 378: /* cat6_atomic_opc: T_OP_ATOMIC_ADD  */
#line 1321 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_ADD); }
#line 5055 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 379: /* cat6_atomic_opc: T_OP_ATOMIC_SUB  */
#line 1322 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_SUB); }
#line 5061 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 380: /* cat6_atomic_opc: T_OP_ATOMIC_XCHG  */
#line 1323 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_XCHG); }
#line 5067 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 381: /* cat6_atomic_opc: T_OP_ATOMIC_INC  */
#line 1324 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_INC); }
#line 5073 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 382: /* cat6_atomic_opc: T_OP_ATOMIC_DEC  */
#line 1325 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_DEC); }
#line 5079 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 383: /* cat6_atomic_opc: T_OP_ATOMIC_CMPXCHG  */
#line 1326 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_CMPXCHG); }
#line 5085 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 384: /* cat6_atomic_opc: T_OP_ATOMIC_MIN  */
#line 1327 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_MIN); }
#line 5091 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 385: /* cat6_atomic_opc: T_OP_ATOMIC_MAX  */
#line 1328 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_MAX); }
#line 5097 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 386: /* cat6_atomic_opc: T_OP_ATOMIC_AND  */
#line 1329 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_AND); }
#line 5103 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 387: /* cat6_atomic_opc: T_OP_ATOMIC_OR  */
#line 1330 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_OR); }
#line 5109 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 388: /* cat6_atomic_opc: T_OP_ATOMIC_XOR  */
#line 1331 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_instr(OPC_ATOMIC_XOR); }
#line 5115 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 389: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_ADD  */
#line 1333 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_ADD); }
#line 5121 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 390: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_SUB  */
#line 1334 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_SUB); }
#line 5127 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 391: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_XCHG  */
#line 1335 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_XCHG); }
#line 5133 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 392: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_INC  */
#line 1336 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_INC); }
#line 5139 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 393: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_DEC  */
#line 1337 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_DEC); }
#line 5145 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 394: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_CMPXCHG  */
#line 1338 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_CMPXCHG); }
#line 5151 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 395: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_MIN  */
#line 1339 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_MIN); }
#line 5157 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 396: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_MAX  */
#line 1340 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_MAX); }
#line 5163 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 397: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_AND  */
#line 1341 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_AND); }
#line 5169 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 398: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_OR  */
#line 1342 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_OR); }
#line 5175 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 399: /* cat6_a3xx_atomic_opc: T_OP_ATOMIC_S_XOR  */
#line 1343 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_S_XOR); }
#line 5181 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 400: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_ADD  */
#line 1345 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_ADD); }
#line 5187 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 401: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_SUB  */
#line 1346 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_SUB); }
#line 5193 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 402: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_XCHG  */
#line 1347 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_XCHG); }
#line 5199 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 403: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_INC  */
#line 1348 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_INC); }
#line 5205 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 404: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_DEC  */
#line 1349 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_DEC); }
#line 5211 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 405: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_CMPXCHG  */
#line 1350 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_CMPXCHG); }
#line 5217 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 406: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_MIN  */
#line 1351 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_MIN); }
#line 5223 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 407: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_MAX  */
#line 1352 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_MAX); }
#line 5229 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 408: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_AND  */
#line 1353 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_AND); }
#line 5235 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 409: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_OR  */
#line 1354 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_OR); }
#line 5241 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 410: /* cat6_a6xx_atomic_opc: T_OP_ATOMIC_G_XOR  */
#line 1355 "../src/freedreno/ir3/ir3_parser.y"
                                              { new_instr(OPC_ATOMIC_G_XOR); }
#line 5247 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 417: /* cat6_ibo_opc_1src: T_OP_RESINFO  */
#line 1367 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_RESINFO); }
#line 5253 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 418: /* cat6_ibo_opc_ldgb: T_OP_LDGB  */
#line 1369 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_LDGB); }
#line 5259 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 419: /* cat6_ibo_opc_stgb: T_OP_STGB  */
#line 1370 "../src/freedreno/ir3/ir3_parser.y"
                                  { new_instr(OPC_STGB); }
#line 5265 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 422: /* $@40: %empty  */
#line 1374 "../src/freedreno/ir3/ir3_parser.y"
                                                                                  { dummy_dst(); }
#line 5271 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 424: /* cat6_id_opc: T_OP_GETSPID  */
#line 1377 "../src/freedreno/ir3/ir3_parser.y"
                                { new_instr(OPC_GETSPID); }
#line 5277 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 425: /* cat6_id_opc: T_OP_GETWID  */
#line 1378 "../src/freedreno/ir3/ir3_parser.y"
                                { new_instr(OPC_GETWID); }
#line 5283 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 426: /* cat6_id_opc: T_OP_GETFIBERID  */
#line 1379 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_instr(OPC_GETFIBERID); }
#line 5289 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 429: /* cat6_bindless_base: '.' T_BASE  */
#line 1384 "../src/freedreno/ir3/ir3_parser.y"
                              { instr->flags |= IR3_INSTR_B; instr->cat6.base = (yyvsp[0].tok); }
#line 5295 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 432: /* cat6_bindless_mode: T_NONUNIFORM cat6_bindless_base  */
#line 1388 "../src/freedreno/ir3/ir3_parser.y"
                                                   { instr->flags |= IR3_INSTR_NONUNIF; }
#line 5301 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 434: /* cat6_reg_or_immed: integer  */
#line 1391 "../src/freedreno/ir3/ir3_parser.y"
                           { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[0].num); }
#line 5307 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 435: /* cat6_bindless_ibo_opc_1src: T_OP_RESINFO_B  */
#line 1393 "../src/freedreno/ir3/ir3_parser.y"
                                                 { new_instr(OPC_RESINFO); }
#line 5313 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 436: /* cat6_bindless_ibo_opc_1src: T_OP_RESBASE  */
#line 1394 "../src/freedreno/ir3/ir3_parser.y"
                                                 { new_instr(OPC_RESBASE); }
#line 5319 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 437: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_ADD  */
#line 1396 "../src/freedreno/ir3/ir3_parser.y"
                                                     { new_instr(OPC_ATOMIC_B_ADD); dummy_dst(); }
#line 5325 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 438: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_SUB  */
#line 1397 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_SUB); dummy_dst(); }
#line 5331 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 439: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_XCHG  */
#line 1398 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_XCHG); dummy_dst(); }
#line 5337 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 440: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_INC  */
#line 1399 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_INC); dummy_dst(); }
#line 5343 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 441: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_DEC  */
#line 1400 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_DEC); dummy_dst(); }
#line 5349 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 442: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_CMPXCHG  */
#line 1401 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_CMPXCHG); dummy_dst(); }
#line 5355 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 443: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_MIN  */
#line 1402 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_MIN); dummy_dst(); }
#line 5361 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 444: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_MAX  */
#line 1403 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_MAX); dummy_dst(); }
#line 5367 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 445: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_AND  */
#line 1404 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_AND); dummy_dst(); }
#line 5373 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 446: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_OR  */
#line 1405 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_OR); dummy_dst(); }
#line 5379 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 447: /* cat6_bindless_ibo_opc_2src: T_OP_ATOMIC_B_XOR  */
#line 1406 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_ATOMIC_B_XOR); dummy_dst(); }
#line 5385 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 448: /* cat6_bindless_ibo_opc_3src: T_OP_STIB_B  */
#line 1408 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_STIB); dummy_dst(); }
#line 5391 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 449: /* cat6_bindless_ibo_opc_3src_dst: T_OP_LDIB_B  */
#line 1410 "../src/freedreno/ir3/ir3_parser.y"
                                                         { new_instr(OPC_LDIB); }
#line 5397 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 451: /* cat6_bindless_ibo: cat6_bindless_ibo_opc_2src cat6_typed cat6_dim cat6_type '.' cat6_immed '.' cat6_bindless_mode src_reg ',' cat6_reg_or_immed ',' cat6_reg_or_immed  */
#line 1413 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                                                                                      { swap(instr->srcs[0], instr->srcs[2]); }
#line 5403 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 452: /* cat6_bindless_ibo: cat6_bindless_ibo_opc_3src cat6_typed cat6_dim cat6_type '.' cat6_immed '.' cat6_bindless_mode src_reg ',' cat6_reg_or_immed src_uoffset ',' cat6_reg_or_immed  */
#line 1414 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                                                                                                  { swap(instr->srcs[0], instr->srcs[3]); }
#line 5409 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 453: /* cat6_bindless_ibo: cat6_bindless_ibo_opc_3src_dst cat6_typed cat6_dim cat6_type '.' cat6_immed '.' cat6_bindless_mode dst_reg ',' cat6_reg_or_immed src_uoffset ',' cat6_reg_or_immed  */
#line 1415 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                                                                                                      { swap(instr->srcs[0], instr->srcs[2]); swap(instr->srcs[1], instr->srcs[2]); }
#line 5415 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 454: /* cat6_bindless_ldc_opc: T_OP_LDC  */
#line 1417 "../src/freedreno/ir3/ir3_parser.y"
                                 { new_instr(OPC_LDC); }
#line 5421 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 455: /* cat6_bindless_ldc_middle: T_OFFSET '.' cat6_immed '.' cat6_bindless_mode dst_reg  */
#line 1421 "../src/freedreno/ir3/ir3_parser.y"
                                                                               { instr->cat6.d = (yyvsp[-5].tok); }
#line 5427 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 456: /* cat6_bindless_ldc_middle: 'u' '.' T_OFFSET '.' cat6_immed '.' cat6_bindless_mode dst_reg  */
#line 1422 "../src/freedreno/ir3/ir3_parser.y"
                                                                                       { instr->flags |= IR3_INSTR_U; instr->cat6.d = (yyvsp[-5].tok); }
#line 5433 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 457: /* cat6_bindless_ldc_middle: cat6_immed '.' 'k' '.' cat6_bindless_mode 'c' '[' T_A1 ']'  */
#line 1423 "../src/freedreno/ir3/ir3_parser.y"
                                                                                   { instr->opc = OPC_LDC_K; }
#line 5439 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 458: /* cat6_bindless_ldc: cat6_bindless_ldc_opc '.' cat6_bindless_ldc_middle ',' cat6_reg_or_immed ',' cat6_reg_or_immed  */
#line 1425 "../src/freedreno/ir3/ir3_parser.y"
                                                                                                                  {
                      instr->cat6.type = TYPE_U32;
                      /* TODO cleanup ir3 src order: */
                      swap(instr->srcs[0], instr->srcs[1]);
                   }
#line 5449 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 459: /* const_dst: integer  */
#line 1431 "../src/freedreno/ir3/ir3_parser.y"
                          { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[0].num); }
#line 5455 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 460: /* const_dst: T_A1  */
#line 1432 "../src/freedreno/ir3/ir3_parser.y"
                       { new_src(0, IR3_REG_IMMED)->iim_val = 0; instr->flags |= IR3_INSTR_A1EN; }
#line 5461 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 461: /* const_dst: T_A1 '+' integer  */
#line 1433 "../src/freedreno/ir3/ir3_parser.y"
                                   { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[0].num); instr->flags |= IR3_INSTR_A1EN; }
#line 5467 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 462: /* $@41: %empty  */
#line 1436 "../src/freedreno/ir3/ir3_parser.y"
                        { new_instr(OPC_STC); }
#line 5473 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 464: /* $@42: %empty  */
#line 1437 "../src/freedreno/ir3/ir3_parser.y"
                        { new_instr(OPC_STSC); }
#line 5479 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 466: /* cat6_shfl_mode: T_MOD_XOR  */
#line 1439 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat6.shfl_mode = SHFL_XOR;   }
#line 5485 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 467: /* cat6_shfl_mode: T_MOD_UP  */
#line 1440 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat6.shfl_mode = SHFL_UP;    }
#line 5491 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 468: /* cat6_shfl_mode: T_MOD_DOWN  */
#line 1441 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat6.shfl_mode = SHFL_DOWN;  }
#line 5497 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 469: /* cat6_shfl_mode: T_MOD_RUP  */
#line 1442 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat6.shfl_mode = SHFL_RUP;   }
#line 5503 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 470: /* cat6_shfl_mode: T_MOD_RDOWN  */
#line 1443 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat6.shfl_mode = SHFL_RDOWN; }
#line 5509 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 471: /* cat6_shfl_mode: integer  */
#line 1447 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat6.shfl_mode = (yyvsp[0].num); }
#line 5515 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 472: /* $@43: %empty  */
#line 1450 "../src/freedreno/ir3/ir3_parser.y"
                   { new_instr(OPC_SHFL); }
#line 5521 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 474: /* $@44: %empty  */
#line 1452 "../src/freedreno/ir3/ir3_parser.y"
                                             {
                     new_instr(OPC_RAY_INTERSECTION);
                     }
#line 5529 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 476: /* cat6_todo: T_OP_G2L  */
#line 1456 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_G2L); }
#line 5535 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 477: /* cat6_todo: T_OP_L2G  */
#line 1457 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_L2G); }
#line 5541 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 478: /* cat6_todo: T_OP_RESFMT  */
#line 1458 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_instr(OPC_RESFMT); }
#line 5547 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 493: /* cat7_scope: '.' 'w'  */
#line 1475 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat7.w = true; }
#line 5553 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 494: /* cat7_scope: '.' 'r'  */
#line 1476 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat7.r = true; }
#line 5559 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 495: /* cat7_scope: '.' 'l'  */
#line 1477 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat7.l = true; }
#line 5565 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 496: /* cat7_scope: '.' 'g'  */
#line 1478 "../src/freedreno/ir3/ir3_parser.y"
                            { instr->cat7.g = true; }
#line 5571 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 499: /* $@45: %empty  */
#line 1483 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_BAR); }
#line 5577 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 501: /* $@46: %empty  */
#line 1484 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_FENCE); }
#line 5583 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 503: /* cat7_data_cache: T_OP_DCCLN  */
#line 1486 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_DCCLN); }
#line 5589 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 504: /* cat7_data_cache: T_OP_DCINV  */
#line 1487 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_DCINV); }
#line 5595 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 505: /* cat7_data_cache: T_OP_DCFLU  */
#line 1488 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_DCFLU); }
#line 5601 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 507: /* cat7_alias_dst: T_RT  */
#line 1491 "../src/freedreno/ir3/ir3_parser.y"
                        { new_dst((yyvsp[0].num), IR3_REG_RT); }
#line 5607 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 510: /* cat7_alias_scope: T_MOD_TEX  */
#line 1496 "../src/freedreno/ir3/ir3_parser.y"
                                { instr->cat7.alias_scope = ALIAS_TEX; }
#line 5613 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 511: /* cat7_alias_scope: T_MOD_MEM  */
#line 1497 "../src/freedreno/ir3/ir3_parser.y"
                                { instr->cat7.alias_scope = ALIAS_MEM; }
#line 5619 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 512: /* cat7_alias_scope: T_MOD_RT  */
#line 1498 "../src/freedreno/ir3/ir3_parser.y"
                                { instr->cat7.alias_scope = ALIAS_RT; }
#line 5625 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 518: /* cat7_alias_type: cat7_alias_float_type  */
#line 1507 "../src/freedreno/ir3/ir3_parser.y"
                                        { instr->cat7.alias_type_float = true; }
#line 5631 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 519: /* cat7_alias_table_size_minus_one: T_INT  */
#line 1509 "../src/freedreno/ir3/ir3_parser.y"
                                       { instr->cat7.alias_table_size_minus_one = (yyvsp[0].num); }
#line 5637 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 522: /* cat7_instr: T_OP_SLEEP  */
#line 1513 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_SLEEP); }
#line 5643 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 523: /* cat7_instr: T_OP_CCINV  */
#line 1514 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_CCINV); }
#line 5649 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 524: /* cat7_instr: T_OP_ICINV  */
#line 1515 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_ICINV); }
#line 5655 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 525: /* cat7_instr: T_OP_LOCK  */
#line 1516 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_LOCK); }
#line 5661 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 526: /* cat7_instr: T_OP_UNLOCK  */
#line 1517 "../src/freedreno/ir3/ir3_parser.y"
                                           { new_instr(OPC_UNLOCK); }
#line 5667 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 527: /* $@47: %empty  */
#line 1518 "../src/freedreno/ir3/ir3_parser.y"
                              {
                       new_instr(OPC_ALIAS);
                   }
#line 5675 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 529: /* raw_instr: T_RAW  */
#line 1522 "../src/freedreno/ir3/ir3_parser.y"
                   {new_instr(OPC_META_RAW)->raw.value = (yyvsp[0].u64);}
#line 5681 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 532: /* meta_print_reg: ',' T_REGISTER  */
#line 1527 "../src/freedreno/ir3/ir3_parser.y"
                               {
	meta_print_data.regs_to_dump[meta_print_data.regs_count++] = (yyvsp[0].num);
}
#line 5689 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 533: /* meta_print_start: T_OP_PRINT T_REGISTER  */
#line 1531 "../src/freedreno/ir3/ir3_parser.y"
                                        {
	meta_print_data.reg_address_lo = (yyvsp[0].num);
	meta_print_data.reg_address_hi = (yyvsp[0].num) + 2;
	meta_print_data.reg_tmp = (yyvsp[0].num) + 4;
	meta_print_data.regs_count = 0;
}
#line 5700 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 534: /* meta_print: meta_print_start meta_print_regs  */
#line 1538 "../src/freedreno/ir3/ir3_parser.y"
                                             {
	/* low */
	new_instr(OPC_MOV);
	instr->cat1.src_type = TYPE_U32;
	instr->cat1.dst_type = TYPE_U32;
	new_dst(meta_print_data.reg_address_lo, 0);
	new_src(0, IR3_REG_IMMED)->uim_val = info->shader_print_buffer_iova & 0xffffffff;

	/* high */
	new_instr(OPC_MOV);
	instr->cat1.src_type = TYPE_U32;
	instr->cat1.dst_type = TYPE_U32;
	new_dst(meta_print_data.reg_address_hi, 0);
	new_src(0, IR3_REG_IMMED)->uim_val = info->shader_print_buffer_iova >> 32;

	/* offset */
	new_instr(OPC_MOV);
	instr->cat1.src_type = TYPE_U32;
	instr->cat1.dst_type = TYPE_U32;
	new_dst(meta_print_data.reg_tmp, 0);
	new_src(0, IR3_REG_IMMED)->uim_val = 4 * meta_print_data.regs_count;

	new_instr(OPC_NOP);
	instr->repeat = 5;

	/* Increment and get current offset into print buffer */
	new_instr(OPC_ATOMIC_G_ADD);
	instr->cat6.d = 1;
	instr->cat6.typed = 0;
	instr->cat6.type = TYPE_U32;
	instr->cat6.iim_val = 1;

	new_dst(meta_print_data.reg_address_lo, 0);
	new_src(meta_print_data.reg_address_lo, 0);
	new_src(meta_print_data.reg_tmp, 0);

	/* Store all regs */
	for (uint32_t i = 0; i < meta_print_data.regs_count; i++) {
		new_instr(OPC_STG);
		dummy_dst();
		instr->cat6.type = TYPE_U32;
		instr->flags = IR3_INSTR_SY;
		new_src(meta_print_data.reg_address_lo, 0);
		new_src(0, IR3_REG_IMMED)->iim_val = 0;
		new_src(meta_print_data.regs_to_dump[i], IR3_REG_R);
		new_src(0, IR3_REG_IMMED)->iim_val = 1;

		new_instr(OPC_ADD_U);
		instr->flags = IR3_INSTR_SS;
		new_dst(meta_print_data.reg_address_lo, 0);
		new_src(meta_print_data.reg_address_lo, 0);
		new_src(0, IR3_REG_IMMED)->uim_val = 4;

		new_instr(OPC_NOP);
		instr->repeat = 5;
	}
}
#line 5762 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 535: /* src_gpr: T_REGISTER  */
#line 1596 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_src((yyvsp[0].num), 0); }
#line 5768 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 536: /* src_a0: T_A0  */
#line 1597 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_src((61 << 3), IR3_REG_HALF); }
#line 5774 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 537: /* src_a1: T_A1  */
#line 1598 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_src((61 << 3) + 1, IR3_REG_HALF); }
#line 5780 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 538: /* src_p0: T_P0  */
#line 1599 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_src((62 << 3) + (yyvsp[0].num), IR3_REG_PREDICATE); }
#line 5786 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 543: /* dst: T_REGISTER  */
#line 1606 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_dst((yyvsp[0].num), 0); }
#line 5792 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 544: /* dst: T_A0  */
#line 1607 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_dst((61 << 3), IR3_REG_HALF); }
#line 5798 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 545: /* dst: T_A1  */
#line 1608 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_dst((61 << 3) + 1, IR3_REG_HALF); }
#line 5804 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 546: /* dst: T_P0  */
#line 1609 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_dst((62 << 3) + (yyvsp[0].num), IR3_REG_PREDICATE); }
#line 5810 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 547: /* const: T_CONSTANT  */
#line 1611 "../src/freedreno/ir3/ir3_parser.y"
                                  { (yyval.reg) = new_src((yyvsp[0].num), IR3_REG_CONST); }
#line 5816 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 548: /* dst_reg_flag: T_EVEN  */
#line 1613 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat1.round = ROUND_EVEN; }
#line 5822 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 549: /* dst_reg_flag: T_POS_INFINITY  */
#line 1614 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat1.round = ROUND_POS_INF; }
#line 5828 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 550: /* dst_reg_flag: T_NEG_INFINITY  */
#line 1615 "../src/freedreno/ir3/ir3_parser.y"
                                  { instr->cat1.round = ROUND_NEG_INF; }
#line 5834 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 551: /* dst_reg_flag: T_EI  */
#line 1616 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.flags |= IR3_REG_EI; }
#line 5840 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 552: /* dst_reg_flag: T_WRMASK  */
#line 1617 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.wrmask = (yyvsp[0].num); }
#line 5846 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 555: /* dst_reg: dst  */
#line 1623 "../src/freedreno/ir3/ir3_parser.y"
                                       { (yyvsp[0].reg)->flags |= IR3_REG_R; }
#line 5852 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 556: /* dst_reg: dst_reg_flags dst  */
#line 1624 "../src/freedreno/ir3/ir3_parser.y"
                                       { (yyvsp[0].reg)->flags |= IR3_REG_R; }
#line 5858 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 557: /* src_reg_flag: T_ABSNEG  */
#line 1626 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.flags |= IR3_REG_ABS|IR3_REG_NEGATE; }
#line 5864 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 558: /* src_reg_flag: T_NEG  */
#line 1627 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.flags |= IR3_REG_NEGATE; }
#line 5870 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 559: /* src_reg_flag: T_ABS  */
#line 1628 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.flags |= IR3_REG_ABS; }
#line 5876 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 560: /* src_reg_flag: T_R  */
#line 1629 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.flags |= IR3_REG_R; }
#line 5882 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 561: /* src_reg_flag: T_LAST  */
#line 1630 "../src/freedreno/ir3/ir3_parser.y"
                                  { rflags.flags |= IR3_REG_LAST_USE; }
#line 5888 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 581: /* uoffset: %empty  */
#line 1659 "../src/freedreno/ir3/ir3_parser.y"
                   { (yyval.num) = 0; }
#line 5894 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 582: /* uoffset: '+' integer  */
#line 1660 "../src/freedreno/ir3/ir3_parser.y"
                               { (yyval.num) = (yyvsp[0].num); }
#line 5900 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 584: /* offset: '-' integer  */
#line 1663 "../src/freedreno/ir3/ir3_parser.y"
                               { (yyval.num) = -(yyvsp[0].num); }
#line 5906 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 585: /* src_uoffset: uoffset  */
#line 1665 "../src/freedreno/ir3/ir3_parser.y"
                           { new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[0].num); if ((yyvsp[0].num)) instr->flags |= IR3_INSTR_IMM_OFFSET; }
#line 5912 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 586: /* relative_gpr_src: 'r' '<' T_A0 offset '>'  */
#line 1667 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_src(0, IR3_REG_RELATIV)->array.offset = (yyvsp[-1].num); }
#line 5918 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 587: /* relative_gpr_src: T_HR '<' T_A0 offset '>'  */
#line 1668 "../src/freedreno/ir3/ir3_parser.y"
                                             { new_src(0, IR3_REG_RELATIV | IR3_REG_HALF)->array.offset = (yyvsp[-1].num); }
#line 5924 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 588: /* relative_gpr_dst: 'r' '<' T_A0 offset '>'  */
#line 1670 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_dst(0, IR3_REG_RELATIV)->array.offset = (yyvsp[-1].num); }
#line 5930 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 589: /* relative_gpr_dst: T_HR '<' T_A0 offset '>'  */
#line 1671 "../src/freedreno/ir3/ir3_parser.y"
                                             { new_dst(0, IR3_REG_RELATIV | IR3_REG_HALF)->array.offset = (yyvsp[-1].num); }
#line 5936 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 590: /* relative_const: 'c' '<' T_A0 offset '>'  */
#line 1673 "../src/freedreno/ir3/ir3_parser.y"
                                            { new_src(0, IR3_REG_RELATIV | IR3_REG_CONST)->array.offset = (yyvsp[-1].num); }
#line 5942 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 591: /* relative_const: T_HC '<' T_A0 offset '>'  */
#line 1674 "../src/freedreno/ir3/ir3_parser.y"
                                             { new_src(0, IR3_REG_RELATIV | IR3_REG_CONST | IR3_REG_HALF)->array.offset = (yyvsp[-1].num); }
#line 5948 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 594: /* immediate_cat1: integer  */
#line 1686 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->iim_val = type_size(instr->cat1.src_type) < 32 ? (yyvsp[0].num) & 0xffff : (yyvsp[0].num); }
#line 5954 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 595: /* immediate_cat1: '(' integer ')'  */
#line 1687 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[-1].num); }
#line 5960 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 596: /* immediate_cat1: '(' float ')'  */
#line 1688 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = (yyvsp[-1].flt); }
#line 5966 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 597: /* immediate_cat1: 'h' '(' integer ')'  */
#line 1689 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED | IR3_REG_HALF)->iim_val = (yyvsp[-1].num) & 0xffff; }
#line 5972 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 598: /* immediate_cat1: 'h' '(' float ')'  */
#line 1690 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED | IR3_REG_HALF)->uim_val = _mesa_float_to_half((yyvsp[-1].flt)); }
#line 5978 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 599: /* immediate_cat1: '(' T_NAN ')'  */
#line 1691 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = NAN; }
#line 5984 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 600: /* immediate_cat1: '(' T_INF ')'  */
#line 1692 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = INFINITY; }
#line 5990 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 601: /* immediate_cat1: T_FLUT_0_0  */
#line 1693 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = 0.0; }
#line 5996 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 602: /* immediate_cat1: T_FLUT_0_5  */
#line 1694 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = 0.5; }
#line 6002 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 603: /* immediate_cat1: T_FLUT_1_0  */
#line 1695 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = 1.0; }
#line 6008 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 604: /* immediate_cat1: T_FLUT_2_0  */
#line 1696 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = 2.0; }
#line 6014 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 605: /* immediate_cat1: T_FLUT_4_0  */
#line 1697 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->fim_val = 4.0; }
#line 6020 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 606: /* immediate: integer  */
#line 1699 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[0].num); }
#line 6026 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 607: /* immediate: '(' integer ')'  */
#line 1700 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->iim_val = (yyvsp[-1].num); }
#line 6032 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 608: /* immediate: flut_immed  */
#line 1701 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED)->uim_val = (yyvsp[0].num); }
#line 6038 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 609: /* immediate: 'h' '(' integer ')'  */
#line 1702 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED | IR3_REG_HALF)->iim_val = (yyvsp[-1].num); }
#line 6044 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 610: /* immediate: 'h' flut_immed  */
#line 1703 "../src/freedreno/ir3/ir3_parser.y"
                                       { new_src(0, IR3_REG_IMMED | IR3_REG_HALF)->uim_val = (yyvsp[0].num); }
#line 6050 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 623: /* uinteger: T_INT  */
#line 1719 "../src/freedreno/ir3/ir3_parser.y"
                               { (yyval.num) = (yyvsp[0].num); }
#line 6056 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 624: /* uinteger: T_HEX  */
#line 1720 "../src/freedreno/ir3/ir3_parser.y"
                               { (yyval.num) = (yyvsp[0].unum); }
#line 6062 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 625: /* integer: uinteger  */
#line 1722 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.num) = (yyvsp[0].num); }
#line 6068 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 626: /* integer: '-' uinteger  */
#line 1723 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.num) = -(yyvsp[0].num); }
#line 6074 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 627: /* float: T_FLOAT  */
#line 1725 "../src/freedreno/ir3/ir3_parser.y"
                               { (yyval.flt) = (yyvsp[0].flt); }
#line 6080 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 628: /* float: '-' T_FLOAT  */
#line 1726 "../src/freedreno/ir3/ir3_parser.y"
                               { (yyval.flt) = -(yyvsp[0].flt); }
#line 6086 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 629: /* type: T_TYPE_F16  */
#line 1728 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_F16;   }
#line 6092 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 630: /* type: T_TYPE_F32  */
#line 1729 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_F32;   }
#line 6098 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 631: /* type: T_TYPE_U16  */
#line 1730 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_U16;   }
#line 6104 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 632: /* type: T_TYPE_U32  */
#line 1731 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_U32;   }
#line 6110 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 633: /* type: T_TYPE_S16  */
#line 1732 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_S16;   }
#line 6116 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 634: /* type: T_TYPE_S32  */
#line 1733 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_S32;   }
#line 6122 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 635: /* type: T_TYPE_U8  */
#line 1734 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_U8;    }
#line 6128 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 636: /* type: T_TYPE_U8_32  */
#line 1735 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_U8_32; }
#line 6134 "src/freedreno/ir3/ir3_parser.c"
    break;

  case 637: /* type: T_TYPE_U64  */
#line 1736 "../src/freedreno/ir3/ir3_parser.y"
                                { (yyval.type) = TYPE_ATOMIC_U64;  }
#line 6140 "src/freedreno/ir3/ir3_parser.c"
    break;


#line 6144 "src/freedreno/ir3/ir3_parser.c"

      default: break;
    }
  /* User semantic actions sometimes alter yychar, and that requires
     that yytoken be updated with the new translation.  We take the
     approach of translating immediately before every use of yytoken.
     One alternative is translating here after every semantic action,
     but that translation would be missed if the semantic action invokes
     YYABORT, YYACCEPT, or YYERROR immediately after altering yychar or
     if it invokes YYBACKUP.  In the case of YYABORT or YYACCEPT, an
     incorrect destructor might then be invoked immediately.  In the
     case of YYERROR or YYBACKUP, subsequent parser actions might lead
     to an incorrect destructor call or verbose syntax error message
     before the lookahead is translated.  */
  YY_SYMBOL_PRINT ("-> $$ =", YY_CAST (yysymbol_kind_t, yyr1[yyn]), &yyval, &yyloc);

  YYPOPSTACK (yylen);
  yylen = 0;

  *++yyvsp = yyval;

  /* Now 'shift' the result of the reduction.  Determine what state
     that goes to, based on the state we popped back to and the rule
     number reduced by.  */
  {
    const int yylhs = yyr1[yyn] - YYNTOKENS;
    const int yyi = yypgoto[yylhs] + *yyssp;
    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
               ? yytable[yyi]
               : yydefgoto[yylhs]);
  }

  goto yynewstate;


/*--------------------------------------.
| yyerrlab -- here on detecting error.  |
`--------------------------------------*/
yyerrlab:
  /* Make sure we have latest lookahead translation.  See comments at
     user semantic actions for why this is necessary.  */
  yytoken = yychar == YYEMPTY ? YYSYMBOL_YYEMPTY : YYTRANSLATE (yychar);
  /* If not already recovering from an error, report this error.  */
  if (!yyerrstatus)
    {
      ++yynerrs;
      {
        yypcontext_t yyctx
          = {yyssp, yytoken};
        char const *yymsgp = YY_("syntax error");
        int yysyntax_error_status;
        yysyntax_error_status = yysyntax_error (&yymsg_alloc, &yymsg, &yyctx);
        if (yysyntax_error_status == 0)
          yymsgp = yymsg;
        else if (yysyntax_error_status == -1)
          {
            if (yymsg != yymsgbuf)
              YYSTACK_FREE (yymsg);
            yymsg = YY_CAST (char *,
                             YYSTACK_ALLOC (YY_CAST (YYSIZE_T, yymsg_alloc)));
            if (yymsg)
              {
                yysyntax_error_status
                  = yysyntax_error (&yymsg_alloc, &yymsg, &yyctx);
                yymsgp = yymsg;
              }
            else
              {
                yymsg = yymsgbuf;
                yymsg_alloc = sizeof yymsgbuf;
                yysyntax_error_status = YYENOMEM;
              }
          }
        yyerror (yymsgp);
        if (yysyntax_error_status == YYENOMEM)
          YYNOMEM;
      }
    }

  if (yyerrstatus == 3)
    {
      /* If just tried and failed to reuse lookahead token after an
         error, discard it.  */

      if (yychar <= YYEOF)
        {
          /* Return failure if at end of input.  */
          if (yychar == YYEOF)
            YYABORT;
        }
      else
        {
          yydestruct ("Error: discarding",
                      yytoken, &yylval);
          yychar = YYEMPTY;
        }
    }

  /* Else will try to reuse lookahead token after shifting the error
     token.  */
  goto yyerrlab1;


/*---------------------------------------------------.
| yyerrorlab -- error raised explicitly by YYERROR.  |
`---------------------------------------------------*/
yyerrorlab:
  /* Pacify compilers when the user code never invokes YYERROR and the
     label yyerrorlab therefore never appears in user code.  */
  if (0)
    YYERROR;
  ++yynerrs;

  /* Do not reclaim the symbols of the rule whose action triggered
     this YYERROR.  */
  YYPOPSTACK (yylen);
  yylen = 0;
  YY_STACK_PRINT (yyss, yyssp);
  yystate = *yyssp;
  goto yyerrlab1;


/*-------------------------------------------------------------.
| yyerrlab1 -- common code for both syntax error and YYERROR.  |
`-------------------------------------------------------------*/
yyerrlab1:
  yyerrstatus = 3;      /* Each real token shifted decrements this.  */

  /* Pop stack until we find a state that shifts the error token.  */
  for (;;)
    {
      yyn = yypact[yystate];
      if (!yypact_value_is_default (yyn))
        {
          yyn += YYSYMBOL_YYerror;
          if (0 <= yyn && yyn <= YYLAST && yycheck[yyn] == YYSYMBOL_YYerror)
            {
              yyn = yytable[yyn];
              if (0 < yyn)
                break;
            }
        }

      /* Pop the current state because it cannot handle the error token.  */
      if (yyssp == yyss)
        YYABORT;


      yydestruct ("Error: popping",
                  YY_ACCESSING_SYMBOL (yystate), yyvsp);
      YYPOPSTACK (1);
      yystate = *yyssp;
      YY_STACK_PRINT (yyss, yyssp);
    }

  YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
  *++yyvsp = yylval;
  YY_IGNORE_MAYBE_UNINITIALIZED_END


  /* Shift the error token.  */
  YY_SYMBOL_PRINT ("Shifting", YY_ACCESSING_SYMBOL (yyn), yyvsp, yylsp);

  yystate = yyn;
  goto yynewstate;


/*-------------------------------------.
| yyacceptlab -- YYACCEPT comes here.  |
`-------------------------------------*/
yyacceptlab:
  yyresult = 0;
  goto yyreturnlab;


/*-----------------------------------.
| yyabortlab -- YYABORT comes here.  |
`-----------------------------------*/
yyabortlab:
  yyresult = 1;
  goto yyreturnlab;


/*-----------------------------------------------------------.
| yyexhaustedlab -- YYNOMEM (memory exhaustion) comes here.  |
`-----------------------------------------------------------*/
yyexhaustedlab:
  yyerror (YY_("memory exhausted"));
  yyresult = 2;
  goto yyreturnlab;


/*----------------------------------------------------------.
| yyreturnlab -- parsing is finished, clean up and return.  |
`----------------------------------------------------------*/
yyreturnlab:
  if (yychar != YYEMPTY)
    {
      /* Make sure we have latest lookahead translation.  See comments at
         user semantic actions for why this is necessary.  */
      yytoken = YYTRANSLATE (yychar);
      yydestruct ("Cleanup: discarding lookahead",
                  yytoken, &yylval);
    }
  /* Do not reclaim the symbols of the rule whose action triggered
     this YYABORT or YYACCEPT.  */
  YYPOPSTACK (yylen);
  YY_STACK_PRINT (yyss, yyssp);
  while (yyssp != yyss)
    {
      yydestruct ("Cleanup: popping",
                  YY_ACCESSING_SYMBOL (+*yyssp), yyvsp);
      YYPOPSTACK (1);
    }
#ifndef yyoverflow
  if (yyss != yyssa)
    YYSTACK_FREE (yyss);
#endif
  if (yymsg != yymsgbuf)
    YYSTACK_FREE (yymsg);
  return yyresult;
}

